/* Generated by Cython 0.27.3 */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_27_3"
#define CYTHON_FUTURE_DIVISION 0
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (0 && PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#if PY_VERSION_HEX < 0x030700A0 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject **args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject **args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef __cplusplus
  #error "Cython files generated with the C++ option must be compiled with a C++ compiler."
#endif
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #else
    #define CYTHON_INLINE inline
  #endif
#endif
template<typename T>
void __Pyx_call_destructor(T& x) {
    x.~T();
}
template<typename T>
class __Pyx_FakeReference {
  public:
    __Pyx_FakeReference() : ptr(NULL) { }
    __Pyx_FakeReference(const T& ref) : ptr(const_cast<T*>(&ref)) { }
    T *operator->() { return ptr; }
    T *operator&() { return ptr; }
    operator T&() { return *ptr; }
    template<typename U> bool operator ==(U other) { return *ptr == other; }
    template<typename U> bool operator !=(U other) { return *ptr != other; }
  private:
    T *ptr;
};

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif


#define __PYX_ERR(f_index, lineno, Ln_error) \
{ \
  __pyx_filename = __pyx_f[f_index]; __pyx_lineno = lineno; __pyx_clineno = __LINE__; goto Ln_error; \
}

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__neologdn
#define __PYX_HAVE_API__neologdn
#include <string.h>
#include <stdlib.h>
#include <utility>
#include "ios"
#include "new"
#include "stdexcept"
#include "typeinfo"
#include <unordered_map>
#include <unordered_set>
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c));
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "neologdn.pyx",
};

/*--- Type declarations ---*/
struct __pyx_opt_args_8neologdn_normalize;

/* "neologdn.pyx":105
 * 
 * 
 * cpdef unicode normalize(unicode text, int repeat=0, bint remove_space=True):             # <<<<<<<<<<<<<<
 *     cdef Py_UNICODE *buf = <Py_UNICODE *>malloc(sizeof(Py_UNICODE) * (len(text) + 1))
 * 
 */
struct __pyx_opt_args_8neologdn_normalize {
  int __pyx_n;
  int repeat;
  int remove_space;
};

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* unicode_iter.proto */
static CYTHON_INLINE int __Pyx_init_unicode_iteration(
    PyObject* ustring, Py_ssize_t *length, void** data, int *kind);

/* GetModuleGlobalName.proto */
static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely((Py_TYPE(obj) == type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args))
                PyErr_SetObject(PyExc_KeyError, args);
            Py_XDECREF(args);
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#else
    #define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o,n,NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* ObjectAsPyUnicode.proto */
static CYTHON_INLINE Py_UNICODE __Pyx_PyObject_AsPy_UNICODE(PyObject*);

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* Globals.proto */
static PyObject* __Pyx_Globals(void);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);


/* Module declarations from 'libc.string' */

/* Module declarations from 'libc.stdlib' */

/* Module declarations from 'libcpp.utility' */

/* Module declarations from 'libcpp.unordered_map' */

/* Module declarations from 'libcpp.unordered_set' */

/* Module declarations from 'neologdn' */
static std::unordered_map<Py_UNICODE,Py_UNICODE>  __pyx_v_8neologdn_conversion_map;
static std::unordered_map<Py_UNICODE,Py_UNICODE>  __pyx_v_8neologdn_kana_ten_map;
static std::unordered_map<Py_UNICODE,Py_UNICODE>  __pyx_v_8neologdn_kana_maru_map;
static std::unordered_set<Py_UNICODE>  __pyx_v_8neologdn_blocks;
static std::unordered_set<Py_UNICODE>  __pyx_v_8neologdn_basic_latin;
static PyObject *__pyx_f_8neologdn_normalize(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_8neologdn_normalize *__pyx_optional_args); /*proto*/
#define __Pyx_MODULE_NAME "neologdn"
extern int __pyx_module_is_main_neologdn;
int __pyx_module_is_main_neologdn = 0;

/* Implementation of 'neologdn' */
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_chr;
static PyObject *__pyx_builtin_map;
static const char __pyx_k_0[] = "0";
static const char __pyx_k_1[] = "1";
static const char __pyx_k_2[] = "2";
static const char __pyx_k_3[] = "3";
static const char __pyx_k_4[] = "4";
static const char __pyx_k_5[] = "5";
static const char __pyx_k_6[] = "6";
static const char __pyx_k_7[] = "7";
static const char __pyx_k_8[] = "8";
static const char __pyx_k_9[] = "9";
static const char __pyx_k_A[] = "A";
static const char __pyx_k_B[] = "B";
static const char __pyx_k_C[] = "C";
static const char __pyx_k_D[] = "D";
static const char __pyx_k_E[] = "E";
static const char __pyx_k_F[] = "F";
static const char __pyx_k_G[] = "G";
static const char __pyx_k_H[] = "H";
static const char __pyx_k_I[] = "I";
static const char __pyx_k_J[] = "J";
static const char __pyx_k_K[] = "K";
static const char __pyx_k_L[] = "L";
static const char __pyx_k_M[] = "M";
static const char __pyx_k_N[] = "N";
static const char __pyx_k_O[] = "O";
static const char __pyx_k_P[] = "P";
static const char __pyx_k_Q[] = "Q";
static const char __pyx_k_R[] = "R";
static const char __pyx_k_S[] = "S";
static const char __pyx_k_T[] = "T";
static const char __pyx_k_U[] = "U";
static const char __pyx_k_V[] = "V";
static const char __pyx_k_W[] = "W";
static const char __pyx_k_X[] = "X";
static const char __pyx_k_Y[] = "Y";
static const char __pyx_k_Z[] = "Z";
static const char __pyx_k_a[] = "a";
static const char __pyx_k_b[] = "b";
static const char __pyx_k_c[] = "c";
static const char __pyx_k_d[] = "d";
static const char __pyx_k_e[] = "e";
static const char __pyx_k_f[] = "f";
static const char __pyx_k_g[] = "g";
static const char __pyx_k_h[] = "h";
static const char __pyx_k_i[] = "i";
static const char __pyx_k_j[] = "j";
static const char __pyx_k_k[] = "k";
static const char __pyx_k_l[] = "l";
static const char __pyx_k_m[] = "m";
static const char __pyx_k_n[] = "n";
static const char __pyx_k_o[] = "o";
static const char __pyx_k_p[] = "p";
static const char __pyx_k_q[] = "q";
static const char __pyx_k_r[] = "r";
static const char __pyx_k_s[] = "s";
static const char __pyx_k_t[] = "t";
static const char __pyx_k_u[] = "u";
static const char __pyx_k_v[] = "v";
static const char __pyx_k_w[] = "w";
static const char __pyx_k_x[] = "x";
static const char __pyx_k_y[] = "y";
static const char __pyx_k_z[] = "z";
static const char __pyx_k__2[] = "\357\275\201";
static const char __pyx_k__4[] = "\357\275\202";
static const char __pyx_k__6[] = "\357\275\203";
static const char __pyx_k__8[] = "\357\275\204";
static const char __pyx_k_0_3[] = "0.3";
static const char __pyx_k__10[] = "\357\275\205";
static const char __pyx_k__12[] = "\357\275\206";
static const char __pyx_k__14[] = "\357\275\207";
static const char __pyx_k__16[] = "\357\275\210";
static const char __pyx_k__18[] = "\357\275\211";
static const char __pyx_k__20[] = "\357\275\212";
static const char __pyx_k__22[] = "\357\275\213";
static const char __pyx_k__24[] = "\357\275\214";
static const char __pyx_k__26[] = "\357\275\215";
static const char __pyx_k__28[] = "\357\275\216";
static const char __pyx_k__30[] = "\357\275\217";
static const char __pyx_k__32[] = "\357\275\220";
static const char __pyx_k__34[] = "\357\275\221";
static const char __pyx_k__36[] = "\357\275\222";
static const char __pyx_k__38[] = "\357\275\223";
static const char __pyx_k__40[] = "\357\275\224";
static const char __pyx_k__42[] = "\357\275\225";
static const char __pyx_k__44[] = "\357\275\226";
static const char __pyx_k__46[] = "\357\275\227";
static const char __pyx_k__48[] = "\357\275\230";
static const char __pyx_k__50[] = "\357\275\231";
static const char __pyx_k__52[] = "\357\275\232";
static const char __pyx_k__54[] = "\357\274\241";
static const char __pyx_k__56[] = "\357\274\242";
static const char __pyx_k__58[] = "\357\274\243";
static const char __pyx_k__60[] = "\357\274\244";
static const char __pyx_k__62[] = "\357\274\245";
static const char __pyx_k__64[] = "\357\274\246";
static const char __pyx_k__66[] = "\357\274\247";
static const char __pyx_k__68[] = "\357\274\250";
static const char __pyx_k__70[] = "\357\274\251";
static const char __pyx_k__72[] = "\357\274\252";
static const char __pyx_k__74[] = "\357\274\253";
static const char __pyx_k__76[] = "\357\274\254";
static const char __pyx_k__78[] = "\357\274\255";
static const char __pyx_k__80[] = "\357\274\256";
static const char __pyx_k__82[] = "\357\274\257";
static const char __pyx_k__84[] = "\357\274\260";
static const char __pyx_k__86[] = "\357\274\261";
static const char __pyx_k__88[] = "\357\274\262";
static const char __pyx_k__90[] = "\357\274\263";
static const char __pyx_k__92[] = "\357\274\264";
static const char __pyx_k__94[] = "\357\274\265";
static const char __pyx_k__96[] = "\357\274\266";
static const char __pyx_k__98[] = "\357\274\267";
static const char __pyx_k_chr[] = "chr";
static const char __pyx_k_map[] = "map";
static const char __pyx_k_sys[] = "sys";
static const char __pyx_k_KANA[] = "KANA";
static const char __pyx_k__100[] = "\357\274\270";
static const char __pyx_k__102[] = "\357\274\271";
static const char __pyx_k__104[] = "\357\274\272";
static const char __pyx_k__106[] = "\357\274\201";
static const char __pyx_k__107[] = "!";
static const char __pyx_k__109[] = "\342\200\235";
static const char __pyx_k__110[] = "\"";
static const char __pyx_k__112[] = "\357\274\203";
static const char __pyx_k__113[] = "#";
static const char __pyx_k__115[] = "\357\274\204";
static const char __pyx_k__116[] = "$";
static const char __pyx_k__118[] = "\357\274\205";
static const char __pyx_k__119[] = "%";
static const char __pyx_k__121[] = "\357\274\206";
static const char __pyx_k__122[] = "&";
static const char __pyx_k__124[] = "\342\200\231";
static const char __pyx_k__125[] = "'";
static const char __pyx_k__127[] = "\357\274\210";
static const char __pyx_k__128[] = "(";
static const char __pyx_k__130[] = "\357\274\211";
static const char __pyx_k__131[] = ")";
static const char __pyx_k__133[] = "\357\274\212";
static const char __pyx_k__134[] = "*";
static const char __pyx_k__136[] = "\357\274\213";
static const char __pyx_k__137[] = "+";
static const char __pyx_k__139[] = "\357\274\214";
static const char __pyx_k__140[] = ",";
static const char __pyx_k__142[] = "\342\210\222";
static const char __pyx_k__143[] = "-";
static const char __pyx_k__145[] = "\357\274\216";
static const char __pyx_k__146[] = ".";
static const char __pyx_k__148[] = "\357\274\217";
static const char __pyx_k__149[] = "/";
static const char __pyx_k__151[] = "\357\274\232";
static const char __pyx_k__152[] = ":";
static const char __pyx_k__154[] = "\357\274\233";
static const char __pyx_k__155[] = ";";
static const char __pyx_k__157[] = "\357\274\234";
static const char __pyx_k__158[] = "<";
static const char __pyx_k__160[] = "\357\274\235";
static const char __pyx_k__161[] = "=";
static const char __pyx_k__163[] = "\357\274\236";
static const char __pyx_k__164[] = ">";
static const char __pyx_k__166[] = "\357\274\237";
static const char __pyx_k__167[] = "?";
static const char __pyx_k__169[] = "\357\274\240";
static const char __pyx_k__170[] = "@";
static const char __pyx_k__172[] = "\357\274\273";
static const char __pyx_k__173[] = "[";
static const char __pyx_k__175[] = "\302\245";
static const char __pyx_k__176[] = "\\";
static const char __pyx_k__178[] = "\357\274\275";
static const char __pyx_k__179[] = "]";
static const char __pyx_k__181[] = "\357\274\276";
static const char __pyx_k__182[] = "^";
static const char __pyx_k__184[] = "\357\274\277";
static const char __pyx_k__185[] = "_";
static const char __pyx_k__187[] = "\342\200\230";
static const char __pyx_k__188[] = "`";
static const char __pyx_k__190[] = "\357\275\233";
static const char __pyx_k__191[] = "{";
  static const char __pyx_k__193[] = "\357\275\234";
  static const char __pyx_k__194[] = "|";
  static const char __pyx_k__196[] = "\357\275\235";
static const char __pyx_k__197[] = "}";
static const char __pyx_k__200[] = "\357\275\261";
static const char __pyx_k__201[] = "\343\202\242";
static const char __pyx_k__203[] = "\357\275\262";
static const char __pyx_k__204[] = "\343\202\244";
static const char __pyx_k__206[] = "\357\275\263";
static const char __pyx_k__207[] = "\343\202\246";
static const char __pyx_k__209[] = "\357\275\264";
static const char __pyx_k__210[] = "\343\202\250";
static const char __pyx_k__212[] = "\357\275\265";
static const char __pyx_k__213[] = "\343\202\252";
static const char __pyx_k__215[] = "\357\275\266";
static const char __pyx_k__216[] = "\343\202\253";
static const char __pyx_k__218[] = "\357\275\267";
static const char __pyx_k__219[] = "\343\202\255";
static const char __pyx_k__221[] = "\357\275\270";
static const char __pyx_k__222[] = "\343\202\257";
static const char __pyx_k__224[] = "\357\275\271";
static const char __pyx_k__225[] = "\343\202\261";
static const char __pyx_k__227[] = "\357\275\272";
static const char __pyx_k__228[] = "\343\202\263";
static const char __pyx_k__230[] = "\357\275\273";
static const char __pyx_k__231[] = "\343\202\265";
static const char __pyx_k__233[] = "\357\275\274";
static const char __pyx_k__234[] = "\343\202\267";
static const char __pyx_k__236[] = "\357\275\275";
static const char __pyx_k__237[] = "\343\202\271";
static const char __pyx_k__239[] = "\357\275\276";
static const char __pyx_k__240[] = "\343\202\273";
static const char __pyx_k__242[] = "\357\275\277";
static const char __pyx_k__243[] = "\343\202\275";
static const char __pyx_k__245[] = "\357\276\200";
static const char __pyx_k__246[] = "\343\202\277";
static const char __pyx_k__248[] = "\357\276\201";
static const char __pyx_k__249[] = "\343\203\201";
static const char __pyx_k__251[] = "\357\276\202";
static const char __pyx_k__252[] = "\343\203\204";
static const char __pyx_k__254[] = "\357\276\203";
static const char __pyx_k__255[] = "\343\203\206";
static const char __pyx_k__257[] = "\357\276\204";
static const char __pyx_k__258[] = "\343\203\210";
static const char __pyx_k__260[] = "\357\276\205";
static const char __pyx_k__261[] = "\343\203\212";
static const char __pyx_k__263[] = "\357\276\206";
static const char __pyx_k__264[] = "\343\203\213";
static const char __pyx_k__266[] = "\357\276\207";
static const char __pyx_k__267[] = "\343\203\214";
static const char __pyx_k__269[] = "\357\276\210";
static const char __pyx_k__270[] = "\343\203\215";
static const char __pyx_k__272[] = "\357\276\211";
static const char __pyx_k__273[] = "\343\203\216";
static const char __pyx_k__275[] = "\357\276\212";
static const char __pyx_k__276[] = "\343\203\217";
static const char __pyx_k__278[] = "\357\276\213";
static const char __pyx_k__279[] = "\343\203\222";
static const char __pyx_k__281[] = "\357\276\214";
static const char __pyx_k__282[] = "\343\203\225";
static const char __pyx_k__284[] = "\357\276\215";
static const char __pyx_k__285[] = "\343\203\230";
static const char __pyx_k__287[] = "\357\276\216";
static const char __pyx_k__288[] = "\343\203\233";
static const char __pyx_k__290[] = "\357\276\217";
static const char __pyx_k__291[] = "\343\203\236";
static const char __pyx_k__293[] = "\357\276\220";
static const char __pyx_k__294[] = "\343\203\237";
static const char __pyx_k__296[] = "\357\276\221";
static const char __pyx_k__297[] = "\343\203\240";
static const char __pyx_k__299[] = "\357\276\222";
static const char __pyx_k__300[] = "\343\203\241";
static const char __pyx_k__302[] = "\357\276\223";
static const char __pyx_k__303[] = "\343\203\242";
static const char __pyx_k__305[] = "\357\276\224";
static const char __pyx_k__306[] = "\343\203\244";
static const char __pyx_k__308[] = "\357\276\225";
static const char __pyx_k__309[] = "\343\203\246";
static const char __pyx_k__311[] = "\357\276\226";
static const char __pyx_k__312[] = "\343\203\250";
static const char __pyx_k__314[] = "\357\276\227";
static const char __pyx_k__315[] = "\343\203\251";
static const char __pyx_k__317[] = "\357\276\230";
static const char __pyx_k__318[] = "\343\203\252";
static const char __pyx_k__320[] = "\357\276\231";
static const char __pyx_k__321[] = "\343\203\253";
static const char __pyx_k__323[] = "\357\276\232";
static const char __pyx_k__324[] = "\343\203\254";
static const char __pyx_k__326[] = "\357\276\233";
static const char __pyx_k__327[] = "\343\203\255";
static const char __pyx_k__329[] = "\357\276\234";
static const char __pyx_k__330[] = "\343\203\257";
static const char __pyx_k__332[] = "\357\275\246";
static const char __pyx_k__333[] = "\343\203\262";
static const char __pyx_k__335[] = "\357\276\235";
static const char __pyx_k__336[] = "\343\203\263";
static const char __pyx_k__338[] = "\357\275\247";
static const char __pyx_k__339[] = "\343\202\241";
static const char __pyx_k__341[] = "\357\275\250";
static const char __pyx_k__342[] = "\343\202\243";
static const char __pyx_k__344[] = "\357\275\251";
static const char __pyx_k__345[] = "\343\202\245";
static const char __pyx_k__347[] = "\357\275\252";
static const char __pyx_k__348[] = "\343\202\247";
static const char __pyx_k__350[] = "\357\275\253";
static const char __pyx_k__351[] = "\343\202\251";
static const char __pyx_k__353[] = "\357\275\257";
static const char __pyx_k__354[] = "\343\203\203";
static const char __pyx_k__356[] = "\357\275\254";
static const char __pyx_k__357[] = "\343\203\243";
static const char __pyx_k__359[] = "\357\275\255";
static const char __pyx_k__360[] = "\343\203\245";
static const char __pyx_k__362[] = "\357\275\256";
static const char __pyx_k__363[] = "\343\203\247";
static const char __pyx_k__365[] = "\357\275\241";
static const char __pyx_k__366[] = "\343\200\202";
static const char __pyx_k__368[] = "\357\275\244";
static const char __pyx_k__369[] = "\343\200\201";
static const char __pyx_k__371[] = "\357\275\245";
static const char __pyx_k__372[] = "\343\203\273";
static const char __pyx_k__374[] = "\343\202\233";
static const char __pyx_k__375[] = "\357\276\236";
static const char __pyx_k__377[] = "\343\202\234";
static const char __pyx_k__378[] = "\357\276\237";
static const char __pyx_k__380[] = "\357\275\242";
static const char __pyx_k__381[] = "\343\200\214";
static const char __pyx_k__383[] = "\357\275\243";
static const char __pyx_k__384[] = "\343\200\215";
static const char __pyx_k__386[] = "\357\275\260";
static const char __pyx_k__387[] = "\343\203\274";
static const char __pyx_k__390[] = "\357\274\220";
static const char __pyx_k__392[] = "\357\274\221";
static const char __pyx_k__394[] = "\357\274\222";
static const char __pyx_k__396[] = "\357\274\223";
static const char __pyx_k__398[] = "\357\274\224";
static const char __pyx_k__400[] = "\357\274\225";
static const char __pyx_k__402[] = "\357\274\226";
static const char __pyx_k__404[] = "\357\274\227";
static const char __pyx_k__406[] = "\357\274\230";
static const char __pyx_k__408[] = "\357\274\231";
static const char __pyx_k__411[] = "\343\202\254";
static const char __pyx_k__413[] = "\343\202\256";
static const char __pyx_k__415[] = "\343\202\260";
static const char __pyx_k__417[] = "\343\202\262";
static const char __pyx_k__419[] = "\343\202\264";
static const char __pyx_k__421[] = "\343\202\266";
static const char __pyx_k__423[] = "\343\202\270";
static const char __pyx_k__425[] = "\343\202\272";
static const char __pyx_k__427[] = "\343\202\274";
static const char __pyx_k__429[] = "\343\202\276";
static const char __pyx_k__431[] = "\343\203\200";
static const char __pyx_k__433[] = "\343\203\202";
static const char __pyx_k__435[] = "\343\203\205";
static const char __pyx_k__437[] = "\343\203\207";
static const char __pyx_k__439[] = "\343\203\211";
static const char __pyx_k__441[] = "\343\203\220";
static const char __pyx_k__443[] = "\343\203\223";
static const char __pyx_k__445[] = "\343\203\226";
static const char __pyx_k__447[] = "\343\203\231";
static const char __pyx_k__449[] = "\343\203\234";
static const char __pyx_k__451[] = "\343\203\264";
static const char __pyx_k__453[] = "\343\201\206";
static const char __pyx_k__454[] = "\343\202\224";
static const char __pyx_k__457[] = "\343\203\221";
static const char __pyx_k__459[] = "\343\203\224";
static const char __pyx_k__461[] = "\343\203\227";
static const char __pyx_k__463[] = "\343\203\232";
static const char __pyx_k__465[] = "\343\203\235";
static const char __pyx_k__467[] = "\343\201\257";
static const char __pyx_k__468[] = "\343\201\261";
static const char __pyx_k__470[] = "\343\201\262";
static const char __pyx_k__471[] = "\343\201\264";
static const char __pyx_k__473[] = "\343\201\265";
static const char __pyx_k__474[] = "\343\201\267";
static const char __pyx_k__476[] = "\343\201\270";
static const char __pyx_k__477[] = "\343\201\272";
static const char __pyx_k__479[] = "\343\201\273";
static const char __pyx_k__480[] = "\343\201\275";
static const char __pyx_k__483[] = "\313\227";
static const char __pyx_k__484[] = "\326\212";
static const char __pyx_k__485[] = "\342\200\220";
static const char __pyx_k__486[] = "\342\200\221";
static const char __pyx_k__487[] = "\342\200\222";
static const char __pyx_k__488[] = "\342\200\223";
static const char __pyx_k__489[] = "\342\201\203";
static const char __pyx_k__490[] = "\342\201\273";
static const char __pyx_k__491[] = "\342\202\213";
static const char __pyx_k__493[] = "\357\271\243";
static const char __pyx_k__494[] = "\357\274\215";
static const char __pyx_k__495[] = "\342\200\224";
static const char __pyx_k__496[] = "\342\200\225";
static const char __pyx_k__497[] = "\342\224\200";
static const char __pyx_k__498[] = "\342\224\201";
static const char __pyx_k__500[] = "~";
static const char __pyx_k__501[] = "\342\210\274";
static const char __pyx_k__502[] = "\342\210\276";
static const char __pyx_k__503[] = "\343\200\234";
static const char __pyx_k__504[] = "\343\200\260";
static const char __pyx_k__505[] = "\357\275\236";
static const char __pyx_k__507[] = " ";
static const char __pyx_k__508[] = "\343\200\200";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_text[] = "text";
static const char __pyx_k_ASCII[] = "ASCII";
static const char __pyx_k_DIGIT[] = "DIGIT";
static const char __pyx_k_SPACE[] = "SPACE";
static const char __pyx_k_after[] = "after";
static const char __pyx_k_chain[] = "chain";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_TILDES[] = "TILDES";
static const char __pyx_k_before[] = "before";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_repeat[] = "repeat";
static const char __pyx_k_unichr[] = "unichr";
static const char __pyx_k_HIPHENS[] = "HIPHENS";
static const char __pyx_k_VERSION[] = "VERSION";
static const char __pyx_k_version[] = "__version__";
static const char __pyx_k_CHOONPUS[] = "CHOONPUS";
static const char __pyx_k_KANA_TEN[] = "KANA_TEN";
static const char __pyx_k_builtins[] = "__builtins__";
static const char __pyx_k_chr_func[] = "chr_func";
static const char __pyx_k_KANA_MARU[] = "KANA_MARU";
static const char __pyx_k_itertools[] = "itertools";
static const char __pyx_k_char_codes[] = "char_codes";
static const char __pyx_k_remove_space[] = "remove_space";
static const char __pyx_k_version_info[] = "version_info";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static PyObject *__pyx_kp_u_0;
static PyObject *__pyx_kp_u_0_3;
static PyObject *__pyx_kp_u_1;
static PyObject *__pyx_kp_u_2;
static PyObject *__pyx_kp_u_3;
static PyObject *__pyx_kp_u_4;
static PyObject *__pyx_kp_u_5;
static PyObject *__pyx_kp_u_6;
static PyObject *__pyx_kp_u_7;
static PyObject *__pyx_kp_u_8;
static PyObject *__pyx_kp_u_9;
static PyObject *__pyx_n_u_A;
static PyObject *__pyx_n_s_ASCII;
static PyObject *__pyx_n_u_B;
static PyObject *__pyx_n_u_C;
static PyObject *__pyx_n_s_CHOONPUS;
static PyObject *__pyx_n_u_D;
static PyObject *__pyx_n_s_DIGIT;
static PyObject *__pyx_n_u_E;
static PyObject *__pyx_n_u_F;
static PyObject *__pyx_n_u_G;
static PyObject *__pyx_n_u_H;
static PyObject *__pyx_n_s_HIPHENS;
static PyObject *__pyx_n_u_I;
static PyObject *__pyx_n_u_J;
static PyObject *__pyx_n_u_K;
static PyObject *__pyx_n_s_KANA;
static PyObject *__pyx_n_s_KANA_MARU;
static PyObject *__pyx_n_s_KANA_TEN;
static PyObject *__pyx_n_u_L;
static PyObject *__pyx_n_u_M;
static PyObject *__pyx_n_u_N;
static PyObject *__pyx_n_u_O;
static PyObject *__pyx_n_u_P;
static PyObject *__pyx_n_u_Q;
static PyObject *__pyx_n_u_R;
static PyObject *__pyx_n_u_S;
static PyObject *__pyx_n_s_SPACE;
static PyObject *__pyx_n_u_T;
static PyObject *__pyx_n_s_TILDES;
static PyObject *__pyx_n_u_U;
static PyObject *__pyx_n_u_V;
static PyObject *__pyx_n_s_VERSION;
static PyObject *__pyx_n_u_W;
static PyObject *__pyx_n_u_X;
static PyObject *__pyx_n_u_Y;
static PyObject *__pyx_n_u_Z;
static PyObject *__pyx_n_u__10;
static PyObject *__pyx_n_u__100;
static PyObject *__pyx_n_u__102;
static PyObject *__pyx_n_u__104;
static PyObject *__pyx_kp_u__106;
static PyObject *__pyx_kp_u__107;
static PyObject *__pyx_kp_u__109;
static PyObject *__pyx_kp_u__110;
static PyObject *__pyx_kp_u__112;
static PyObject *__pyx_kp_u__113;
static PyObject *__pyx_kp_u__115;
static PyObject *__pyx_kp_u__116;
static PyObject *__pyx_kp_u__118;
static PyObject *__pyx_kp_u__119;
static PyObject *__pyx_n_u__12;
static PyObject *__pyx_kp_u__121;
static PyObject *__pyx_kp_u__122;
static PyObject *__pyx_kp_u__124;
static PyObject *__pyx_kp_u__125;
static PyObject *__pyx_kp_u__127;
static PyObject *__pyx_kp_u__128;
static PyObject *__pyx_kp_u__130;
static PyObject *__pyx_kp_u__131;
static PyObject *__pyx_kp_u__133;
static PyObject *__pyx_kp_u__134;
static PyObject *__pyx_kp_u__136;
static PyObject *__pyx_kp_u__137;
static PyObject *__pyx_kp_u__139;
static PyObject *__pyx_n_u__14;
static PyObject *__pyx_kp_u__140;
static PyObject *__pyx_kp_u__142;
static PyObject *__pyx_kp_u__143;
static PyObject *__pyx_kp_u__145;
static PyObject *__pyx_kp_u__146;
static PyObject *__pyx_kp_u__148;
static PyObject *__pyx_kp_u__149;
static PyObject *__pyx_kp_u__151;
static PyObject *__pyx_kp_u__152;
static PyObject *__pyx_kp_u__154;
static PyObject *__pyx_kp_u__155;
static PyObject *__pyx_kp_u__157;
static PyObject *__pyx_kp_u__158;
static PyObject *__pyx_n_u__16;
static PyObject *__pyx_kp_u__160;
static PyObject *__pyx_kp_u__161;
static PyObject *__pyx_kp_u__163;
static PyObject *__pyx_kp_u__164;
static PyObject *__pyx_kp_u__166;
static PyObject *__pyx_kp_u__167;
static PyObject *__pyx_kp_u__169;
static PyObject *__pyx_kp_u__170;
static PyObject *__pyx_kp_u__172;
static PyObject *__pyx_kp_u__173;
static PyObject *__pyx_kp_u__175;
static PyObject *__pyx_kp_u__176;
static PyObject *__pyx_kp_u__178;
static PyObject *__pyx_kp_u__179;
static PyObject *__pyx_n_u__18;
static PyObject *__pyx_kp_u__181;
static PyObject *__pyx_kp_u__182;
static PyObject *__pyx_kp_u__184;
static PyObject *__pyx_n_u__185;
static PyObject *__pyx_kp_u__187;
static PyObject *__pyx_kp_u__188;
static PyObject *__pyx_kp_u__190;
static PyObject *__pyx_kp_u__191;
static PyObject *__pyx_kp_u__193;
static PyObject *__pyx_kp_u__194;
static PyObject *__pyx_kp_u__196;
static PyObject *__pyx_kp_u__197;
static PyObject *__pyx_n_u__2;
static PyObject *__pyx_n_u__20;
static PyObject *__pyx_n_u__200;
static PyObject *__pyx_n_u__201;
static PyObject *__pyx_n_u__203;
static PyObject *__pyx_n_u__204;
static PyObject *__pyx_n_u__206;
static PyObject *__pyx_n_u__207;
static PyObject *__pyx_n_u__209;
static PyObject *__pyx_n_u__210;
static PyObject *__pyx_n_u__212;
static PyObject *__pyx_n_u__213;
static PyObject *__pyx_n_u__215;
static PyObject *__pyx_n_u__216;
static PyObject *__pyx_n_u__218;
static PyObject *__pyx_n_u__219;
static PyObject *__pyx_n_u__22;
static PyObject *__pyx_n_u__221;
static PyObject *__pyx_n_u__222;
static PyObject *__pyx_n_u__224;
static PyObject *__pyx_n_u__225;
static PyObject *__pyx_n_u__227;
static PyObject *__pyx_n_u__228;
static PyObject *__pyx_n_u__230;
static PyObject *__pyx_n_u__231;
static PyObject *__pyx_n_u__233;
static PyObject *__pyx_n_u__234;
static PyObject *__pyx_n_u__236;
static PyObject *__pyx_n_u__237;
static PyObject *__pyx_n_u__239;
static PyObject *__pyx_n_u__24;
static PyObject *__pyx_n_u__240;
static PyObject *__pyx_n_u__242;
static PyObject *__pyx_n_u__243;
static PyObject *__pyx_n_u__245;
static PyObject *__pyx_n_u__246;
static PyObject *__pyx_n_u__248;
static PyObject *__pyx_n_u__249;
static PyObject *__pyx_n_u__251;
static PyObject *__pyx_n_u__252;
static PyObject *__pyx_n_u__254;
static PyObject *__pyx_n_u__255;
static PyObject *__pyx_n_u__257;
static PyObject *__pyx_n_u__258;
static PyObject *__pyx_n_u__26;
static PyObject *__pyx_n_u__260;
static PyObject *__pyx_n_u__261;
static PyObject *__pyx_n_u__263;
static PyObject *__pyx_n_u__264;
static PyObject *__pyx_n_u__266;
static PyObject *__pyx_n_u__267;
static PyObject *__pyx_n_u__269;
static PyObject *__pyx_n_u__270;
static PyObject *__pyx_n_u__272;
static PyObject *__pyx_n_u__273;
static PyObject *__pyx_n_u__275;
static PyObject *__pyx_n_u__276;
static PyObject *__pyx_n_u__278;
static PyObject *__pyx_n_u__279;
static PyObject *__pyx_n_u__28;
static PyObject *__pyx_n_u__281;
static PyObject *__pyx_n_u__282;
static PyObject *__pyx_n_u__284;
static PyObject *__pyx_n_u__285;
static PyObject *__pyx_n_u__287;
static PyObject *__pyx_n_u__288;
static PyObject *__pyx_n_u__290;
static PyObject *__pyx_n_u__291;
static PyObject *__pyx_n_u__293;
static PyObject *__pyx_n_u__294;
static PyObject *__pyx_n_u__296;
static PyObject *__pyx_n_u__297;
static PyObject *__pyx_n_u__299;
static PyObject *__pyx_n_u__30;
static PyObject *__pyx_n_u__300;
static PyObject *__pyx_n_u__302;
static PyObject *__pyx_n_u__303;
static PyObject *__pyx_n_u__305;
static PyObject *__pyx_n_u__306;
static PyObject *__pyx_n_u__308;
static PyObject *__pyx_n_u__309;
static PyObject *__pyx_n_u__311;
static PyObject *__pyx_n_u__312;
static PyObject *__pyx_n_u__314;
static PyObject *__pyx_n_u__315;
static PyObject *__pyx_n_u__317;
static PyObject *__pyx_n_u__318;
static PyObject *__pyx_n_u__32;
static PyObject *__pyx_n_u__320;
static PyObject *__pyx_n_u__321;
static PyObject *__pyx_n_u__323;
static PyObject *__pyx_n_u__324;
static PyObject *__pyx_n_u__326;
static PyObject *__pyx_n_u__327;
static PyObject *__pyx_n_u__329;
static PyObject *__pyx_n_u__330;
static PyObject *__pyx_n_u__332;
static PyObject *__pyx_n_u__333;
static PyObject *__pyx_n_u__335;
static PyObject *__pyx_n_u__336;
static PyObject *__pyx_n_u__338;
static PyObject *__pyx_n_u__339;
static PyObject *__pyx_n_u__34;
static PyObject *__pyx_n_u__341;
static PyObject *__pyx_n_u__342;
static PyObject *__pyx_n_u__344;
static PyObject *__pyx_n_u__345;
static PyObject *__pyx_n_u__347;
static PyObject *__pyx_n_u__348;
static PyObject *__pyx_n_u__350;
static PyObject *__pyx_n_u__351;
static PyObject *__pyx_n_u__353;
static PyObject *__pyx_n_u__354;
static PyObject *__pyx_n_u__356;
static PyObject *__pyx_n_u__357;
static PyObject *__pyx_n_u__359;
static PyObject *__pyx_n_u__36;
static PyObject *__pyx_n_u__360;
static PyObject *__pyx_n_u__362;
static PyObject *__pyx_n_u__363;
static PyObject *__pyx_kp_u__365;
static PyObject *__pyx_kp_u__366;
static PyObject *__pyx_kp_u__368;
static PyObject *__pyx_kp_u__369;
static PyObject *__pyx_kp_u__371;
static PyObject *__pyx_kp_u__372;
static PyObject *__pyx_kp_u__374;
static PyObject *__pyx_n_u__375;
static PyObject *__pyx_kp_u__377;
static PyObject *__pyx_n_u__378;
static PyObject *__pyx_n_u__38;
static PyObject *__pyx_kp_u__380;
static PyObject *__pyx_kp_u__381;
static PyObject *__pyx_kp_u__383;
static PyObject *__pyx_kp_u__384;
static PyObject *__pyx_n_u__386;
static PyObject *__pyx_n_u__387;
static PyObject *__pyx_n_u__390;
static PyObject *__pyx_n_u__392;
static PyObject *__pyx_n_u__394;
static PyObject *__pyx_n_u__396;
static PyObject *__pyx_n_u__398;
static PyObject *__pyx_n_u__4;
static PyObject *__pyx_n_u__40;
static PyObject *__pyx_n_u__400;
static PyObject *__pyx_n_u__402;
static PyObject *__pyx_n_u__404;
static PyObject *__pyx_n_u__406;
static PyObject *__pyx_n_u__408;
static PyObject *__pyx_n_u__411;
static PyObject *__pyx_n_u__413;
static PyObject *__pyx_n_u__415;
static PyObject *__pyx_n_u__417;
static PyObject *__pyx_n_u__419;
static PyObject *__pyx_n_u__42;
static PyObject *__pyx_n_u__421;
static PyObject *__pyx_n_u__423;
static PyObject *__pyx_n_u__425;
static PyObject *__pyx_n_u__427;
static PyObject *__pyx_n_u__429;
static PyObject *__pyx_n_u__431;
static PyObject *__pyx_n_u__433;
static PyObject *__pyx_n_u__435;
static PyObject *__pyx_n_u__437;
static PyObject *__pyx_n_u__439;
static PyObject *__pyx_n_u__44;
static PyObject *__pyx_n_u__441;
static PyObject *__pyx_n_u__443;
static PyObject *__pyx_n_u__445;
static PyObject *__pyx_n_u__447;
static PyObject *__pyx_n_u__449;
static PyObject *__pyx_n_u__451;
static PyObject *__pyx_n_u__453;
static PyObject *__pyx_n_u__454;
static PyObject *__pyx_n_u__457;
static PyObject *__pyx_n_u__459;
static PyObject *__pyx_n_u__46;
static PyObject *__pyx_n_u__461;
static PyObject *__pyx_n_u__463;
static PyObject *__pyx_n_u__465;
static PyObject *__pyx_n_u__467;
static PyObject *__pyx_n_u__468;
static PyObject *__pyx_n_u__470;
static PyObject *__pyx_n_u__471;
static PyObject *__pyx_n_u__473;
static PyObject *__pyx_n_u__474;
static PyObject *__pyx_n_u__476;
static PyObject *__pyx_n_u__477;
static PyObject *__pyx_n_u__479;
static PyObject *__pyx_n_u__48;
static PyObject *__pyx_n_u__480;
static PyObject *__pyx_kp_u__483;
static PyObject *__pyx_kp_u__484;
static PyObject *__pyx_kp_u__485;
static PyObject *__pyx_kp_u__486;
static PyObject *__pyx_kp_u__487;
static PyObject *__pyx_kp_u__488;
static PyObject *__pyx_kp_u__489;
static PyObject *__pyx_kp_u__490;
static PyObject *__pyx_kp_u__491;
static PyObject *__pyx_kp_u__493;
static PyObject *__pyx_kp_u__494;
static PyObject *__pyx_kp_u__495;
static PyObject *__pyx_kp_u__496;
static PyObject *__pyx_kp_u__497;
static PyObject *__pyx_kp_u__498;
static PyObject *__pyx_n_u__50;
static PyObject *__pyx_kp_u__500;
static PyObject *__pyx_kp_u__501;
static PyObject *__pyx_kp_u__502;
static PyObject *__pyx_kp_u__503;
static PyObject *__pyx_kp_u__504;
static PyObject *__pyx_kp_u__505;
static PyObject *__pyx_kp_u__507;
static PyObject *__pyx_kp_u__508;
static PyObject *__pyx_n_u__52;
static PyObject *__pyx_n_u__54;
static PyObject *__pyx_n_u__56;
static PyObject *__pyx_n_u__58;
static PyObject *__pyx_n_u__6;
static PyObject *__pyx_n_u__60;
static PyObject *__pyx_n_u__62;
static PyObject *__pyx_n_u__64;
static PyObject *__pyx_n_u__66;
static PyObject *__pyx_n_u__68;
static PyObject *__pyx_n_u__70;
static PyObject *__pyx_n_u__72;
static PyObject *__pyx_n_u__74;
static PyObject *__pyx_n_u__76;
static PyObject *__pyx_n_u__78;
static PyObject *__pyx_n_u__8;
static PyObject *__pyx_n_u__80;
static PyObject *__pyx_n_u__82;
static PyObject *__pyx_n_u__84;
static PyObject *__pyx_n_u__86;
static PyObject *__pyx_n_u__88;
static PyObject *__pyx_n_u__90;
static PyObject *__pyx_n_u__92;
static PyObject *__pyx_n_u__94;
static PyObject *__pyx_n_u__96;
static PyObject *__pyx_n_u__98;
static PyObject *__pyx_n_u_a;
static PyObject *__pyx_n_s_after;
static PyObject *__pyx_n_u_b;
static PyObject *__pyx_n_s_before;
static PyObject *__pyx_n_u_builtins;
static PyObject *__pyx_n_s_c;
static PyObject *__pyx_n_u_c;
static PyObject *__pyx_n_s_chain;
static PyObject *__pyx_n_s_char_codes;
static PyObject *__pyx_n_s_chr;
static PyObject *__pyx_n_s_chr_func;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_u_d;
static PyObject *__pyx_n_u_e;
static PyObject *__pyx_n_u_f;
static PyObject *__pyx_n_u_g;
static PyObject *__pyx_n_u_h;
static PyObject *__pyx_n_u_i;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_itertools;
static PyObject *__pyx_n_u_j;
static PyObject *__pyx_n_u_k;
static PyObject *__pyx_n_u_l;
static PyObject *__pyx_n_u_m;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_map;
static PyObject *__pyx_n_u_n;
static PyObject *__pyx_n_u_o;
static PyObject *__pyx_n_u_p;
static PyObject *__pyx_n_u_q;
static PyObject *__pyx_n_u_r;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_remove_space;
static PyObject *__pyx_n_s_repeat;
static PyObject *__pyx_n_u_s;
static PyObject *__pyx_n_s_sys;
static PyObject *__pyx_n_u_t;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_text;
static PyObject *__pyx_n_u_u;
static PyObject *__pyx_n_s_unichr;
static PyObject *__pyx_n_u_v;
static PyObject *__pyx_n_s_version;
static PyObject *__pyx_n_s_version_info;
static PyObject *__pyx_n_u_w;
static PyObject *__pyx_n_u_x;
static PyObject *__pyx_n_u_y;
static PyObject *__pyx_n_u_z;
static PyObject *__pyx_pf_8neologdn_normalize(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text, int __pyx_v_repeat, int __pyx_v_remove_space); /* proto */
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_3;
static PyObject *__pyx_int_128;
static PyObject *__pyx_int_12289;
static PyObject *__pyx_int_12352;
static PyObject *__pyx_int_12448;
static PyObject *__pyx_int_12544;
static PyObject *__pyx_int_19968;
static PyObject *__pyx_int_40960;
static PyObject *__pyx_int_65280;
static PyObject *__pyx_int_65520;
static PyObject *__pyx_tuple_;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_tuple__7;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__13;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_tuple__17;
static PyObject *__pyx_tuple__19;
static PyObject *__pyx_tuple__21;
static PyObject *__pyx_tuple__23;
static PyObject *__pyx_tuple__25;
static PyObject *__pyx_tuple__27;
static PyObject *__pyx_tuple__29;
static PyObject *__pyx_tuple__31;
static PyObject *__pyx_tuple__33;
static PyObject *__pyx_tuple__35;
static PyObject *__pyx_tuple__37;
static PyObject *__pyx_tuple__39;
static PyObject *__pyx_tuple__41;
static PyObject *__pyx_tuple__43;
static PyObject *__pyx_tuple__45;
static PyObject *__pyx_tuple__47;
static PyObject *__pyx_tuple__49;
static PyObject *__pyx_tuple__51;
static PyObject *__pyx_tuple__53;
static PyObject *__pyx_tuple__55;
static PyObject *__pyx_tuple__57;
static PyObject *__pyx_tuple__59;
static PyObject *__pyx_tuple__61;
static PyObject *__pyx_tuple__63;
static PyObject *__pyx_tuple__65;
static PyObject *__pyx_tuple__67;
static PyObject *__pyx_tuple__69;
static PyObject *__pyx_tuple__71;
static PyObject *__pyx_tuple__73;
static PyObject *__pyx_tuple__75;
static PyObject *__pyx_tuple__77;
static PyObject *__pyx_tuple__79;
static PyObject *__pyx_tuple__81;
static PyObject *__pyx_tuple__83;
static PyObject *__pyx_tuple__85;
static PyObject *__pyx_tuple__87;
static PyObject *__pyx_tuple__89;
static PyObject *__pyx_tuple__91;
static PyObject *__pyx_tuple__93;
static PyObject *__pyx_tuple__95;
static PyObject *__pyx_tuple__97;
static PyObject *__pyx_tuple__99;
static PyObject *__pyx_tuple__101;
static PyObject *__pyx_tuple__103;
static PyObject *__pyx_tuple__105;
static PyObject *__pyx_tuple__108;
static PyObject *__pyx_tuple__111;
static PyObject *__pyx_tuple__114;
static PyObject *__pyx_tuple__117;
static PyObject *__pyx_tuple__120;
static PyObject *__pyx_tuple__123;
static PyObject *__pyx_tuple__126;
static PyObject *__pyx_tuple__129;
static PyObject *__pyx_tuple__132;
static PyObject *__pyx_tuple__135;
static PyObject *__pyx_tuple__138;
static PyObject *__pyx_tuple__141;
static PyObject *__pyx_tuple__144;
static PyObject *__pyx_tuple__147;
static PyObject *__pyx_tuple__150;
static PyObject *__pyx_tuple__153;
static PyObject *__pyx_tuple__156;
static PyObject *__pyx_tuple__159;
static PyObject *__pyx_tuple__162;
static PyObject *__pyx_tuple__165;
static PyObject *__pyx_tuple__168;
static PyObject *__pyx_tuple__171;
static PyObject *__pyx_tuple__174;
static PyObject *__pyx_tuple__177;
static PyObject *__pyx_tuple__180;
static PyObject *__pyx_tuple__183;
static PyObject *__pyx_tuple__186;
static PyObject *__pyx_tuple__189;
static PyObject *__pyx_tuple__192;
static PyObject *__pyx_tuple__195;
static PyObject *__pyx_tuple__198;
static PyObject *__pyx_tuple__199;
static PyObject *__pyx_tuple__202;
static PyObject *__pyx_tuple__205;
static PyObject *__pyx_tuple__208;
static PyObject *__pyx_tuple__211;
static PyObject *__pyx_tuple__214;
static PyObject *__pyx_tuple__217;
static PyObject *__pyx_tuple__220;
static PyObject *__pyx_tuple__223;
static PyObject *__pyx_tuple__226;
static PyObject *__pyx_tuple__229;
static PyObject *__pyx_tuple__232;
static PyObject *__pyx_tuple__235;
static PyObject *__pyx_tuple__238;
static PyObject *__pyx_tuple__241;
static PyObject *__pyx_tuple__244;
static PyObject *__pyx_tuple__247;
static PyObject *__pyx_tuple__250;
static PyObject *__pyx_tuple__253;
static PyObject *__pyx_tuple__256;
static PyObject *__pyx_tuple__259;
static PyObject *__pyx_tuple__262;
static PyObject *__pyx_tuple__265;
static PyObject *__pyx_tuple__268;
static PyObject *__pyx_tuple__271;
static PyObject *__pyx_tuple__274;
static PyObject *__pyx_tuple__277;
static PyObject *__pyx_tuple__280;
static PyObject *__pyx_tuple__283;
static PyObject *__pyx_tuple__286;
static PyObject *__pyx_tuple__289;
static PyObject *__pyx_tuple__292;
static PyObject *__pyx_tuple__295;
static PyObject *__pyx_tuple__298;
static PyObject *__pyx_tuple__301;
static PyObject *__pyx_tuple__304;
static PyObject *__pyx_tuple__307;
static PyObject *__pyx_tuple__310;
static PyObject *__pyx_tuple__313;
static PyObject *__pyx_tuple__316;
static PyObject *__pyx_tuple__319;
static PyObject *__pyx_tuple__322;
static PyObject *__pyx_tuple__325;
static PyObject *__pyx_tuple__328;
static PyObject *__pyx_tuple__331;
static PyObject *__pyx_tuple__334;
static PyObject *__pyx_tuple__337;
static PyObject *__pyx_tuple__340;
static PyObject *__pyx_tuple__343;
static PyObject *__pyx_tuple__346;
static PyObject *__pyx_tuple__349;
static PyObject *__pyx_tuple__352;
static PyObject *__pyx_tuple__355;
static PyObject *__pyx_tuple__358;
static PyObject *__pyx_tuple__361;
static PyObject *__pyx_tuple__364;
static PyObject *__pyx_tuple__367;
static PyObject *__pyx_tuple__370;
static PyObject *__pyx_tuple__373;
static PyObject *__pyx_tuple__376;
static PyObject *__pyx_tuple__379;
static PyObject *__pyx_tuple__382;
static PyObject *__pyx_tuple__385;
static PyObject *__pyx_tuple__388;
static PyObject *__pyx_tuple__389;
static PyObject *__pyx_tuple__391;
static PyObject *__pyx_tuple__393;
static PyObject *__pyx_tuple__395;
static PyObject *__pyx_tuple__397;
static PyObject *__pyx_tuple__399;
static PyObject *__pyx_tuple__401;
static PyObject *__pyx_tuple__403;
static PyObject *__pyx_tuple__405;
static PyObject *__pyx_tuple__407;
static PyObject *__pyx_tuple__409;
static PyObject *__pyx_tuple__410;
static PyObject *__pyx_tuple__412;
static PyObject *__pyx_tuple__414;
static PyObject *__pyx_tuple__416;
static PyObject *__pyx_tuple__418;
static PyObject *__pyx_tuple__420;
static PyObject *__pyx_tuple__422;
static PyObject *__pyx_tuple__424;
static PyObject *__pyx_tuple__426;
static PyObject *__pyx_tuple__428;
static PyObject *__pyx_tuple__430;
static PyObject *__pyx_tuple__432;
static PyObject *__pyx_tuple__434;
static PyObject *__pyx_tuple__436;
static PyObject *__pyx_tuple__438;
static PyObject *__pyx_tuple__440;
static PyObject *__pyx_tuple__442;
static PyObject *__pyx_tuple__444;
static PyObject *__pyx_tuple__446;
static PyObject *__pyx_tuple__448;
static PyObject *__pyx_tuple__450;
static PyObject *__pyx_tuple__452;
static PyObject *__pyx_tuple__455;
static PyObject *__pyx_tuple__456;
static PyObject *__pyx_tuple__458;
static PyObject *__pyx_tuple__460;
static PyObject *__pyx_tuple__462;
static PyObject *__pyx_tuple__464;
static PyObject *__pyx_tuple__466;
static PyObject *__pyx_tuple__469;
static PyObject *__pyx_tuple__472;
static PyObject *__pyx_tuple__475;
static PyObject *__pyx_tuple__478;
static PyObject *__pyx_tuple__481;
static PyObject *__pyx_tuple__482;
static PyObject *__pyx_tuple__492;
static PyObject *__pyx_tuple__499;
static PyObject *__pyx_tuple__506;
static PyObject *__pyx_tuple__509;
static PyObject *__pyx_tuple__510;
static PyObject *__pyx_tuple__511;
static PyObject *__pyx_tuple__512;
static PyObject *__pyx_tuple__513;
static PyObject *__pyx_tuple__514;
static PyObject *__pyx_tuple__515;
static PyObject *__pyx_tuple__516;

/* "neologdn.pyx":105
 * 
 * 
 * cpdef unicode normalize(unicode text, int repeat=0, bint remove_space=True):             # <<<<<<<<<<<<<<
 *     cdef Py_UNICODE *buf = <Py_UNICODE *>malloc(sizeof(Py_UNICODE) * (len(text) + 1))
 * 
 */

static PyObject *__pyx_pw_8neologdn_1normalize(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_8neologdn_normalize(PyObject *__pyx_v_text, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_8neologdn_normalize *__pyx_optional_args) {
  int __pyx_v_repeat = ((int)0);
  int __pyx_v_remove_space = ((int)1);
  Py_UNICODE *__pyx_v_buf;
  Py_UNICODE __pyx_v_c;
  Py_UNICODE __pyx_v_prev;
  int __pyx_v_pos;
  int __pyx_v_lattin_space;
  int __pyx_v_repeat_count;
  PyObject *__pyx_v_ret = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  void *__pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_t_11;
  __Pyx_RefNannySetupContext("normalize", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_repeat = __pyx_optional_args->repeat;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_remove_space = __pyx_optional_args->remove_space;
      }
    }
  }

  /* "neologdn.pyx":106
 * 
 * cpdef unicode normalize(unicode text, int repeat=0, bint remove_space=True):
 *     cdef Py_UNICODE *buf = <Py_UNICODE *>malloc(sizeof(Py_UNICODE) * (len(text) + 1))             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_UNICODE c, prev = '\0'
 */
  if (unlikely(__pyx_v_text == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 106, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_text); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 106, __pyx_L1_error)
  __pyx_v_buf = ((Py_UNICODE *)malloc(((sizeof(Py_UNICODE)) * (__pyx_t_1 + 1))));

  /* "neologdn.pyx":108
 *     cdef Py_UNICODE *buf = <Py_UNICODE *>malloc(sizeof(Py_UNICODE) * (len(text) + 1))
 * 
 *     cdef Py_UNICODE c, prev = '\0'             # <<<<<<<<<<<<<<
 *     cdef int pos = 0
 *     cdef bint lattin_space = False
 */
  __pyx_v_prev = 0;

  /* "neologdn.pyx":109
 * 
 *     cdef Py_UNICODE c, prev = '\0'
 *     cdef int pos = 0             # <<<<<<<<<<<<<<
 *     cdef bint lattin_space = False
 *     cdef int repeat_count = 1
 */
  __pyx_v_pos = 0;

  /* "neologdn.pyx":110
 *     cdef Py_UNICODE c, prev = '\0'
 *     cdef int pos = 0
 *     cdef bint lattin_space = False             # <<<<<<<<<<<<<<
 *     cdef int repeat_count = 1
 * 
 */
  __pyx_v_lattin_space = 0;

  /* "neologdn.pyx":111
 *     cdef int pos = 0
 *     cdef bint lattin_space = False
 *     cdef int repeat_count = 1             # <<<<<<<<<<<<<<
 * 
 *     for c in text:
 */
  __pyx_v_repeat_count = 1;

  /* "neologdn.pyx":113
 *     cdef int repeat_count = 1
 * 
 *     for c in text:             # <<<<<<<<<<<<<<
 *         if c in SPACE:
 *             c = ' '
 */
  if (unlikely(__pyx_v_text == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' is not iterable");
    __PYX_ERR(0, 113, __pyx_L1_error)
  }
  __Pyx_INCREF(__pyx_v_text);
  __pyx_t_2 = __pyx_v_text;
  __pyx_t_6 = __Pyx_init_unicode_iteration(__pyx_t_2, (&__pyx_t_3), (&__pyx_t_4), (&__pyx_t_5)); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 113, __pyx_L1_error)
  for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_3; __pyx_t_7++) {
    __pyx_t_1 = __pyx_t_7;
    __pyx_v_c = __Pyx_PyUnicode_READ(__pyx_t_5, __pyx_t_4, __pyx_t_1);

    /* "neologdn.pyx":114
 * 
 *     for c in text:
 *         if c in SPACE:             # <<<<<<<<<<<<<<
 *             c = ' '
 *             if (prev == ' ' or blocks.count(prev)) and remove_space:
 */
    __pyx_t_8 = PyUnicode_FromOrdinal(__pyx_v_c); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_SPACE); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = (__Pyx_PySequence_ContainsTF(__pyx_t_8, __pyx_t_9, Py_EQ)); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 114, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_11 = (__pyx_t_10 != 0);
    if (__pyx_t_11) {

      /* "neologdn.pyx":115
 *     for c in text:
 *         if c in SPACE:
 *             c = ' '             # <<<<<<<<<<<<<<
 *             if (prev == ' ' or blocks.count(prev)) and remove_space:
 *                 continue
 */
      __pyx_v_c = 32;

      /* "neologdn.pyx":116
 *         if c in SPACE:
 *             c = ' '
 *             if (prev == ' ' or blocks.count(prev)) and remove_space:             # <<<<<<<<<<<<<<
 *                 continue
 *             elif prev != '*' and pos > 0 and basic_latin.count(prev):
 */
      __pyx_t_10 = ((__pyx_v_prev == 32) != 0);
      if (!__pyx_t_10) {
      } else {
        goto __pyx_L8_next_and;
      }
      __pyx_t_10 = (__pyx_v_8neologdn_blocks.count(__pyx_v_prev) != 0);
      if (__pyx_t_10) {
      } else {
        __pyx_t_11 = __pyx_t_10;
        goto __pyx_L7_bool_binop_done;
      }
      __pyx_L8_next_and:;
      __pyx_t_10 = (__pyx_v_remove_space != 0);
      __pyx_t_11 = __pyx_t_10;
      __pyx_L7_bool_binop_done:;
      if (__pyx_t_11) {

        /* "neologdn.pyx":117
 *             c = ' '
 *             if (prev == ' ' or blocks.count(prev)) and remove_space:
 *                 continue             # <<<<<<<<<<<<<<
 *             elif prev != '*' and pos > 0 and basic_latin.count(prev):
 *                 lattin_space = True
 */
        goto __pyx_L3_continue;

        /* "neologdn.pyx":116
 *         if c in SPACE:
 *             c = ' '
 *             if (prev == ' ' or blocks.count(prev)) and remove_space:             # <<<<<<<<<<<<<<
 *                 continue
 *             elif prev != '*' and pos > 0 and basic_latin.count(prev):
 */
      }

      /* "neologdn.pyx":118
 *             if (prev == ' ' or blocks.count(prev)) and remove_space:
 *                 continue
 *             elif prev != '*' and pos > 0 and basic_latin.count(prev):             # <<<<<<<<<<<<<<
 *                 lattin_space = True
 *                 buf[pos] = c
 */
      __pyx_t_10 = ((__pyx_v_prev != 42) != 0);
      if (__pyx_t_10) {
      } else {
        __pyx_t_11 = __pyx_t_10;
        goto __pyx_L10_bool_binop_done;
      }
      __pyx_t_10 = ((__pyx_v_pos > 0) != 0);
      if (__pyx_t_10) {
      } else {
        __pyx_t_11 = __pyx_t_10;
        goto __pyx_L10_bool_binop_done;
      }
      __pyx_t_10 = (__pyx_v_8neologdn_basic_latin.count(__pyx_v_prev) != 0);
      __pyx_t_11 = __pyx_t_10;
      __pyx_L10_bool_binop_done:;
      if (__pyx_t_11) {

        /* "neologdn.pyx":119
 *                 continue
 *             elif prev != '*' and pos > 0 and basic_latin.count(prev):
 *                 lattin_space = True             # <<<<<<<<<<<<<<
 *                 buf[pos] = c
 *             elif remove_space:
 */
        __pyx_v_lattin_space = 1;

        /* "neologdn.pyx":120
 *             elif prev != '*' and pos > 0 and basic_latin.count(prev):
 *                 lattin_space = True
 *                 buf[pos] = c             # <<<<<<<<<<<<<<
 *             elif remove_space:
 *                 pos -= 1
 */
        (__pyx_v_buf[__pyx_v_pos]) = __pyx_v_c;

        /* "neologdn.pyx":118
 *             if (prev == ' ' or blocks.count(prev)) and remove_space:
 *                 continue
 *             elif prev != '*' and pos > 0 and basic_latin.count(prev):             # <<<<<<<<<<<<<<
 *                 lattin_space = True
 *                 buf[pos] = c
 */
        goto __pyx_L6;
      }

      /* "neologdn.pyx":121
 *                 lattin_space = True
 *                 buf[pos] = c
 *             elif remove_space:             # <<<<<<<<<<<<<<
 *                 pos -= 1
 *             else:
 */
      __pyx_t_11 = (__pyx_v_remove_space != 0);
      if (__pyx_t_11) {

        /* "neologdn.pyx":122
 *                 buf[pos] = c
 *             elif remove_space:
 *                 pos -= 1             # <<<<<<<<<<<<<<
 *             else:
 *                 buf[pos] = c
 */
        __pyx_v_pos = (__pyx_v_pos - 1);

        /* "neologdn.pyx":121
 *                 lattin_space = True
 *                 buf[pos] = c
 *             elif remove_space:             # <<<<<<<<<<<<<<
 *                 pos -= 1
 *             else:
 */
        goto __pyx_L6;
      }

      /* "neologdn.pyx":124
 *                 pos -= 1
 *             else:
 *                 buf[pos] = c             # <<<<<<<<<<<<<<
 *         else:
 *             if c in HIPHENS:
 */
      /*else*/ {
        (__pyx_v_buf[__pyx_v_pos]) = __pyx_v_c;
      }
      __pyx_L6:;

      /* "neologdn.pyx":114
 * 
 *     for c in text:
 *         if c in SPACE:             # <<<<<<<<<<<<<<
 *             c = ' '
 *             if (prev == ' ' or blocks.count(prev)) and remove_space:
 */
      goto __pyx_L5;
    }

    /* "neologdn.pyx":126
 *                 buf[pos] = c
 *         else:
 *             if c in HIPHENS:             # <<<<<<<<<<<<<<
 *                 if prev == '-':
 *                     continue
 */
    /*else*/ {
      __pyx_t_9 = PyUnicode_FromOrdinal(__pyx_v_c); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_HIPHENS); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_11 = (__Pyx_PySequence_ContainsTF(__pyx_t_9, __pyx_t_8, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 126, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_10 = (__pyx_t_11 != 0);
      if (__pyx_t_10) {

        /* "neologdn.pyx":127
 *         else:
 *             if c in HIPHENS:
 *                 if prev == '-':             # <<<<<<<<<<<<<<
 *                     continue
 *                 else:
 */
        __pyx_t_10 = ((__pyx_v_prev == 45) != 0);
        if (__pyx_t_10) {

          /* "neologdn.pyx":128
 *             if c in HIPHENS:
 *                 if prev == '-':
 *                     continue             # <<<<<<<<<<<<<<
 *                 else:
 *                     buf[pos] = c = '-'
 */
          goto __pyx_L3_continue;

          /* "neologdn.pyx":127
 *         else:
 *             if c in HIPHENS:
 *                 if prev == '-':             # <<<<<<<<<<<<<<
 *                     continue
 *                 else:
 */
        }

        /* "neologdn.pyx":130
 *                     continue
 *                 else:
 *                     buf[pos] = c = '-'             # <<<<<<<<<<<<<<
 *             elif c in CHOONPUS:
 *                 if prev == '':
 */
        /*else*/ {
          (__pyx_v_buf[__pyx_v_pos]) = 45;
          __pyx_v_c = 45;
        }

        /* "neologdn.pyx":126
 *                 buf[pos] = c
 *         else:
 *             if c in HIPHENS:             # <<<<<<<<<<<<<<
 *                 if prev == '-':
 *                     continue
 */
        goto __pyx_L13;
      }

      /* "neologdn.pyx":131
 *                 else:
 *                     buf[pos] = c = '-'
 *             elif c in CHOONPUS:             # <<<<<<<<<<<<<<
 *                 if prev == '':
 *                     continue
 */
      __pyx_t_8 = PyUnicode_FromOrdinal(__pyx_v_c); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 131, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_CHOONPUS); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 131, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = (__Pyx_PySequence_ContainsTF(__pyx_t_8, __pyx_t_9, Py_EQ)); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 131, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_11 = (__pyx_t_10 != 0);
      if (__pyx_t_11) {

        /* "neologdn.pyx":132
 *                     buf[pos] = c = '-'
 *             elif c in CHOONPUS:
 *                 if prev == '':             # <<<<<<<<<<<<<<
 *                     continue
 *                 else:
 */
        __pyx_t_11 = ((__pyx_v_prev == 0x30FC) != 0);
        if (__pyx_t_11) {

          /* "neologdn.pyx":133
 *             elif c in CHOONPUS:
 *                 if prev == '':
 *                     continue             # <<<<<<<<<<<<<<
 *                 else:
 *                     buf[pos] = c = ''
 */
          goto __pyx_L3_continue;

          /* "neologdn.pyx":132
 *                     buf[pos] = c = '-'
 *             elif c in CHOONPUS:
 *                 if prev == '':             # <<<<<<<<<<<<<<
 *                     continue
 *                 else:
 */
        }

        /* "neologdn.pyx":135
 *                     continue
 *                 else:
 *                     buf[pos] = c = ''             # <<<<<<<<<<<<<<
 *             elif c in TILDES:
 *                 continue
 */
        /*else*/ {
          (__pyx_v_buf[__pyx_v_pos]) = 0x30FC;
          __pyx_v_c = 0x30FC;
        }

        /* "neologdn.pyx":131
 *                 else:
 *                     buf[pos] = c = '-'
 *             elif c in CHOONPUS:             # <<<<<<<<<<<<<<
 *                 if prev == '':
 *                     continue
 */
        goto __pyx_L13;
      }

      /* "neologdn.pyx":136
 *                 else:
 *                     buf[pos] = c = ''
 *             elif c in TILDES:             # <<<<<<<<<<<<<<
 *                 continue
 *             else:
 */
      __pyx_t_9 = PyUnicode_FromOrdinal(__pyx_v_c); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 136, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_TILDES); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 136, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_11 = (__Pyx_PySequence_ContainsTF(__pyx_t_9, __pyx_t_8, Py_EQ)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 136, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_10 = (__pyx_t_11 != 0);
      if (__pyx_t_10) {

        /* "neologdn.pyx":137
 *                     buf[pos] = c = ''
 *             elif c in TILDES:
 *                 continue             # <<<<<<<<<<<<<<
 *             else:
 *                 if conversion_map.count(c):
 */
        goto __pyx_L3_continue;

        /* "neologdn.pyx":136
 *                 else:
 *                     buf[pos] = c = ''
 *             elif c in TILDES:             # <<<<<<<<<<<<<<
 *                 continue
 *             else:
 */
      }

      /* "neologdn.pyx":139
 *                 continue
 *             else:
 *                 if conversion_map.count(c):             # <<<<<<<<<<<<<<
 *                     c = conversion_map[c]
 *                 if c == '' and kana_ten_map.count(prev):
 */
      /*else*/ {
        __pyx_t_10 = (__pyx_v_8neologdn_conversion_map.count(__pyx_v_c) != 0);
        if (__pyx_t_10) {

          /* "neologdn.pyx":140
 *             else:
 *                 if conversion_map.count(c):
 *                     c = conversion_map[c]             # <<<<<<<<<<<<<<
 *                 if c == '' and kana_ten_map.count(prev):
 *                     pos -= 1
 */
          __pyx_v_c = (__pyx_v_8neologdn_conversion_map[__pyx_v_c]);

          /* "neologdn.pyx":139
 *                 continue
 *             else:
 *                 if conversion_map.count(c):             # <<<<<<<<<<<<<<
 *                     c = conversion_map[c]
 *                 if c == '' and kana_ten_map.count(prev):
 */
        }

        /* "neologdn.pyx":141
 *                 if conversion_map.count(c):
 *                     c = conversion_map[c]
 *                 if c == '' and kana_ten_map.count(prev):             # <<<<<<<<<<<<<<
 *                     pos -= 1
 *                     c = kana_ten_map[prev]
 */
        __pyx_t_11 = ((__pyx_v_c == 0xFF9E) != 0);
        if (__pyx_t_11) {
        } else {
          __pyx_t_10 = __pyx_t_11;
          goto __pyx_L18_bool_binop_done;
        }
        __pyx_t_11 = (__pyx_v_8neologdn_kana_ten_map.count(__pyx_v_prev) != 0);
        __pyx_t_10 = __pyx_t_11;
        __pyx_L18_bool_binop_done:;
        if (__pyx_t_10) {

          /* "neologdn.pyx":142
 *                     c = conversion_map[c]
 *                 if c == '' and kana_ten_map.count(prev):
 *                     pos -= 1             # <<<<<<<<<<<<<<
 *                     c = kana_ten_map[prev]
 *                 elif c == '' and kana_maru_map.count(prev):
 */
          __pyx_v_pos = (__pyx_v_pos - 1);

          /* "neologdn.pyx":143
 *                 if c == '' and kana_ten_map.count(prev):
 *                     pos -= 1
 *                     c = kana_ten_map[prev]             # <<<<<<<<<<<<<<
 *                 elif c == '' and kana_maru_map.count(prev):
 *                     pos -= 1
 */
          __pyx_v_c = (__pyx_v_8neologdn_kana_ten_map[__pyx_v_prev]);

          /* "neologdn.pyx":141
 *                 if conversion_map.count(c):
 *                     c = conversion_map[c]
 *                 if c == '' and kana_ten_map.count(prev):             # <<<<<<<<<<<<<<
 *                     pos -= 1
 *                     c = kana_ten_map[prev]
 */
          goto __pyx_L17;
        }

        /* "neologdn.pyx":144
 *                     pos -= 1
 *                     c = kana_ten_map[prev]
 *                 elif c == '' and kana_maru_map.count(prev):             # <<<<<<<<<<<<<<
 *                     pos -= 1
 *                     c = kana_maru_map[prev]
 */
        __pyx_t_11 = ((__pyx_v_c == 0xFF9F) != 0);
        if (__pyx_t_11) {
        } else {
          __pyx_t_10 = __pyx_t_11;
          goto __pyx_L20_bool_binop_done;
        }
        __pyx_t_11 = (__pyx_v_8neologdn_kana_maru_map.count(__pyx_v_prev) != 0);
        __pyx_t_10 = __pyx_t_11;
        __pyx_L20_bool_binop_done:;
        if (__pyx_t_10) {

          /* "neologdn.pyx":145
 *                     c = kana_ten_map[prev]
 *                 elif c == '' and kana_maru_map.count(prev):
 *                     pos -= 1             # <<<<<<<<<<<<<<
 *                     c = kana_maru_map[prev]
 *                 if lattin_space and blocks.count(c) and remove_space:
 */
          __pyx_v_pos = (__pyx_v_pos - 1);

          /* "neologdn.pyx":146
 *                 elif c == '' and kana_maru_map.count(prev):
 *                     pos -= 1
 *                     c = kana_maru_map[prev]             # <<<<<<<<<<<<<<
 *                 if lattin_space and blocks.count(c) and remove_space:
 *                     pos -= 1
 */
          __pyx_v_c = (__pyx_v_8neologdn_kana_maru_map[__pyx_v_prev]);

          /* "neologdn.pyx":144
 *                     pos -= 1
 *                     c = kana_ten_map[prev]
 *                 elif c == '' and kana_maru_map.count(prev):             # <<<<<<<<<<<<<<
 *                     pos -= 1
 *                     c = kana_maru_map[prev]
 */
        }
        __pyx_L17:;

        /* "neologdn.pyx":147
 *                     pos -= 1
 *                     c = kana_maru_map[prev]
 *                 if lattin_space and blocks.count(c) and remove_space:             # <<<<<<<<<<<<<<
 *                     pos -= 1
 *                 lattin_space = False
 */
        __pyx_t_11 = (__pyx_v_lattin_space != 0);
        if (__pyx_t_11) {
        } else {
          __pyx_t_10 = __pyx_t_11;
          goto __pyx_L23_bool_binop_done;
        }
        __pyx_t_11 = (__pyx_v_8neologdn_blocks.count(__pyx_v_c) != 0);
        if (__pyx_t_11) {
        } else {
          __pyx_t_10 = __pyx_t_11;
          goto __pyx_L23_bool_binop_done;
        }
        __pyx_t_11 = (__pyx_v_remove_space != 0);
        __pyx_t_10 = __pyx_t_11;
        __pyx_L23_bool_binop_done:;
        if (__pyx_t_10) {

          /* "neologdn.pyx":148
 *                     c = kana_maru_map[prev]
 *                 if lattin_space and blocks.count(c) and remove_space:
 *                     pos -= 1             # <<<<<<<<<<<<<<
 *                 lattin_space = False
 *                 if repeat:
 */
          __pyx_v_pos = (__pyx_v_pos - 1);

          /* "neologdn.pyx":147
 *                     pos -= 1
 *                     c = kana_maru_map[prev]
 *                 if lattin_space and blocks.count(c) and remove_space:             # <<<<<<<<<<<<<<
 *                     pos -= 1
 *                 lattin_space = False
 */
        }

        /* "neologdn.pyx":149
 *                 if lattin_space and blocks.count(c) and remove_space:
 *                     pos -= 1
 *                 lattin_space = False             # <<<<<<<<<<<<<<
 *                 if repeat:
 *                     if c == prev:
 */
        __pyx_v_lattin_space = 0;

        /* "neologdn.pyx":150
 *                     pos -= 1
 *                 lattin_space = False
 *                 if repeat:             # <<<<<<<<<<<<<<
 *                     if c == prev:
 *                         if repeat_count >= repeat:
 */
        __pyx_t_10 = (__pyx_v_repeat != 0);
        if (__pyx_t_10) {

          /* "neologdn.pyx":151
 *                 lattin_space = False
 *                 if repeat:
 *                     if c == prev:             # <<<<<<<<<<<<<<
 *                         if repeat_count >= repeat:
 *                             continue
 */
          __pyx_t_10 = ((__pyx_v_c == __pyx_v_prev) != 0);
          if (__pyx_t_10) {

            /* "neologdn.pyx":152
 *                 if repeat:
 *                     if c == prev:
 *                         if repeat_count >= repeat:             # <<<<<<<<<<<<<<
 *                             continue
 *                         repeat_count += 1
 */
            __pyx_t_10 = ((__pyx_v_repeat_count >= __pyx_v_repeat) != 0);
            if (__pyx_t_10) {

              /* "neologdn.pyx":153
 *                     if c == prev:
 *                         if repeat_count >= repeat:
 *                             continue             # <<<<<<<<<<<<<<
 *                         repeat_count += 1
 *                     else:
 */
              goto __pyx_L3_continue;

              /* "neologdn.pyx":152
 *                 if repeat:
 *                     if c == prev:
 *                         if repeat_count >= repeat:             # <<<<<<<<<<<<<<
 *                             continue
 *                         repeat_count += 1
 */
            }

            /* "neologdn.pyx":154
 *                         if repeat_count >= repeat:
 *                             continue
 *                         repeat_count += 1             # <<<<<<<<<<<<<<
 *                     else:
 *                         repeat_count = 1
 */
            __pyx_v_repeat_count = (__pyx_v_repeat_count + 1);

            /* "neologdn.pyx":151
 *                 lattin_space = False
 *                 if repeat:
 *                     if c == prev:             # <<<<<<<<<<<<<<
 *                         if repeat_count >= repeat:
 *                             continue
 */
            goto __pyx_L27;
          }

          /* "neologdn.pyx":156
 *                         repeat_count += 1
 *                     else:
 *                         repeat_count = 1             # <<<<<<<<<<<<<<
 *                 buf[pos] = c
 *         prev = c
 */
          /*else*/ {
            __pyx_v_repeat_count = 1;
          }
          __pyx_L27:;

          /* "neologdn.pyx":150
 *                     pos -= 1
 *                 lattin_space = False
 *                 if repeat:             # <<<<<<<<<<<<<<
 *                     if c == prev:
 *                         if repeat_count >= repeat:
 */
        }

        /* "neologdn.pyx":157
 *                     else:
 *                         repeat_count = 1
 *                 buf[pos] = c             # <<<<<<<<<<<<<<
 *         prev = c
 *         pos += 1
 */
        (__pyx_v_buf[__pyx_v_pos]) = __pyx_v_c;
      }
      __pyx_L13:;
    }
    __pyx_L5:;

    /* "neologdn.pyx":158
 *                         repeat_count = 1
 *                 buf[pos] = c
 *         prev = c             # <<<<<<<<<<<<<<
 *         pos += 1
 * 
 */
    __pyx_v_prev = __pyx_v_c;

    /* "neologdn.pyx":159
 *                 buf[pos] = c
 *         prev = c
 *         pos += 1             # <<<<<<<<<<<<<<
 * 
 *     if buf[pos-1] == ' ':
 */
    __pyx_v_pos = (__pyx_v_pos + 1);
    __pyx_L3_continue:;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "neologdn.pyx":161
 *         pos += 1
 * 
 *     if buf[pos-1] == ' ':             # <<<<<<<<<<<<<<
 *         pos -= 1
 *     buf[pos] = '\0'
 */
  __pyx_t_10 = (((__pyx_v_buf[(__pyx_v_pos - 1)]) == 32) != 0);
  if (__pyx_t_10) {

    /* "neologdn.pyx":162
 * 
 *     if buf[pos-1] == ' ':
 *         pos -= 1             # <<<<<<<<<<<<<<
 *     buf[pos] = '\0'
 * 
 */
    __pyx_v_pos = (__pyx_v_pos - 1);

    /* "neologdn.pyx":161
 *         pos += 1
 * 
 *     if buf[pos-1] == ' ':             # <<<<<<<<<<<<<<
 *         pos -= 1
 *     buf[pos] = '\0'
 */
  }

  /* "neologdn.pyx":163
 *     if buf[pos-1] == ' ':
 *         pos -= 1
 *     buf[pos] = '\0'             # <<<<<<<<<<<<<<
 * 
 *     cdef unicode ret = buf
 */
  (__pyx_v_buf[__pyx_v_pos]) = 0;

  /* "neologdn.pyx":165
 *     buf[pos] = '\0'
 * 
 *     cdef unicode ret = buf             # <<<<<<<<<<<<<<
 *     free(buf)
 *     return ret
 */
  __pyx_t_8 = __Pyx_PyUnicode_FromUnicode(__pyx_v_buf); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_8))||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_8)->tp_name), 0))) __PYX_ERR(0, 165, __pyx_L1_error)
  __pyx_v_ret = ((PyObject*)__pyx_t_8);
  __pyx_t_8 = 0;

  /* "neologdn.pyx":166
 * 
 *     cdef unicode ret = buf
 *     free(buf)             # <<<<<<<<<<<<<<
 *     return ret
 */
  free(__pyx_v_buf);

  /* "neologdn.pyx":167
 *     cdef unicode ret = buf
 *     free(buf)
 *     return ret             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "neologdn.pyx":105
 * 
 * 
 * cpdef unicode normalize(unicode text, int repeat=0, bint remove_space=True):             # <<<<<<<<<<<<<<
 *     cdef Py_UNICODE *buf = <Py_UNICODE *>malloc(sizeof(Py_UNICODE) * (len(text) + 1))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("neologdn.normalize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8neologdn_1normalize(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_8neologdn_1normalize(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_text = 0;
  int __pyx_v_repeat;
  int __pyx_v_remove_space;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("normalize (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_text,&__pyx_n_s_repeat,&__pyx_n_s_remove_space,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_text)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_repeat);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_remove_space);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "normalize") < 0)) __PYX_ERR(0, 105, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_text = ((PyObject*)values[0]);
    if (values[1]) {
      __pyx_v_repeat = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_repeat == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 105, __pyx_L3_error)
    } else {
      __pyx_v_repeat = ((int)0);
    }
    if (values[2]) {
      __pyx_v_remove_space = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_remove_space == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 105, __pyx_L3_error)
    } else {
      __pyx_v_remove_space = ((int)1);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("normalize", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 105, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("neologdn.normalize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_text), (&PyUnicode_Type), 1, "text", 1))) __PYX_ERR(0, 105, __pyx_L1_error)
  __pyx_r = __pyx_pf_8neologdn_normalize(__pyx_self, __pyx_v_text, __pyx_v_repeat, __pyx_v_remove_space);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8neologdn_normalize(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text, int __pyx_v_repeat, int __pyx_v_remove_space) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_8neologdn_normalize __pyx_t_2;
  __Pyx_RefNannySetupContext("normalize", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.repeat = __pyx_v_repeat;
  __pyx_t_2.remove_space = __pyx_v_remove_space;
  __pyx_t_1 = __pyx_f_8neologdn_normalize(__pyx_v_text, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("neologdn.normalize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyMethodDef __pyx_methods[] = {
  {"normalize", (PyCFunction)__pyx_pw_8neologdn_1normalize, METH_VARARGS|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_neologdn(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_neologdn},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "neologdn",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_0, __pyx_k_0, sizeof(__pyx_k_0), 0, 1, 0, 0},
  {&__pyx_kp_u_0_3, __pyx_k_0_3, sizeof(__pyx_k_0_3), 0, 1, 0, 0},
  {&__pyx_kp_u_1, __pyx_k_1, sizeof(__pyx_k_1), 0, 1, 0, 0},
  {&__pyx_kp_u_2, __pyx_k_2, sizeof(__pyx_k_2), 0, 1, 0, 0},
  {&__pyx_kp_u_3, __pyx_k_3, sizeof(__pyx_k_3), 0, 1, 0, 0},
  {&__pyx_kp_u_4, __pyx_k_4, sizeof(__pyx_k_4), 0, 1, 0, 0},
  {&__pyx_kp_u_5, __pyx_k_5, sizeof(__pyx_k_5), 0, 1, 0, 0},
  {&__pyx_kp_u_6, __pyx_k_6, sizeof(__pyx_k_6), 0, 1, 0, 0},
  {&__pyx_kp_u_7, __pyx_k_7, sizeof(__pyx_k_7), 0, 1, 0, 0},
  {&__pyx_kp_u_8, __pyx_k_8, sizeof(__pyx_k_8), 0, 1, 0, 0},
  {&__pyx_kp_u_9, __pyx_k_9, sizeof(__pyx_k_9), 0, 1, 0, 0},
  {&__pyx_n_u_A, __pyx_k_A, sizeof(__pyx_k_A), 0, 1, 0, 1},
  {&__pyx_n_s_ASCII, __pyx_k_ASCII, sizeof(__pyx_k_ASCII), 0, 0, 1, 1},
  {&__pyx_n_u_B, __pyx_k_B, sizeof(__pyx_k_B), 0, 1, 0, 1},
  {&__pyx_n_u_C, __pyx_k_C, sizeof(__pyx_k_C), 0, 1, 0, 1},
  {&__pyx_n_s_CHOONPUS, __pyx_k_CHOONPUS, sizeof(__pyx_k_CHOONPUS), 0, 0, 1, 1},
  {&__pyx_n_u_D, __pyx_k_D, sizeof(__pyx_k_D), 0, 1, 0, 1},
  {&__pyx_n_s_DIGIT, __pyx_k_DIGIT, sizeof(__pyx_k_DIGIT), 0, 0, 1, 1},
  {&__pyx_n_u_E, __pyx_k_E, sizeof(__pyx_k_E), 0, 1, 0, 1},
  {&__pyx_n_u_F, __pyx_k_F, sizeof(__pyx_k_F), 0, 1, 0, 1},
  {&__pyx_n_u_G, __pyx_k_G, sizeof(__pyx_k_G), 0, 1, 0, 1},
  {&__pyx_n_u_H, __pyx_k_H, sizeof(__pyx_k_H), 0, 1, 0, 1},
  {&__pyx_n_s_HIPHENS, __pyx_k_HIPHENS, sizeof(__pyx_k_HIPHENS), 0, 0, 1, 1},
  {&__pyx_n_u_I, __pyx_k_I, sizeof(__pyx_k_I), 0, 1, 0, 1},
  {&__pyx_n_u_J, __pyx_k_J, sizeof(__pyx_k_J), 0, 1, 0, 1},
  {&__pyx_n_u_K, __pyx_k_K, sizeof(__pyx_k_K), 0, 1, 0, 1},
  {&__pyx_n_s_KANA, __pyx_k_KANA, sizeof(__pyx_k_KANA), 0, 0, 1, 1},
  {&__pyx_n_s_KANA_MARU, __pyx_k_KANA_MARU, sizeof(__pyx_k_KANA_MARU), 0, 0, 1, 1},
  {&__pyx_n_s_KANA_TEN, __pyx_k_KANA_TEN, sizeof(__pyx_k_KANA_TEN), 0, 0, 1, 1},
  {&__pyx_n_u_L, __pyx_k_L, sizeof(__pyx_k_L), 0, 1, 0, 1},
  {&__pyx_n_u_M, __pyx_k_M, sizeof(__pyx_k_M), 0, 1, 0, 1},
  {&__pyx_n_u_N, __pyx_k_N, sizeof(__pyx_k_N), 0, 1, 0, 1},
  {&__pyx_n_u_O, __pyx_k_O, sizeof(__pyx_k_O), 0, 1, 0, 1},
  {&__pyx_n_u_P, __pyx_k_P, sizeof(__pyx_k_P), 0, 1, 0, 1},
  {&__pyx_n_u_Q, __pyx_k_Q, sizeof(__pyx_k_Q), 0, 1, 0, 1},
  {&__pyx_n_u_R, __pyx_k_R, sizeof(__pyx_k_R), 0, 1, 0, 1},
  {&__pyx_n_u_S, __pyx_k_S, sizeof(__pyx_k_S), 0, 1, 0, 1},
  {&__pyx_n_s_SPACE, __pyx_k_SPACE, sizeof(__pyx_k_SPACE), 0, 0, 1, 1},
  {&__pyx_n_u_T, __pyx_k_T, sizeof(__pyx_k_T), 0, 1, 0, 1},
  {&__pyx_n_s_TILDES, __pyx_k_TILDES, sizeof(__pyx_k_TILDES), 0, 0, 1, 1},
  {&__pyx_n_u_U, __pyx_k_U, sizeof(__pyx_k_U), 0, 1, 0, 1},
  {&__pyx_n_u_V, __pyx_k_V, sizeof(__pyx_k_V), 0, 1, 0, 1},
  {&__pyx_n_s_VERSION, __pyx_k_VERSION, sizeof(__pyx_k_VERSION), 0, 0, 1, 1},
  {&__pyx_n_u_W, __pyx_k_W, sizeof(__pyx_k_W), 0, 1, 0, 1},
  {&__pyx_n_u_X, __pyx_k_X, sizeof(__pyx_k_X), 0, 1, 0, 1},
  {&__pyx_n_u_Y, __pyx_k_Y, sizeof(__pyx_k_Y), 0, 1, 0, 1},
  {&__pyx_n_u_Z, __pyx_k_Z, sizeof(__pyx_k_Z), 0, 1, 0, 1},
  {&__pyx_n_u__10, __pyx_k__10, sizeof(__pyx_k__10), 0, 1, 0, 1},
  {&__pyx_n_u__100, __pyx_k__100, sizeof(__pyx_k__100), 0, 1, 0, 1},
  {&__pyx_n_u__102, __pyx_k__102, sizeof(__pyx_k__102), 0, 1, 0, 1},
  {&__pyx_n_u__104, __pyx_k__104, sizeof(__pyx_k__104), 0, 1, 0, 1},
  {&__pyx_kp_u__106, __pyx_k__106, sizeof(__pyx_k__106), 0, 1, 0, 0},
  {&__pyx_kp_u__107, __pyx_k__107, sizeof(__pyx_k__107), 0, 1, 0, 0},
  {&__pyx_kp_u__109, __pyx_k__109, sizeof(__pyx_k__109), 0, 1, 0, 0},
  {&__pyx_kp_u__110, __pyx_k__110, sizeof(__pyx_k__110), 0, 1, 0, 0},
  {&__pyx_kp_u__112, __pyx_k__112, sizeof(__pyx_k__112), 0, 1, 0, 0},
  {&__pyx_kp_u__113, __pyx_k__113, sizeof(__pyx_k__113), 0, 1, 0, 0},
  {&__pyx_kp_u__115, __pyx_k__115, sizeof(__pyx_k__115), 0, 1, 0, 0},
  {&__pyx_kp_u__116, __pyx_k__116, sizeof(__pyx_k__116), 0, 1, 0, 0},
  {&__pyx_kp_u__118, __pyx_k__118, sizeof(__pyx_k__118), 0, 1, 0, 0},
  {&__pyx_kp_u__119, __pyx_k__119, sizeof(__pyx_k__119), 0, 1, 0, 0},
  {&__pyx_n_u__12, __pyx_k__12, sizeof(__pyx_k__12), 0, 1, 0, 1},
  {&__pyx_kp_u__121, __pyx_k__121, sizeof(__pyx_k__121), 0, 1, 0, 0},
  {&__pyx_kp_u__122, __pyx_k__122, sizeof(__pyx_k__122), 0, 1, 0, 0},
  {&__pyx_kp_u__124, __pyx_k__124, sizeof(__pyx_k__124), 0, 1, 0, 0},
  {&__pyx_kp_u__125, __pyx_k__125, sizeof(__pyx_k__125), 0, 1, 0, 0},
  {&__pyx_kp_u__127, __pyx_k__127, sizeof(__pyx_k__127), 0, 1, 0, 0},
  {&__pyx_kp_u__128, __pyx_k__128, sizeof(__pyx_k__128), 0, 1, 0, 0},
  {&__pyx_kp_u__130, __pyx_k__130, sizeof(__pyx_k__130), 0, 1, 0, 0},
  {&__pyx_kp_u__131, __pyx_k__131, sizeof(__pyx_k__131), 0, 1, 0, 0},
  {&__pyx_kp_u__133, __pyx_k__133, sizeof(__pyx_k__133), 0, 1, 0, 0},
  {&__pyx_kp_u__134, __pyx_k__134, sizeof(__pyx_k__134), 0, 1, 0, 0},
  {&__pyx_kp_u__136, __pyx_k__136, sizeof(__pyx_k__136), 0, 1, 0, 0},
  {&__pyx_kp_u__137, __pyx_k__137, sizeof(__pyx_k__137), 0, 1, 0, 0},
  {&__pyx_kp_u__139, __pyx_k__139, sizeof(__pyx_k__139), 0, 1, 0, 0},
  {&__pyx_n_u__14, __pyx_k__14, sizeof(__pyx_k__14), 0, 1, 0, 1},
  {&__pyx_kp_u__140, __pyx_k__140, sizeof(__pyx_k__140), 0, 1, 0, 0},
  {&__pyx_kp_u__142, __pyx_k__142, sizeof(__pyx_k__142), 0, 1, 0, 0},
  {&__pyx_kp_u__143, __pyx_k__143, sizeof(__pyx_k__143), 0, 1, 0, 0},
  {&__pyx_kp_u__145, __pyx_k__145, sizeof(__pyx_k__145), 0, 1, 0, 0},
  {&__pyx_kp_u__146, __pyx_k__146, sizeof(__pyx_k__146), 0, 1, 0, 0},
  {&__pyx_kp_u__148, __pyx_k__148, sizeof(__pyx_k__148), 0, 1, 0, 0},
  {&__pyx_kp_u__149, __pyx_k__149, sizeof(__pyx_k__149), 0, 1, 0, 0},
  {&__pyx_kp_u__151, __pyx_k__151, sizeof(__pyx_k__151), 0, 1, 0, 0},
  {&__pyx_kp_u__152, __pyx_k__152, sizeof(__pyx_k__152), 0, 1, 0, 0},
  {&__pyx_kp_u__154, __pyx_k__154, sizeof(__pyx_k__154), 0, 1, 0, 0},
  {&__pyx_kp_u__155, __pyx_k__155, sizeof(__pyx_k__155), 0, 1, 0, 0},
  {&__pyx_kp_u__157, __pyx_k__157, sizeof(__pyx_k__157), 0, 1, 0, 0},
  {&__pyx_kp_u__158, __pyx_k__158, sizeof(__pyx_k__158), 0, 1, 0, 0},
  {&__pyx_n_u__16, __pyx_k__16, sizeof(__pyx_k__16), 0, 1, 0, 1},
  {&__pyx_kp_u__160, __pyx_k__160, sizeof(__pyx_k__160), 0, 1, 0, 0},
  {&__pyx_kp_u__161, __pyx_k__161, sizeof(__pyx_k__161), 0, 1, 0, 0},
  {&__pyx_kp_u__163, __pyx_k__163, sizeof(__pyx_k__163), 0, 1, 0, 0},
  {&__pyx_kp_u__164, __pyx_k__164, sizeof(__pyx_k__164), 0, 1, 0, 0},
  {&__pyx_kp_u__166, __pyx_k__166, sizeof(__pyx_k__166), 0, 1, 0, 0},
  {&__pyx_kp_u__167, __pyx_k__167, sizeof(__pyx_k__167), 0, 1, 0, 0},
  {&__pyx_kp_u__169, __pyx_k__169, sizeof(__pyx_k__169), 0, 1, 0, 0},
  {&__pyx_kp_u__170, __pyx_k__170, sizeof(__pyx_k__170), 0, 1, 0, 0},
  {&__pyx_kp_u__172, __pyx_k__172, sizeof(__pyx_k__172), 0, 1, 0, 0},
  {&__pyx_kp_u__173, __pyx_k__173, sizeof(__pyx_k__173), 0, 1, 0, 0},
  {&__pyx_kp_u__175, __pyx_k__175, sizeof(__pyx_k__175), 0, 1, 0, 0},
  {&__pyx_kp_u__176, __pyx_k__176, sizeof(__pyx_k__176), 0, 1, 0, 0},
  {&__pyx_kp_u__178, __pyx_k__178, sizeof(__pyx_k__178), 0, 1, 0, 0},
  {&__pyx_kp_u__179, __pyx_k__179, sizeof(__pyx_k__179), 0, 1, 0, 0},
  {&__pyx_n_u__18, __pyx_k__18, sizeof(__pyx_k__18), 0, 1, 0, 1},
  {&__pyx_kp_u__181, __pyx_k__181, sizeof(__pyx_k__181), 0, 1, 0, 0},
  {&__pyx_kp_u__182, __pyx_k__182, sizeof(__pyx_k__182), 0, 1, 0, 0},
  {&__pyx_kp_u__184, __pyx_k__184, sizeof(__pyx_k__184), 0, 1, 0, 0},
  {&__pyx_n_u__185, __pyx_k__185, sizeof(__pyx_k__185), 0, 1, 0, 1},
  {&__pyx_kp_u__187, __pyx_k__187, sizeof(__pyx_k__187), 0, 1, 0, 0},
  {&__pyx_kp_u__188, __pyx_k__188, sizeof(__pyx_k__188), 0, 1, 0, 0},
  {&__pyx_kp_u__190, __pyx_k__190, sizeof(__pyx_k__190), 0, 1, 0, 0},
  {&__pyx_kp_u__191, __pyx_k__191, sizeof(__pyx_k__191), 0, 1, 0, 0},
  {&__pyx_kp_u__193, __pyx_k__193, sizeof(__pyx_k__193), 0, 1, 0, 0},
  {&__pyx_kp_u__194, __pyx_k__194, sizeof(__pyx_k__194), 0, 1, 0, 0},
  {&__pyx_kp_u__196, __pyx_k__196, sizeof(__pyx_k__196), 0, 1, 0, 0},
  {&__pyx_kp_u__197, __pyx_k__197, sizeof(__pyx_k__197), 0, 1, 0, 0},
  {&__pyx_n_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 1},
  {&__pyx_n_u__20, __pyx_k__20, sizeof(__pyx_k__20), 0, 1, 0, 1},
  {&__pyx_n_u__200, __pyx_k__200, sizeof(__pyx_k__200), 0, 1, 0, 1},
  {&__pyx_n_u__201, __pyx_k__201, sizeof(__pyx_k__201), 0, 1, 0, 1},
  {&__pyx_n_u__203, __pyx_k__203, sizeof(__pyx_k__203), 0, 1, 0, 1},
  {&__pyx_n_u__204, __pyx_k__204, sizeof(__pyx_k__204), 0, 1, 0, 1},
  {&__pyx_n_u__206, __pyx_k__206, sizeof(__pyx_k__206), 0, 1, 0, 1},
  {&__pyx_n_u__207, __pyx_k__207, sizeof(__pyx_k__207), 0, 1, 0, 1},
  {&__pyx_n_u__209, __pyx_k__209, sizeof(__pyx_k__209), 0, 1, 0, 1},
  {&__pyx_n_u__210, __pyx_k__210, sizeof(__pyx_k__210), 0, 1, 0, 1},
  {&__pyx_n_u__212, __pyx_k__212, sizeof(__pyx_k__212), 0, 1, 0, 1},
  {&__pyx_n_u__213, __pyx_k__213, sizeof(__pyx_k__213), 0, 1, 0, 1},
  {&__pyx_n_u__215, __pyx_k__215, sizeof(__pyx_k__215), 0, 1, 0, 1},
  {&__pyx_n_u__216, __pyx_k__216, sizeof(__pyx_k__216), 0, 1, 0, 1},
  {&__pyx_n_u__218, __pyx_k__218, sizeof(__pyx_k__218), 0, 1, 0, 1},
  {&__pyx_n_u__219, __pyx_k__219, sizeof(__pyx_k__219), 0, 1, 0, 1},
  {&__pyx_n_u__22, __pyx_k__22, sizeof(__pyx_k__22), 0, 1, 0, 1},
  {&__pyx_n_u__221, __pyx_k__221, sizeof(__pyx_k__221), 0, 1, 0, 1},
  {&__pyx_n_u__222, __pyx_k__222, sizeof(__pyx_k__222), 0, 1, 0, 1},
  {&__pyx_n_u__224, __pyx_k__224, sizeof(__pyx_k__224), 0, 1, 0, 1},
  {&__pyx_n_u__225, __pyx_k__225, sizeof(__pyx_k__225), 0, 1, 0, 1},
  {&__pyx_n_u__227, __pyx_k__227, sizeof(__pyx_k__227), 0, 1, 0, 1},
  {&__pyx_n_u__228, __pyx_k__228, sizeof(__pyx_k__228), 0, 1, 0, 1},
  {&__pyx_n_u__230, __pyx_k__230, sizeof(__pyx_k__230), 0, 1, 0, 1},
  {&__pyx_n_u__231, __pyx_k__231, sizeof(__pyx_k__231), 0, 1, 0, 1},
  {&__pyx_n_u__233, __pyx_k__233, sizeof(__pyx_k__233), 0, 1, 0, 1},
  {&__pyx_n_u__234, __pyx_k__234, sizeof(__pyx_k__234), 0, 1, 0, 1},
  {&__pyx_n_u__236, __pyx_k__236, sizeof(__pyx_k__236), 0, 1, 0, 1},
  {&__pyx_n_u__237, __pyx_k__237, sizeof(__pyx_k__237), 0, 1, 0, 1},
  {&__pyx_n_u__239, __pyx_k__239, sizeof(__pyx_k__239), 0, 1, 0, 1},
  {&__pyx_n_u__24, __pyx_k__24, sizeof(__pyx_k__24), 0, 1, 0, 1},
  {&__pyx_n_u__240, __pyx_k__240, sizeof(__pyx_k__240), 0, 1, 0, 1},
  {&__pyx_n_u__242, __pyx_k__242, sizeof(__pyx_k__242), 0, 1, 0, 1},
  {&__pyx_n_u__243, __pyx_k__243, sizeof(__pyx_k__243), 0, 1, 0, 1},
  {&__pyx_n_u__245, __pyx_k__245, sizeof(__pyx_k__245), 0, 1, 0, 1},
  {&__pyx_n_u__246, __pyx_k__246, sizeof(__pyx_k__246), 0, 1, 0, 1},
  {&__pyx_n_u__248, __pyx_k__248, sizeof(__pyx_k__248), 0, 1, 0, 1},
  {&__pyx_n_u__249, __pyx_k__249, sizeof(__pyx_k__249), 0, 1, 0, 1},
  {&__pyx_n_u__251, __pyx_k__251, sizeof(__pyx_k__251), 0, 1, 0, 1},
  {&__pyx_n_u__252, __pyx_k__252, sizeof(__pyx_k__252), 0, 1, 0, 1},
  {&__pyx_n_u__254, __pyx_k__254, sizeof(__pyx_k__254), 0, 1, 0, 1},
  {&__pyx_n_u__255, __pyx_k__255, sizeof(__pyx_k__255), 0, 1, 0, 1},
  {&__pyx_n_u__257, __pyx_k__257, sizeof(__pyx_k__257), 0, 1, 0, 1},
  {&__pyx_n_u__258, __pyx_k__258, sizeof(__pyx_k__258), 0, 1, 0, 1},
  {&__pyx_n_u__26, __pyx_k__26, sizeof(__pyx_k__26), 0, 1, 0, 1},
  {&__pyx_n_u__260, __pyx_k__260, sizeof(__pyx_k__260), 0, 1, 0, 1},
  {&__pyx_n_u__261, __pyx_k__261, sizeof(__pyx_k__261), 0, 1, 0, 1},
  {&__pyx_n_u__263, __pyx_k__263, sizeof(__pyx_k__263), 0, 1, 0, 1},
  {&__pyx_n_u__264, __pyx_k__264, sizeof(__pyx_k__264), 0, 1, 0, 1},
  {&__pyx_n_u__266, __pyx_k__266, sizeof(__pyx_k__266), 0, 1, 0, 1},
  {&__pyx_n_u__267, __pyx_k__267, sizeof(__pyx_k__267), 0, 1, 0, 1},
  {&__pyx_n_u__269, __pyx_k__269, sizeof(__pyx_k__269), 0, 1, 0, 1},
  {&__pyx_n_u__270, __pyx_k__270, sizeof(__pyx_k__270), 0, 1, 0, 1},
  {&__pyx_n_u__272, __pyx_k__272, sizeof(__pyx_k__272), 0, 1, 0, 1},
  {&__pyx_n_u__273, __pyx_k__273, sizeof(__pyx_k__273), 0, 1, 0, 1},
  {&__pyx_n_u__275, __pyx_k__275, sizeof(__pyx_k__275), 0, 1, 0, 1},
  {&__pyx_n_u__276, __pyx_k__276, sizeof(__pyx_k__276), 0, 1, 0, 1},
  {&__pyx_n_u__278, __pyx_k__278, sizeof(__pyx_k__278), 0, 1, 0, 1},
  {&__pyx_n_u__279, __pyx_k__279, sizeof(__pyx_k__279), 0, 1, 0, 1},
  {&__pyx_n_u__28, __pyx_k__28, sizeof(__pyx_k__28), 0, 1, 0, 1},
  {&__pyx_n_u__281, __pyx_k__281, sizeof(__pyx_k__281), 0, 1, 0, 1},
  {&__pyx_n_u__282, __pyx_k__282, sizeof(__pyx_k__282), 0, 1, 0, 1},
  {&__pyx_n_u__284, __pyx_k__284, sizeof(__pyx_k__284), 0, 1, 0, 1},
  {&__pyx_n_u__285, __pyx_k__285, sizeof(__pyx_k__285), 0, 1, 0, 1},
  {&__pyx_n_u__287, __pyx_k__287, sizeof(__pyx_k__287), 0, 1, 0, 1},
  {&__pyx_n_u__288, __pyx_k__288, sizeof(__pyx_k__288), 0, 1, 0, 1},
  {&__pyx_n_u__290, __pyx_k__290, sizeof(__pyx_k__290), 0, 1, 0, 1},
  {&__pyx_n_u__291, __pyx_k__291, sizeof(__pyx_k__291), 0, 1, 0, 1},
  {&__pyx_n_u__293, __pyx_k__293, sizeof(__pyx_k__293), 0, 1, 0, 1},
  {&__pyx_n_u__294, __pyx_k__294, sizeof(__pyx_k__294), 0, 1, 0, 1},
  {&__pyx_n_u__296, __pyx_k__296, sizeof(__pyx_k__296), 0, 1, 0, 1},
  {&__pyx_n_u__297, __pyx_k__297, sizeof(__pyx_k__297), 0, 1, 0, 1},
  {&__pyx_n_u__299, __pyx_k__299, sizeof(__pyx_k__299), 0, 1, 0, 1},
  {&__pyx_n_u__30, __pyx_k__30, sizeof(__pyx_k__30), 0, 1, 0, 1},
  {&__pyx_n_u__300, __pyx_k__300, sizeof(__pyx_k__300), 0, 1, 0, 1},
  {&__pyx_n_u__302, __pyx_k__302, sizeof(__pyx_k__302), 0, 1, 0, 1},
  {&__pyx_n_u__303, __pyx_k__303, sizeof(__pyx_k__303), 0, 1, 0, 1},
  {&__pyx_n_u__305, __pyx_k__305, sizeof(__pyx_k__305), 0, 1, 0, 1},
  {&__pyx_n_u__306, __pyx_k__306, sizeof(__pyx_k__306), 0, 1, 0, 1},
  {&__pyx_n_u__308, __pyx_k__308, sizeof(__pyx_k__308), 0, 1, 0, 1},
  {&__pyx_n_u__309, __pyx_k__309, sizeof(__pyx_k__309), 0, 1, 0, 1},
  {&__pyx_n_u__311, __pyx_k__311, sizeof(__pyx_k__311), 0, 1, 0, 1},
  {&__pyx_n_u__312, __pyx_k__312, sizeof(__pyx_k__312), 0, 1, 0, 1},
  {&__pyx_n_u__314, __pyx_k__314, sizeof(__pyx_k__314), 0, 1, 0, 1},
  {&__pyx_n_u__315, __pyx_k__315, sizeof(__pyx_k__315), 0, 1, 0, 1},
  {&__pyx_n_u__317, __pyx_k__317, sizeof(__pyx_k__317), 0, 1, 0, 1},
  {&__pyx_n_u__318, __pyx_k__318, sizeof(__pyx_k__318), 0, 1, 0, 1},
  {&__pyx_n_u__32, __pyx_k__32, sizeof(__pyx_k__32), 0, 1, 0, 1},
  {&__pyx_n_u__320, __pyx_k__320, sizeof(__pyx_k__320), 0, 1, 0, 1},
  {&__pyx_n_u__321, __pyx_k__321, sizeof(__pyx_k__321), 0, 1, 0, 1},
  {&__pyx_n_u__323, __pyx_k__323, sizeof(__pyx_k__323), 0, 1, 0, 1},
  {&__pyx_n_u__324, __pyx_k__324, sizeof(__pyx_k__324), 0, 1, 0, 1},
  {&__pyx_n_u__326, __pyx_k__326, sizeof(__pyx_k__326), 0, 1, 0, 1},
  {&__pyx_n_u__327, __pyx_k__327, sizeof(__pyx_k__327), 0, 1, 0, 1},
  {&__pyx_n_u__329, __pyx_k__329, sizeof(__pyx_k__329), 0, 1, 0, 1},
  {&__pyx_n_u__330, __pyx_k__330, sizeof(__pyx_k__330), 0, 1, 0, 1},
  {&__pyx_n_u__332, __pyx_k__332, sizeof(__pyx_k__332), 0, 1, 0, 1},
  {&__pyx_n_u__333, __pyx_k__333, sizeof(__pyx_k__333), 0, 1, 0, 1},
  {&__pyx_n_u__335, __pyx_k__335, sizeof(__pyx_k__335), 0, 1, 0, 1},
  {&__pyx_n_u__336, __pyx_k__336, sizeof(__pyx_k__336), 0, 1, 0, 1},
  {&__pyx_n_u__338, __pyx_k__338, sizeof(__pyx_k__338), 0, 1, 0, 1},
  {&__pyx_n_u__339, __pyx_k__339, sizeof(__pyx_k__339), 0, 1, 0, 1},
  {&__pyx_n_u__34, __pyx_k__34, sizeof(__pyx_k__34), 0, 1, 0, 1},
  {&__pyx_n_u__341, __pyx_k__341, sizeof(__pyx_k__341), 0, 1, 0, 1},
  {&__pyx_n_u__342, __pyx_k__342, sizeof(__pyx_k__342), 0, 1, 0, 1},
  {&__pyx_n_u__344, __pyx_k__344, sizeof(__pyx_k__344), 0, 1, 0, 1},
  {&__pyx_n_u__345, __pyx_k__345, sizeof(__pyx_k__345), 0, 1, 0, 1},
  {&__pyx_n_u__347, __pyx_k__347, sizeof(__pyx_k__347), 0, 1, 0, 1},
  {&__pyx_n_u__348, __pyx_k__348, sizeof(__pyx_k__348), 0, 1, 0, 1},
  {&__pyx_n_u__350, __pyx_k__350, sizeof(__pyx_k__350), 0, 1, 0, 1},
  {&__pyx_n_u__351, __pyx_k__351, sizeof(__pyx_k__351), 0, 1, 0, 1},
  {&__pyx_n_u__353, __pyx_k__353, sizeof(__pyx_k__353), 0, 1, 0, 1},
  {&__pyx_n_u__354, __pyx_k__354, sizeof(__pyx_k__354), 0, 1, 0, 1},
  {&__pyx_n_u__356, __pyx_k__356, sizeof(__pyx_k__356), 0, 1, 0, 1},
  {&__pyx_n_u__357, __pyx_k__357, sizeof(__pyx_k__357), 0, 1, 0, 1},
  {&__pyx_n_u__359, __pyx_k__359, sizeof(__pyx_k__359), 0, 1, 0, 1},
  {&__pyx_n_u__36, __pyx_k__36, sizeof(__pyx_k__36), 0, 1, 0, 1},
  {&__pyx_n_u__360, __pyx_k__360, sizeof(__pyx_k__360), 0, 1, 0, 1},
  {&__pyx_n_u__362, __pyx_k__362, sizeof(__pyx_k__362), 0, 1, 0, 1},
  {&__pyx_n_u__363, __pyx_k__363, sizeof(__pyx_k__363), 0, 1, 0, 1},
  {&__pyx_kp_u__365, __pyx_k__365, sizeof(__pyx_k__365), 0, 1, 0, 0},
  {&__pyx_kp_u__366, __pyx_k__366, sizeof(__pyx_k__366), 0, 1, 0, 0},
  {&__pyx_kp_u__368, __pyx_k__368, sizeof(__pyx_k__368), 0, 1, 0, 0},
  {&__pyx_kp_u__369, __pyx_k__369, sizeof(__pyx_k__369), 0, 1, 0, 0},
  {&__pyx_kp_u__371, __pyx_k__371, sizeof(__pyx_k__371), 0, 1, 0, 0},
  {&__pyx_kp_u__372, __pyx_k__372, sizeof(__pyx_k__372), 0, 1, 0, 0},
  {&__pyx_kp_u__374, __pyx_k__374, sizeof(__pyx_k__374), 0, 1, 0, 0},
  {&__pyx_n_u__375, __pyx_k__375, sizeof(__pyx_k__375), 0, 1, 0, 1},
  {&__pyx_kp_u__377, __pyx_k__377, sizeof(__pyx_k__377), 0, 1, 0, 0},
  {&__pyx_n_u__378, __pyx_k__378, sizeof(__pyx_k__378), 0, 1, 0, 1},
  {&__pyx_n_u__38, __pyx_k__38, sizeof(__pyx_k__38), 0, 1, 0, 1},
  {&__pyx_kp_u__380, __pyx_k__380, sizeof(__pyx_k__380), 0, 1, 0, 0},
  {&__pyx_kp_u__381, __pyx_k__381, sizeof(__pyx_k__381), 0, 1, 0, 0},
  {&__pyx_kp_u__383, __pyx_k__383, sizeof(__pyx_k__383), 0, 1, 0, 0},
  {&__pyx_kp_u__384, __pyx_k__384, sizeof(__pyx_k__384), 0, 1, 0, 0},
  {&__pyx_n_u__386, __pyx_k__386, sizeof(__pyx_k__386), 0, 1, 0, 1},
  {&__pyx_n_u__387, __pyx_k__387, sizeof(__pyx_k__387), 0, 1, 0, 1},
  {&__pyx_n_u__390, __pyx_k__390, sizeof(__pyx_k__390), 0, 1, 0, 1},
  {&__pyx_n_u__392, __pyx_k__392, sizeof(__pyx_k__392), 0, 1, 0, 1},
  {&__pyx_n_u__394, __pyx_k__394, sizeof(__pyx_k__394), 0, 1, 0, 1},
  {&__pyx_n_u__396, __pyx_k__396, sizeof(__pyx_k__396), 0, 1, 0, 1},
  {&__pyx_n_u__398, __pyx_k__398, sizeof(__pyx_k__398), 0, 1, 0, 1},
  {&__pyx_n_u__4, __pyx_k__4, sizeof(__pyx_k__4), 0, 1, 0, 1},
  {&__pyx_n_u__40, __pyx_k__40, sizeof(__pyx_k__40), 0, 1, 0, 1},
  {&__pyx_n_u__400, __pyx_k__400, sizeof(__pyx_k__400), 0, 1, 0, 1},
  {&__pyx_n_u__402, __pyx_k__402, sizeof(__pyx_k__402), 0, 1, 0, 1},
  {&__pyx_n_u__404, __pyx_k__404, sizeof(__pyx_k__404), 0, 1, 0, 1},
  {&__pyx_n_u__406, __pyx_k__406, sizeof(__pyx_k__406), 0, 1, 0, 1},
  {&__pyx_n_u__408, __pyx_k__408, sizeof(__pyx_k__408), 0, 1, 0, 1},
  {&__pyx_n_u__411, __pyx_k__411, sizeof(__pyx_k__411), 0, 1, 0, 1},
  {&__pyx_n_u__413, __pyx_k__413, sizeof(__pyx_k__413), 0, 1, 0, 1},
  {&__pyx_n_u__415, __pyx_k__415, sizeof(__pyx_k__415), 0, 1, 0, 1},
  {&__pyx_n_u__417, __pyx_k__417, sizeof(__pyx_k__417), 0, 1, 0, 1},
  {&__pyx_n_u__419, __pyx_k__419, sizeof(__pyx_k__419), 0, 1, 0, 1},
  {&__pyx_n_u__42, __pyx_k__42, sizeof(__pyx_k__42), 0, 1, 0, 1},
  {&__pyx_n_u__421, __pyx_k__421, sizeof(__pyx_k__421), 0, 1, 0, 1},
  {&__pyx_n_u__423, __pyx_k__423, sizeof(__pyx_k__423), 0, 1, 0, 1},
  {&__pyx_n_u__425, __pyx_k__425, sizeof(__pyx_k__425), 0, 1, 0, 1},
  {&__pyx_n_u__427, __pyx_k__427, sizeof(__pyx_k__427), 0, 1, 0, 1},
  {&__pyx_n_u__429, __pyx_k__429, sizeof(__pyx_k__429), 0, 1, 0, 1},
  {&__pyx_n_u__431, __pyx_k__431, sizeof(__pyx_k__431), 0, 1, 0, 1},
  {&__pyx_n_u__433, __pyx_k__433, sizeof(__pyx_k__433), 0, 1, 0, 1},
  {&__pyx_n_u__435, __pyx_k__435, sizeof(__pyx_k__435), 0, 1, 0, 1},
  {&__pyx_n_u__437, __pyx_k__437, sizeof(__pyx_k__437), 0, 1, 0, 1},
  {&__pyx_n_u__439, __pyx_k__439, sizeof(__pyx_k__439), 0, 1, 0, 1},
  {&__pyx_n_u__44, __pyx_k__44, sizeof(__pyx_k__44), 0, 1, 0, 1},
  {&__pyx_n_u__441, __pyx_k__441, sizeof(__pyx_k__441), 0, 1, 0, 1},
  {&__pyx_n_u__443, __pyx_k__443, sizeof(__pyx_k__443), 0, 1, 0, 1},
  {&__pyx_n_u__445, __pyx_k__445, sizeof(__pyx_k__445), 0, 1, 0, 1},
  {&__pyx_n_u__447, __pyx_k__447, sizeof(__pyx_k__447), 0, 1, 0, 1},
  {&__pyx_n_u__449, __pyx_k__449, sizeof(__pyx_k__449), 0, 1, 0, 1},
  {&__pyx_n_u__451, __pyx_k__451, sizeof(__pyx_k__451), 0, 1, 0, 1},
  {&__pyx_n_u__453, __pyx_k__453, sizeof(__pyx_k__453), 0, 1, 0, 1},
  {&__pyx_n_u__454, __pyx_k__454, sizeof(__pyx_k__454), 0, 1, 0, 1},
  {&__pyx_n_u__457, __pyx_k__457, sizeof(__pyx_k__457), 0, 1, 0, 1},
  {&__pyx_n_u__459, __pyx_k__459, sizeof(__pyx_k__459), 0, 1, 0, 1},
  {&__pyx_n_u__46, __pyx_k__46, sizeof(__pyx_k__46), 0, 1, 0, 1},
  {&__pyx_n_u__461, __pyx_k__461, sizeof(__pyx_k__461), 0, 1, 0, 1},
  {&__pyx_n_u__463, __pyx_k__463, sizeof(__pyx_k__463), 0, 1, 0, 1},
  {&__pyx_n_u__465, __pyx_k__465, sizeof(__pyx_k__465), 0, 1, 0, 1},
  {&__pyx_n_u__467, __pyx_k__467, sizeof(__pyx_k__467), 0, 1, 0, 1},
  {&__pyx_n_u__468, __pyx_k__468, sizeof(__pyx_k__468), 0, 1, 0, 1},
  {&__pyx_n_u__470, __pyx_k__470, sizeof(__pyx_k__470), 0, 1, 0, 1},
  {&__pyx_n_u__471, __pyx_k__471, sizeof(__pyx_k__471), 0, 1, 0, 1},
  {&__pyx_n_u__473, __pyx_k__473, sizeof(__pyx_k__473), 0, 1, 0, 1},
  {&__pyx_n_u__474, __pyx_k__474, sizeof(__pyx_k__474), 0, 1, 0, 1},
  {&__pyx_n_u__476, __pyx_k__476, sizeof(__pyx_k__476), 0, 1, 0, 1},
  {&__pyx_n_u__477, __pyx_k__477, sizeof(__pyx_k__477), 0, 1, 0, 1},
  {&__pyx_n_u__479, __pyx_k__479, sizeof(__pyx_k__479), 0, 1, 0, 1},
  {&__pyx_n_u__48, __pyx_k__48, sizeof(__pyx_k__48), 0, 1, 0, 1},
  {&__pyx_n_u__480, __pyx_k__480, sizeof(__pyx_k__480), 0, 1, 0, 1},
  {&__pyx_kp_u__483, __pyx_k__483, sizeof(__pyx_k__483), 0, 1, 0, 0},
  {&__pyx_kp_u__484, __pyx_k__484, sizeof(__pyx_k__484), 0, 1, 0, 0},
  {&__pyx_kp_u__485, __pyx_k__485, sizeof(__pyx_k__485), 0, 1, 0, 0},
  {&__pyx_kp_u__486, __pyx_k__486, sizeof(__pyx_k__486), 0, 1, 0, 0},
  {&__pyx_kp_u__487, __pyx_k__487, sizeof(__pyx_k__487), 0, 1, 0, 0},
  {&__pyx_kp_u__488, __pyx_k__488, sizeof(__pyx_k__488), 0, 1, 0, 0},
  {&__pyx_kp_u__489, __pyx_k__489, sizeof(__pyx_k__489), 0, 1, 0, 0},
  {&__pyx_kp_u__490, __pyx_k__490, sizeof(__pyx_k__490), 0, 1, 0, 0},
  {&__pyx_kp_u__491, __pyx_k__491, sizeof(__pyx_k__491), 0, 1, 0, 0},
  {&__pyx_kp_u__493, __pyx_k__493, sizeof(__pyx_k__493), 0, 1, 0, 0},
  {&__pyx_kp_u__494, __pyx_k__494, sizeof(__pyx_k__494), 0, 1, 0, 0},
  {&__pyx_kp_u__495, __pyx_k__495, sizeof(__pyx_k__495), 0, 1, 0, 0},
  {&__pyx_kp_u__496, __pyx_k__496, sizeof(__pyx_k__496), 0, 1, 0, 0},
  {&__pyx_kp_u__497, __pyx_k__497, sizeof(__pyx_k__497), 0, 1, 0, 0},
  {&__pyx_kp_u__498, __pyx_k__498, sizeof(__pyx_k__498), 0, 1, 0, 0},
  {&__pyx_n_u__50, __pyx_k__50, sizeof(__pyx_k__50), 0, 1, 0, 1},
  {&__pyx_kp_u__500, __pyx_k__500, sizeof(__pyx_k__500), 0, 1, 0, 0},
  {&__pyx_kp_u__501, __pyx_k__501, sizeof(__pyx_k__501), 0, 1, 0, 0},
  {&__pyx_kp_u__502, __pyx_k__502, sizeof(__pyx_k__502), 0, 1, 0, 0},
  {&__pyx_kp_u__503, __pyx_k__503, sizeof(__pyx_k__503), 0, 1, 0, 0},
  {&__pyx_kp_u__504, __pyx_k__504, sizeof(__pyx_k__504), 0, 1, 0, 0},
  {&__pyx_kp_u__505, __pyx_k__505, sizeof(__pyx_k__505), 0, 1, 0, 0},
  {&__pyx_kp_u__507, __pyx_k__507, sizeof(__pyx_k__507), 0, 1, 0, 0},
  {&__pyx_kp_u__508, __pyx_k__508, sizeof(__pyx_k__508), 0, 1, 0, 0},
  {&__pyx_n_u__52, __pyx_k__52, sizeof(__pyx_k__52), 0, 1, 0, 1},
  {&__pyx_n_u__54, __pyx_k__54, sizeof(__pyx_k__54), 0, 1, 0, 1},
  {&__pyx_n_u__56, __pyx_k__56, sizeof(__pyx_k__56), 0, 1, 0, 1},
  {&__pyx_n_u__58, __pyx_k__58, sizeof(__pyx_k__58), 0, 1, 0, 1},
  {&__pyx_n_u__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 1, 0, 1},
  {&__pyx_n_u__60, __pyx_k__60, sizeof(__pyx_k__60), 0, 1, 0, 1},
  {&__pyx_n_u__62, __pyx_k__62, sizeof(__pyx_k__62), 0, 1, 0, 1},
  {&__pyx_n_u__64, __pyx_k__64, sizeof(__pyx_k__64), 0, 1, 0, 1},
  {&__pyx_n_u__66, __pyx_k__66, sizeof(__pyx_k__66), 0, 1, 0, 1},
  {&__pyx_n_u__68, __pyx_k__68, sizeof(__pyx_k__68), 0, 1, 0, 1},
  {&__pyx_n_u__70, __pyx_k__70, sizeof(__pyx_k__70), 0, 1, 0, 1},
  {&__pyx_n_u__72, __pyx_k__72, sizeof(__pyx_k__72), 0, 1, 0, 1},
  {&__pyx_n_u__74, __pyx_k__74, sizeof(__pyx_k__74), 0, 1, 0, 1},
  {&__pyx_n_u__76, __pyx_k__76, sizeof(__pyx_k__76), 0, 1, 0, 1},
  {&__pyx_n_u__78, __pyx_k__78, sizeof(__pyx_k__78), 0, 1, 0, 1},
  {&__pyx_n_u__8, __pyx_k__8, sizeof(__pyx_k__8), 0, 1, 0, 1},
  {&__pyx_n_u__80, __pyx_k__80, sizeof(__pyx_k__80), 0, 1, 0, 1},
  {&__pyx_n_u__82, __pyx_k__82, sizeof(__pyx_k__82), 0, 1, 0, 1},
  {&__pyx_n_u__84, __pyx_k__84, sizeof(__pyx_k__84), 0, 1, 0, 1},
  {&__pyx_n_u__86, __pyx_k__86, sizeof(__pyx_k__86), 0, 1, 0, 1},
  {&__pyx_n_u__88, __pyx_k__88, sizeof(__pyx_k__88), 0, 1, 0, 1},
  {&__pyx_n_u__90, __pyx_k__90, sizeof(__pyx_k__90), 0, 1, 0, 1},
  {&__pyx_n_u__92, __pyx_k__92, sizeof(__pyx_k__92), 0, 1, 0, 1},
  {&__pyx_n_u__94, __pyx_k__94, sizeof(__pyx_k__94), 0, 1, 0, 1},
  {&__pyx_n_u__96, __pyx_k__96, sizeof(__pyx_k__96), 0, 1, 0, 1},
  {&__pyx_n_u__98, __pyx_k__98, sizeof(__pyx_k__98), 0, 1, 0, 1},
  {&__pyx_n_u_a, __pyx_k_a, sizeof(__pyx_k_a), 0, 1, 0, 1},
  {&__pyx_n_s_after, __pyx_k_after, sizeof(__pyx_k_after), 0, 0, 1, 1},
  {&__pyx_n_u_b, __pyx_k_b, sizeof(__pyx_k_b), 0, 1, 0, 1},
  {&__pyx_n_s_before, __pyx_k_before, sizeof(__pyx_k_before), 0, 0, 1, 1},
  {&__pyx_n_u_builtins, __pyx_k_builtins, sizeof(__pyx_k_builtins), 0, 1, 0, 1},
  {&__pyx_n_s_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 0, 1, 1},
  {&__pyx_n_u_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 1, 0, 1},
  {&__pyx_n_s_chain, __pyx_k_chain, sizeof(__pyx_k_chain), 0, 0, 1, 1},
  {&__pyx_n_s_char_codes, __pyx_k_char_codes, sizeof(__pyx_k_char_codes), 0, 0, 1, 1},
  {&__pyx_n_s_chr, __pyx_k_chr, sizeof(__pyx_k_chr), 0, 0, 1, 1},
  {&__pyx_n_s_chr_func, __pyx_k_chr_func, sizeof(__pyx_k_chr_func), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_u_d, __pyx_k_d, sizeof(__pyx_k_d), 0, 1, 0, 1},
  {&__pyx_n_u_e, __pyx_k_e, sizeof(__pyx_k_e), 0, 1, 0, 1},
  {&__pyx_n_u_f, __pyx_k_f, sizeof(__pyx_k_f), 0, 1, 0, 1},
  {&__pyx_n_u_g, __pyx_k_g, sizeof(__pyx_k_g), 0, 1, 0, 1},
  {&__pyx_n_u_h, __pyx_k_h, sizeof(__pyx_k_h), 0, 1, 0, 1},
  {&__pyx_n_u_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 1, 0, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_itertools, __pyx_k_itertools, sizeof(__pyx_k_itertools), 0, 0, 1, 1},
  {&__pyx_n_u_j, __pyx_k_j, sizeof(__pyx_k_j), 0, 1, 0, 1},
  {&__pyx_n_u_k, __pyx_k_k, sizeof(__pyx_k_k), 0, 1, 0, 1},
  {&__pyx_n_u_l, __pyx_k_l, sizeof(__pyx_k_l), 0, 1, 0, 1},
  {&__pyx_n_u_m, __pyx_k_m, sizeof(__pyx_k_m), 0, 1, 0, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_map, __pyx_k_map, sizeof(__pyx_k_map), 0, 0, 1, 1},
  {&__pyx_n_u_n, __pyx_k_n, sizeof(__pyx_k_n), 0, 1, 0, 1},
  {&__pyx_n_u_o, __pyx_k_o, sizeof(__pyx_k_o), 0, 1, 0, 1},
  {&__pyx_n_u_p, __pyx_k_p, sizeof(__pyx_k_p), 0, 1, 0, 1},
  {&__pyx_n_u_q, __pyx_k_q, sizeof(__pyx_k_q), 0, 1, 0, 1},
  {&__pyx_n_u_r, __pyx_k_r, sizeof(__pyx_k_r), 0, 1, 0, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_remove_space, __pyx_k_remove_space, sizeof(__pyx_k_remove_space), 0, 0, 1, 1},
  {&__pyx_n_s_repeat, __pyx_k_repeat, sizeof(__pyx_k_repeat), 0, 0, 1, 1},
  {&__pyx_n_u_s, __pyx_k_s, sizeof(__pyx_k_s), 0, 1, 0, 1},
  {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
  {&__pyx_n_u_t, __pyx_k_t, sizeof(__pyx_k_t), 0, 1, 0, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_text, __pyx_k_text, sizeof(__pyx_k_text), 0, 0, 1, 1},
  {&__pyx_n_u_u, __pyx_k_u, sizeof(__pyx_k_u), 0, 1, 0, 1},
  {&__pyx_n_s_unichr, __pyx_k_unichr, sizeof(__pyx_k_unichr), 0, 0, 1, 1},
  {&__pyx_n_u_v, __pyx_k_v, sizeof(__pyx_k_v), 0, 1, 0, 1},
  {&__pyx_n_s_version, __pyx_k_version, sizeof(__pyx_k_version), 0, 0, 1, 1},
  {&__pyx_n_s_version_info, __pyx_k_version_info, sizeof(__pyx_k_version_info), 0, 0, 1, 1},
  {&__pyx_n_u_w, __pyx_k_w, sizeof(__pyx_k_w), 0, 1, 0, 1},
  {&__pyx_n_u_x, __pyx_k_x, sizeof(__pyx_k_x), 0, 1, 0, 1},
  {&__pyx_n_u_y, __pyx_k_y, sizeof(__pyx_k_y), 0, 1, 0, 1},
  {&__pyx_n_u_z, __pyx_k_z, sizeof(__pyx_k_z), 0, 1, 0, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 86, __pyx_L1_error)
  __pyx_builtin_chr = __Pyx_GetBuiltinName(__pyx_n_s_chr); if (!__pyx_builtin_chr) __PYX_ERR(0, 93, __pyx_L1_error)
  __pyx_builtin_map = __Pyx_GetBuiltinName(__pyx_n_s_map); if (!__pyx_builtin_map) __PYX_ERR(0, 96, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "neologdn.pyx":11
 * from libcpp.unordered_set cimport unordered_set
 * 
 * VERSION = (0, 3)             # <<<<<<<<<<<<<<
 * __version__ = '0.3'
 * 
 */
  __pyx_tuple_ = PyTuple_Pack(2, __pyx_int_0, __pyx_int_3); if (unlikely(!__pyx_tuple_)) __PYX_ERR(0, 11, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "neologdn.pyx":15
 * 
 * ASCII = (
 *     ('', 'a'), ('', 'b'), ('', 'c'), ('', 'd'), ('', 'e'),             # <<<<<<<<<<<<<<
 *     ('', 'f'), ('', 'g'), ('', 'h'), ('', 'i'), ('', 'j'),
 *     ('', 'k'), ('', 'l'), ('', 'm'), ('', 'n'), ('', 'o'),
 */
  __pyx_tuple__3 = PyTuple_Pack(2, __pyx_n_u__2, __pyx_n_u_a); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);
  __pyx_tuple__5 = PyTuple_Pack(2, __pyx_n_u__4, __pyx_n_u_b); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);
  __pyx_tuple__7 = PyTuple_Pack(2, __pyx_n_u__6, __pyx_n_u_c); if (unlikely(!__pyx_tuple__7)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);
  __pyx_tuple__9 = PyTuple_Pack(2, __pyx_n_u__8, __pyx_n_u_d); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);
  __pyx_tuple__11 = PyTuple_Pack(2, __pyx_n_u__10, __pyx_n_u_e); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "neologdn.pyx":16
 * ASCII = (
 *     ('', 'a'), ('', 'b'), ('', 'c'), ('', 'd'), ('', 'e'),
 *     ('', 'f'), ('', 'g'), ('', 'h'), ('', 'i'), ('', 'j'),             # <<<<<<<<<<<<<<
 *     ('', 'k'), ('', 'l'), ('', 'm'), ('', 'n'), ('', 'o'),
 *     ('', 'p'), ('', 'q'), ('', 'r'), ('', 's'), ('', 't'),
 */
  __pyx_tuple__13 = PyTuple_Pack(2, __pyx_n_u__12, __pyx_n_u_f); if (unlikely(!__pyx_tuple__13)) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__13);
  __Pyx_GIVEREF(__pyx_tuple__13);
  __pyx_tuple__15 = PyTuple_Pack(2, __pyx_n_u__14, __pyx_n_u_g); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);
  __pyx_tuple__17 = PyTuple_Pack(2, __pyx_n_u__16, __pyx_n_u_h); if (unlikely(!__pyx_tuple__17)) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);
  __pyx_tuple__19 = PyTuple_Pack(2, __pyx_n_u__18, __pyx_n_u_i); if (unlikely(!__pyx_tuple__19)) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);
  __pyx_tuple__21 = PyTuple_Pack(2, __pyx_n_u__20, __pyx_n_u_j); if (unlikely(!__pyx_tuple__21)) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);

  /* "neologdn.pyx":17
 *     ('', 'a'), ('', 'b'), ('', 'c'), ('', 'd'), ('', 'e'),
 *     ('', 'f'), ('', 'g'), ('', 'h'), ('', 'i'), ('', 'j'),
 *     ('', 'k'), ('', 'l'), ('', 'm'), ('', 'n'), ('', 'o'),             # <<<<<<<<<<<<<<
 *     ('', 'p'), ('', 'q'), ('', 'r'), ('', 's'), ('', 't'),
 *     ('', 'u'), ('', 'v'), ('', 'w'), ('', 'x'), ('', 'y'),
 */
  __pyx_tuple__23 = PyTuple_Pack(2, __pyx_n_u__22, __pyx_n_u_k); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);
  __pyx_tuple__25 = PyTuple_Pack(2, __pyx_n_u__24, __pyx_n_u_l); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);
  __pyx_tuple__27 = PyTuple_Pack(2, __pyx_n_u__26, __pyx_n_u_m); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);
  __pyx_tuple__29 = PyTuple_Pack(2, __pyx_n_u__28, __pyx_n_u_n); if (unlikely(!__pyx_tuple__29)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);
  __pyx_tuple__31 = PyTuple_Pack(2, __pyx_n_u__30, __pyx_n_u_o); if (unlikely(!__pyx_tuple__31)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__31);
  __Pyx_GIVEREF(__pyx_tuple__31);

  /* "neologdn.pyx":18
 *     ('', 'f'), ('', 'g'), ('', 'h'), ('', 'i'), ('', 'j'),
 *     ('', 'k'), ('', 'l'), ('', 'm'), ('', 'n'), ('', 'o'),
 *     ('', 'p'), ('', 'q'), ('', 'r'), ('', 's'), ('', 't'),             # <<<<<<<<<<<<<<
 *     ('', 'u'), ('', 'v'), ('', 'w'), ('', 'x'), ('', 'y'),
 *     ('', 'z'),
 */
  __pyx_tuple__33 = PyTuple_Pack(2, __pyx_n_u__32, __pyx_n_u_p); if (unlikely(!__pyx_tuple__33)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__33);
  __Pyx_GIVEREF(__pyx_tuple__33);
  __pyx_tuple__35 = PyTuple_Pack(2, __pyx_n_u__34, __pyx_n_u_q); if (unlikely(!__pyx_tuple__35)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);
  __pyx_tuple__37 = PyTuple_Pack(2, __pyx_n_u__36, __pyx_n_u_r); if (unlikely(!__pyx_tuple__37)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__37);
  __Pyx_GIVEREF(__pyx_tuple__37);
  __pyx_tuple__39 = PyTuple_Pack(2, __pyx_n_u__38, __pyx_n_u_s); if (unlikely(!__pyx_tuple__39)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__39);
  __Pyx_GIVEREF(__pyx_tuple__39);
  __pyx_tuple__41 = PyTuple_Pack(2, __pyx_n_u__40, __pyx_n_u_t); if (unlikely(!__pyx_tuple__41)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);

  /* "neologdn.pyx":19
 *     ('', 'k'), ('', 'l'), ('', 'm'), ('', 'n'), ('', 'o'),
 *     ('', 'p'), ('', 'q'), ('', 'r'), ('', 's'), ('', 't'),
 *     ('', 'u'), ('', 'v'), ('', 'w'), ('', 'x'), ('', 'y'),             # <<<<<<<<<<<<<<
 *     ('', 'z'),
 *     ('', 'A'), ('', 'B'), ('', 'C'), ('', 'D'), ('', 'E'),
 */
  __pyx_tuple__43 = PyTuple_Pack(2, __pyx_n_u__42, __pyx_n_u_u); if (unlikely(!__pyx_tuple__43)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);
  __pyx_tuple__45 = PyTuple_Pack(2, __pyx_n_u__44, __pyx_n_u_v); if (unlikely(!__pyx_tuple__45)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__45);
  __Pyx_GIVEREF(__pyx_tuple__45);
  __pyx_tuple__47 = PyTuple_Pack(2, __pyx_n_u__46, __pyx_n_u_w); if (unlikely(!__pyx_tuple__47)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__47);
  __Pyx_GIVEREF(__pyx_tuple__47);
  __pyx_tuple__49 = PyTuple_Pack(2, __pyx_n_u__48, __pyx_n_u_x); if (unlikely(!__pyx_tuple__49)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__49);
  __Pyx_GIVEREF(__pyx_tuple__49);
  __pyx_tuple__51 = PyTuple_Pack(2, __pyx_n_u__50, __pyx_n_u_y); if (unlikely(!__pyx_tuple__51)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__51);
  __Pyx_GIVEREF(__pyx_tuple__51);

  /* "neologdn.pyx":20
 *     ('', 'p'), ('', 'q'), ('', 'r'), ('', 's'), ('', 't'),
 *     ('', 'u'), ('', 'v'), ('', 'w'), ('', 'x'), ('', 'y'),
 *     ('', 'z'),             # <<<<<<<<<<<<<<
 *     ('', 'A'), ('', 'B'), ('', 'C'), ('', 'D'), ('', 'E'),
 *     ('', 'F'), ('', 'G'), ('', 'H'), ('', 'I'), ('', 'J'),
 */
  __pyx_tuple__53 = PyTuple_Pack(2, __pyx_n_u__52, __pyx_n_u_z); if (unlikely(!__pyx_tuple__53)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__53);
  __Pyx_GIVEREF(__pyx_tuple__53);

  /* "neologdn.pyx":21
 *     ('', 'u'), ('', 'v'), ('', 'w'), ('', 'x'), ('', 'y'),
 *     ('', 'z'),
 *     ('', 'A'), ('', 'B'), ('', 'C'), ('', 'D'), ('', 'E'),             # <<<<<<<<<<<<<<
 *     ('', 'F'), ('', 'G'), ('', 'H'), ('', 'I'), ('', 'J'),
 *     ('', 'K'), ('', 'L'), ('', 'M'), ('', 'N'), ('', 'O'),
 */
  __pyx_tuple__55 = PyTuple_Pack(2, __pyx_n_u__54, __pyx_n_u_A); if (unlikely(!__pyx_tuple__55)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__55);
  __Pyx_GIVEREF(__pyx_tuple__55);
  __pyx_tuple__57 = PyTuple_Pack(2, __pyx_n_u__56, __pyx_n_u_B); if (unlikely(!__pyx_tuple__57)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__57);
  __Pyx_GIVEREF(__pyx_tuple__57);
  __pyx_tuple__59 = PyTuple_Pack(2, __pyx_n_u__58, __pyx_n_u_C); if (unlikely(!__pyx_tuple__59)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__59);
  __Pyx_GIVEREF(__pyx_tuple__59);
  __pyx_tuple__61 = PyTuple_Pack(2, __pyx_n_u__60, __pyx_n_u_D); if (unlikely(!__pyx_tuple__61)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__61);
  __Pyx_GIVEREF(__pyx_tuple__61);
  __pyx_tuple__63 = PyTuple_Pack(2, __pyx_n_u__62, __pyx_n_u_E); if (unlikely(!__pyx_tuple__63)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__63);
  __Pyx_GIVEREF(__pyx_tuple__63);

  /* "neologdn.pyx":22
 *     ('', 'z'),
 *     ('', 'A'), ('', 'B'), ('', 'C'), ('', 'D'), ('', 'E'),
 *     ('', 'F'), ('', 'G'), ('', 'H'), ('', 'I'), ('', 'J'),             # <<<<<<<<<<<<<<
 *     ('', 'K'), ('', 'L'), ('', 'M'), ('', 'N'), ('', 'O'),
 *     ('', 'P'), ('', 'Q'), ('', 'R'), ('', 'S'), ('', 'T'),
 */
  __pyx_tuple__65 = PyTuple_Pack(2, __pyx_n_u__64, __pyx_n_u_F); if (unlikely(!__pyx_tuple__65)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__65);
  __Pyx_GIVEREF(__pyx_tuple__65);
  __pyx_tuple__67 = PyTuple_Pack(2, __pyx_n_u__66, __pyx_n_u_G); if (unlikely(!__pyx_tuple__67)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__67);
  __Pyx_GIVEREF(__pyx_tuple__67);
  __pyx_tuple__69 = PyTuple_Pack(2, __pyx_n_u__68, __pyx_n_u_H); if (unlikely(!__pyx_tuple__69)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__69);
  __Pyx_GIVEREF(__pyx_tuple__69);
  __pyx_tuple__71 = PyTuple_Pack(2, __pyx_n_u__70, __pyx_n_u_I); if (unlikely(!__pyx_tuple__71)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__71);
  __Pyx_GIVEREF(__pyx_tuple__71);
  __pyx_tuple__73 = PyTuple_Pack(2, __pyx_n_u__72, __pyx_n_u_J); if (unlikely(!__pyx_tuple__73)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__73);
  __Pyx_GIVEREF(__pyx_tuple__73);

  /* "neologdn.pyx":23
 *     ('', 'A'), ('', 'B'), ('', 'C'), ('', 'D'), ('', 'E'),
 *     ('', 'F'), ('', 'G'), ('', 'H'), ('', 'I'), ('', 'J'),
 *     ('', 'K'), ('', 'L'), ('', 'M'), ('', 'N'), ('', 'O'),             # <<<<<<<<<<<<<<
 *     ('', 'P'), ('', 'Q'), ('', 'R'), ('', 'S'), ('', 'T'),
 *     ('', 'U'), ('', 'V'), ('', 'W'), ('', 'X'), ('', 'Y'),
 */
  __pyx_tuple__75 = PyTuple_Pack(2, __pyx_n_u__74, __pyx_n_u_K); if (unlikely(!__pyx_tuple__75)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__75);
  __Pyx_GIVEREF(__pyx_tuple__75);
  __pyx_tuple__77 = PyTuple_Pack(2, __pyx_n_u__76, __pyx_n_u_L); if (unlikely(!__pyx_tuple__77)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__77);
  __Pyx_GIVEREF(__pyx_tuple__77);
  __pyx_tuple__79 = PyTuple_Pack(2, __pyx_n_u__78, __pyx_n_u_M); if (unlikely(!__pyx_tuple__79)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__79);
  __Pyx_GIVEREF(__pyx_tuple__79);
  __pyx_tuple__81 = PyTuple_Pack(2, __pyx_n_u__80, __pyx_n_u_N); if (unlikely(!__pyx_tuple__81)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__81);
  __Pyx_GIVEREF(__pyx_tuple__81);
  __pyx_tuple__83 = PyTuple_Pack(2, __pyx_n_u__82, __pyx_n_u_O); if (unlikely(!__pyx_tuple__83)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__83);
  __Pyx_GIVEREF(__pyx_tuple__83);

  /* "neologdn.pyx":24
 *     ('', 'F'), ('', 'G'), ('', 'H'), ('', 'I'), ('', 'J'),
 *     ('', 'K'), ('', 'L'), ('', 'M'), ('', 'N'), ('', 'O'),
 *     ('', 'P'), ('', 'Q'), ('', 'R'), ('', 'S'), ('', 'T'),             # <<<<<<<<<<<<<<
 *     ('', 'U'), ('', 'V'), ('', 'W'), ('', 'X'), ('', 'Y'),
 *     ('', 'Z'),
 */
  __pyx_tuple__85 = PyTuple_Pack(2, __pyx_n_u__84, __pyx_n_u_P); if (unlikely(!__pyx_tuple__85)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__85);
  __Pyx_GIVEREF(__pyx_tuple__85);
  __pyx_tuple__87 = PyTuple_Pack(2, __pyx_n_u__86, __pyx_n_u_Q); if (unlikely(!__pyx_tuple__87)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__87);
  __Pyx_GIVEREF(__pyx_tuple__87);
  __pyx_tuple__89 = PyTuple_Pack(2, __pyx_n_u__88, __pyx_n_u_R); if (unlikely(!__pyx_tuple__89)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__89);
  __Pyx_GIVEREF(__pyx_tuple__89);
  __pyx_tuple__91 = PyTuple_Pack(2, __pyx_n_u__90, __pyx_n_u_S); if (unlikely(!__pyx_tuple__91)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__91);
  __Pyx_GIVEREF(__pyx_tuple__91);
  __pyx_tuple__93 = PyTuple_Pack(2, __pyx_n_u__92, __pyx_n_u_T); if (unlikely(!__pyx_tuple__93)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__93);
  __Pyx_GIVEREF(__pyx_tuple__93);

  /* "neologdn.pyx":25
 *     ('', 'K'), ('', 'L'), ('', 'M'), ('', 'N'), ('', 'O'),
 *     ('', 'P'), ('', 'Q'), ('', 'R'), ('', 'S'), ('', 'T'),
 *     ('', 'U'), ('', 'V'), ('', 'W'), ('', 'X'), ('', 'Y'),             # <<<<<<<<<<<<<<
 *     ('', 'Z'),
 *     ('', '!'), ('', '"'), ('', '#'), ('', '$'), ('', '%'),
 */
  __pyx_tuple__95 = PyTuple_Pack(2, __pyx_n_u__94, __pyx_n_u_U); if (unlikely(!__pyx_tuple__95)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__95);
  __Pyx_GIVEREF(__pyx_tuple__95);
  __pyx_tuple__97 = PyTuple_Pack(2, __pyx_n_u__96, __pyx_n_u_V); if (unlikely(!__pyx_tuple__97)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__97);
  __Pyx_GIVEREF(__pyx_tuple__97);
  __pyx_tuple__99 = PyTuple_Pack(2, __pyx_n_u__98, __pyx_n_u_W); if (unlikely(!__pyx_tuple__99)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__99);
  __Pyx_GIVEREF(__pyx_tuple__99);
  __pyx_tuple__101 = PyTuple_Pack(2, __pyx_n_u__100, __pyx_n_u_X); if (unlikely(!__pyx_tuple__101)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__101);
  __Pyx_GIVEREF(__pyx_tuple__101);
  __pyx_tuple__103 = PyTuple_Pack(2, __pyx_n_u__102, __pyx_n_u_Y); if (unlikely(!__pyx_tuple__103)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__103);
  __Pyx_GIVEREF(__pyx_tuple__103);

  /* "neologdn.pyx":26
 *     ('', 'P'), ('', 'Q'), ('', 'R'), ('', 'S'), ('', 'T'),
 *     ('', 'U'), ('', 'V'), ('', 'W'), ('', 'X'), ('', 'Y'),
 *     ('', 'Z'),             # <<<<<<<<<<<<<<
 *     ('', '!'), ('', '"'), ('', '#'), ('', '$'), ('', '%'),
 *     ('', '&'), ('', '\''), ('', '('), ('', ')'), ('', '*'),
 */
  __pyx_tuple__105 = PyTuple_Pack(2, __pyx_n_u__104, __pyx_n_u_Z); if (unlikely(!__pyx_tuple__105)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__105);
  __Pyx_GIVEREF(__pyx_tuple__105);

  /* "neologdn.pyx":27
 *     ('', 'U'), ('', 'V'), ('', 'W'), ('', 'X'), ('', 'Y'),
 *     ('', 'Z'),
 *     ('', '!'), ('', '"'), ('', '#'), ('', '$'), ('', '%'),             # <<<<<<<<<<<<<<
 *     ('', '&'), ('', '\''), ('', '('), ('', ')'), ('', '*'),
 *     ('', '+'), ('', ','), ('', '-'), ('', '.'), ('', '/'),
 */
  __pyx_tuple__108 = PyTuple_Pack(2, __pyx_kp_u__106, __pyx_kp_u__107); if (unlikely(!__pyx_tuple__108)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__108);
  __Pyx_GIVEREF(__pyx_tuple__108);
  __pyx_tuple__111 = PyTuple_Pack(2, __pyx_kp_u__109, __pyx_kp_u__110); if (unlikely(!__pyx_tuple__111)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__111);
  __Pyx_GIVEREF(__pyx_tuple__111);
  __pyx_tuple__114 = PyTuple_Pack(2, __pyx_kp_u__112, __pyx_kp_u__113); if (unlikely(!__pyx_tuple__114)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__114);
  __Pyx_GIVEREF(__pyx_tuple__114);
  __pyx_tuple__117 = PyTuple_Pack(2, __pyx_kp_u__115, __pyx_kp_u__116); if (unlikely(!__pyx_tuple__117)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__117);
  __Pyx_GIVEREF(__pyx_tuple__117);
  __pyx_tuple__120 = PyTuple_Pack(2, __pyx_kp_u__118, __pyx_kp_u__119); if (unlikely(!__pyx_tuple__120)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__120);
  __Pyx_GIVEREF(__pyx_tuple__120);

  /* "neologdn.pyx":28
 *     ('', 'Z'),
 *     ('', '!'), ('', '"'), ('', '#'), ('', '$'), ('', '%'),
 *     ('', '&'), ('', '\''), ('', '('), ('', ')'), ('', '*'),             # <<<<<<<<<<<<<<
 *     ('', '+'), ('', ','), ('', '-'), ('', '.'), ('', '/'),
 *     ('', ':'), ('', ';'), ('', '<'), ('', '='), ('', '>'),
 */
  __pyx_tuple__123 = PyTuple_Pack(2, __pyx_kp_u__121, __pyx_kp_u__122); if (unlikely(!__pyx_tuple__123)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__123);
  __Pyx_GIVEREF(__pyx_tuple__123);
  __pyx_tuple__126 = PyTuple_Pack(2, __pyx_kp_u__124, __pyx_kp_u__125); if (unlikely(!__pyx_tuple__126)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__126);
  __Pyx_GIVEREF(__pyx_tuple__126);
  __pyx_tuple__129 = PyTuple_Pack(2, __pyx_kp_u__127, __pyx_kp_u__128); if (unlikely(!__pyx_tuple__129)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__129);
  __Pyx_GIVEREF(__pyx_tuple__129);
  __pyx_tuple__132 = PyTuple_Pack(2, __pyx_kp_u__130, __pyx_kp_u__131); if (unlikely(!__pyx_tuple__132)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__132);
  __Pyx_GIVEREF(__pyx_tuple__132);
  __pyx_tuple__135 = PyTuple_Pack(2, __pyx_kp_u__133, __pyx_kp_u__134); if (unlikely(!__pyx_tuple__135)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__135);
  __Pyx_GIVEREF(__pyx_tuple__135);

  /* "neologdn.pyx":29
 *     ('', '!'), ('', '"'), ('', '#'), ('', '$'), ('', '%'),
 *     ('', '&'), ('', '\''), ('', '('), ('', ')'), ('', '*'),
 *     ('', '+'), ('', ','), ('', '-'), ('', '.'), ('', '/'),             # <<<<<<<<<<<<<<
 *     ('', ':'), ('', ';'), ('', '<'), ('', '='), ('', '>'),
 *     ('', '?'), ('', '@'), ('', '['), ('', '\\'), ('', ']'),
 */
  __pyx_tuple__138 = PyTuple_Pack(2, __pyx_kp_u__136, __pyx_kp_u__137); if (unlikely(!__pyx_tuple__138)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__138);
  __Pyx_GIVEREF(__pyx_tuple__138);
  __pyx_tuple__141 = PyTuple_Pack(2, __pyx_kp_u__139, __pyx_kp_u__140); if (unlikely(!__pyx_tuple__141)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__141);
  __Pyx_GIVEREF(__pyx_tuple__141);
  __pyx_tuple__144 = PyTuple_Pack(2, __pyx_kp_u__142, __pyx_kp_u__143); if (unlikely(!__pyx_tuple__144)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__144);
  __Pyx_GIVEREF(__pyx_tuple__144);
  __pyx_tuple__147 = PyTuple_Pack(2, __pyx_kp_u__145, __pyx_kp_u__146); if (unlikely(!__pyx_tuple__147)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__147);
  __Pyx_GIVEREF(__pyx_tuple__147);
  __pyx_tuple__150 = PyTuple_Pack(2, __pyx_kp_u__148, __pyx_kp_u__149); if (unlikely(!__pyx_tuple__150)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__150);
  __Pyx_GIVEREF(__pyx_tuple__150);

  /* "neologdn.pyx":30
 *     ('', '&'), ('', '\''), ('', '('), ('', ')'), ('', '*'),
 *     ('', '+'), ('', ','), ('', '-'), ('', '.'), ('', '/'),
 *     ('', ':'), ('', ';'), ('', '<'), ('', '='), ('', '>'),             # <<<<<<<<<<<<<<
 *     ('', '?'), ('', '@'), ('', '['), ('', '\\'), ('', ']'),
 *     ('', '^'), ('', '_'), ('', '`'), ('', '{'), ('', '|'),
 */
  __pyx_tuple__153 = PyTuple_Pack(2, __pyx_kp_u__151, __pyx_kp_u__152); if (unlikely(!__pyx_tuple__153)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__153);
  __Pyx_GIVEREF(__pyx_tuple__153);
  __pyx_tuple__156 = PyTuple_Pack(2, __pyx_kp_u__154, __pyx_kp_u__155); if (unlikely(!__pyx_tuple__156)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__156);
  __Pyx_GIVEREF(__pyx_tuple__156);
  __pyx_tuple__159 = PyTuple_Pack(2, __pyx_kp_u__157, __pyx_kp_u__158); if (unlikely(!__pyx_tuple__159)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__159);
  __Pyx_GIVEREF(__pyx_tuple__159);
  __pyx_tuple__162 = PyTuple_Pack(2, __pyx_kp_u__160, __pyx_kp_u__161); if (unlikely(!__pyx_tuple__162)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__162);
  __Pyx_GIVEREF(__pyx_tuple__162);
  __pyx_tuple__165 = PyTuple_Pack(2, __pyx_kp_u__163, __pyx_kp_u__164); if (unlikely(!__pyx_tuple__165)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__165);
  __Pyx_GIVEREF(__pyx_tuple__165);

  /* "neologdn.pyx":31
 *     ('', '+'), ('', ','), ('', '-'), ('', '.'), ('', '/'),
 *     ('', ':'), ('', ';'), ('', '<'), ('', '='), ('', '>'),
 *     ('', '?'), ('', '@'), ('', '['), ('', '\\'), ('', ']'),             # <<<<<<<<<<<<<<
 *     ('', '^'), ('', '_'), ('', '`'), ('', '{'), ('', '|'),
 *     ('', '}')
 */
  __pyx_tuple__168 = PyTuple_Pack(2, __pyx_kp_u__166, __pyx_kp_u__167); if (unlikely(!__pyx_tuple__168)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__168);
  __Pyx_GIVEREF(__pyx_tuple__168);
  __pyx_tuple__171 = PyTuple_Pack(2, __pyx_kp_u__169, __pyx_kp_u__170); if (unlikely(!__pyx_tuple__171)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__171);
  __Pyx_GIVEREF(__pyx_tuple__171);
  __pyx_tuple__174 = PyTuple_Pack(2, __pyx_kp_u__172, __pyx_kp_u__173); if (unlikely(!__pyx_tuple__174)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__174);
  __Pyx_GIVEREF(__pyx_tuple__174);
  __pyx_tuple__177 = PyTuple_Pack(2, __pyx_kp_u__175, __pyx_kp_u__176); if (unlikely(!__pyx_tuple__177)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__177);
  __Pyx_GIVEREF(__pyx_tuple__177);
  __pyx_tuple__180 = PyTuple_Pack(2, __pyx_kp_u__178, __pyx_kp_u__179); if (unlikely(!__pyx_tuple__180)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__180);
  __Pyx_GIVEREF(__pyx_tuple__180);

  /* "neologdn.pyx":32
 *     ('', ':'), ('', ';'), ('', '<'), ('', '='), ('', '>'),
 *     ('', '?'), ('', '@'), ('', '['), ('', '\\'), ('', ']'),
 *     ('', '^'), ('', '_'), ('', '`'), ('', '{'), ('', '|'),             # <<<<<<<<<<<<<<
 *     ('', '}')
 * )
 */
  __pyx_tuple__183 = PyTuple_Pack(2, __pyx_kp_u__181, __pyx_kp_u__182); if (unlikely(!__pyx_tuple__183)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__183);
  __Pyx_GIVEREF(__pyx_tuple__183);
  __pyx_tuple__186 = PyTuple_Pack(2, __pyx_kp_u__184, __pyx_n_u__185); if (unlikely(!__pyx_tuple__186)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__186);
  __Pyx_GIVEREF(__pyx_tuple__186);
  __pyx_tuple__189 = PyTuple_Pack(2, __pyx_kp_u__187, __pyx_kp_u__188); if (unlikely(!__pyx_tuple__189)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__189);
  __Pyx_GIVEREF(__pyx_tuple__189);
  __pyx_tuple__192 = PyTuple_Pack(2, __pyx_kp_u__190, __pyx_kp_u__191); if (unlikely(!__pyx_tuple__192)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__192);
  __Pyx_GIVEREF(__pyx_tuple__192);
  __pyx_tuple__195 = PyTuple_Pack(2, __pyx_kp_u__193, __pyx_kp_u__194); if (unlikely(!__pyx_tuple__195)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__195);
  __Pyx_GIVEREF(__pyx_tuple__195);

  /* "neologdn.pyx":33
 *     ('', '?'), ('', '@'), ('', '['), ('', '\\'), ('', ']'),
 *     ('', '^'), ('', '_'), ('', '`'), ('', '{'), ('', '|'),
 *     ('', '}')             # <<<<<<<<<<<<<<
 * )
 * KANA = (
 */
  __pyx_tuple__198 = PyTuple_Pack(2, __pyx_kp_u__196, __pyx_kp_u__197); if (unlikely(!__pyx_tuple__198)) __PYX_ERR(0, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__198);
  __Pyx_GIVEREF(__pyx_tuple__198);

  /* "neologdn.pyx":15
 * 
 * ASCII = (
 *     ('', 'a'), ('', 'b'), ('', 'c'), ('', 'd'), ('', 'e'),             # <<<<<<<<<<<<<<
 *     ('', 'f'), ('', 'g'), ('', 'h'), ('', 'i'), ('', 'j'),
 *     ('', 'k'), ('', 'l'), ('', 'm'), ('', 'n'), ('', 'o'),
 */
  __pyx_tuple__199 = PyTuple_Pack(83, __pyx_tuple__3, __pyx_tuple__5, __pyx_tuple__7, __pyx_tuple__9, __pyx_tuple__11, __pyx_tuple__13, __pyx_tuple__15, __pyx_tuple__17, __pyx_tuple__19, __pyx_tuple__21, __pyx_tuple__23, __pyx_tuple__25, __pyx_tuple__27, __pyx_tuple__29, __pyx_tuple__31, __pyx_tuple__33, __pyx_tuple__35, __pyx_tuple__37, __pyx_tuple__39, __pyx_tuple__41, __pyx_tuple__43, __pyx_tuple__45, __pyx_tuple__47, __pyx_tuple__49, __pyx_tuple__51, __pyx_tuple__53, __pyx_tuple__55, __pyx_tuple__57, __pyx_tuple__59, __pyx_tuple__61, __pyx_tuple__63, __pyx_tuple__65, __pyx_tuple__67, __pyx_tuple__69, __pyx_tuple__71, __pyx_tuple__73, __pyx_tuple__75, __pyx_tuple__77, __pyx_tuple__79, __pyx_tuple__81, __pyx_tuple__83, __pyx_tuple__85, __pyx_tuple__87, __pyx_tuple__89, __pyx_tuple__91, __pyx_tuple__93, __pyx_tuple__95, __pyx_tuple__97, __pyx_tuple__99, __pyx_tuple__101, __pyx_tuple__103, __pyx_tuple__105, __pyx_tuple__108, __pyx_tuple__111, __pyx_tuple__114, __pyx_tuple__117, __pyx_tuple__120, __pyx_tuple__123, __pyx_tuple__126, __pyx_tuple__129, __pyx_tuple__132, __pyx_tuple__135, __pyx_tuple__138, __pyx_tuple__141, __pyx_tuple__144, __pyx_tuple__147, __pyx_tuple__150, __pyx_tuple__153, __pyx_tuple__156, __pyx_tuple__159, __pyx_tuple__162, __pyx_tuple__165, __pyx_tuple__168, __pyx_tuple__171, __pyx_tuple__174, __pyx_tuple__177, __pyx_tuple__180, __pyx_tuple__183, __pyx_tuple__186, __pyx_tuple__189, __pyx_tuple__192, __pyx_tuple__195, __pyx_tuple__198); if (unlikely(!__pyx_tuple__199)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__199);
  __Pyx_GIVEREF(__pyx_tuple__199);

  /* "neologdn.pyx":36
 * )
 * KANA = (
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 */
  __pyx_tuple__202 = PyTuple_Pack(2, __pyx_n_u__200, __pyx_n_u__201); if (unlikely(!__pyx_tuple__202)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__202);
  __Pyx_GIVEREF(__pyx_tuple__202);
  __pyx_tuple__205 = PyTuple_Pack(2, __pyx_n_u__203, __pyx_n_u__204); if (unlikely(!__pyx_tuple__205)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__205);
  __Pyx_GIVEREF(__pyx_tuple__205);
  __pyx_tuple__208 = PyTuple_Pack(2, __pyx_n_u__206, __pyx_n_u__207); if (unlikely(!__pyx_tuple__208)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__208);
  __Pyx_GIVEREF(__pyx_tuple__208);
  __pyx_tuple__211 = PyTuple_Pack(2, __pyx_n_u__209, __pyx_n_u__210); if (unlikely(!__pyx_tuple__211)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__211);
  __Pyx_GIVEREF(__pyx_tuple__211);
  __pyx_tuple__214 = PyTuple_Pack(2, __pyx_n_u__212, __pyx_n_u__213); if (unlikely(!__pyx_tuple__214)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__214);
  __Pyx_GIVEREF(__pyx_tuple__214);

  /* "neologdn.pyx":37
 * KANA = (
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 */
  __pyx_tuple__217 = PyTuple_Pack(2, __pyx_n_u__215, __pyx_n_u__216); if (unlikely(!__pyx_tuple__217)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__217);
  __Pyx_GIVEREF(__pyx_tuple__217);
  __pyx_tuple__220 = PyTuple_Pack(2, __pyx_n_u__218, __pyx_n_u__219); if (unlikely(!__pyx_tuple__220)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__220);
  __Pyx_GIVEREF(__pyx_tuple__220);
  __pyx_tuple__223 = PyTuple_Pack(2, __pyx_n_u__221, __pyx_n_u__222); if (unlikely(!__pyx_tuple__223)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__223);
  __Pyx_GIVEREF(__pyx_tuple__223);
  __pyx_tuple__226 = PyTuple_Pack(2, __pyx_n_u__224, __pyx_n_u__225); if (unlikely(!__pyx_tuple__226)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__226);
  __Pyx_GIVEREF(__pyx_tuple__226);
  __pyx_tuple__229 = PyTuple_Pack(2, __pyx_n_u__227, __pyx_n_u__228); if (unlikely(!__pyx_tuple__229)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__229);
  __Pyx_GIVEREF(__pyx_tuple__229);

  /* "neologdn.pyx":38
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 */
  __pyx_tuple__232 = PyTuple_Pack(2, __pyx_n_u__230, __pyx_n_u__231); if (unlikely(!__pyx_tuple__232)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__232);
  __Pyx_GIVEREF(__pyx_tuple__232);
  __pyx_tuple__235 = PyTuple_Pack(2, __pyx_n_u__233, __pyx_n_u__234); if (unlikely(!__pyx_tuple__235)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__235);
  __Pyx_GIVEREF(__pyx_tuple__235);
  __pyx_tuple__238 = PyTuple_Pack(2, __pyx_n_u__236, __pyx_n_u__237); if (unlikely(!__pyx_tuple__238)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__238);
  __Pyx_GIVEREF(__pyx_tuple__238);
  __pyx_tuple__241 = PyTuple_Pack(2, __pyx_n_u__239, __pyx_n_u__240); if (unlikely(!__pyx_tuple__241)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__241);
  __Pyx_GIVEREF(__pyx_tuple__241);
  __pyx_tuple__244 = PyTuple_Pack(2, __pyx_n_u__242, __pyx_n_u__243); if (unlikely(!__pyx_tuple__244)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__244);
  __Pyx_GIVEREF(__pyx_tuple__244);

  /* "neologdn.pyx":39
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 */
  __pyx_tuple__247 = PyTuple_Pack(2, __pyx_n_u__245, __pyx_n_u__246); if (unlikely(!__pyx_tuple__247)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__247);
  __Pyx_GIVEREF(__pyx_tuple__247);
  __pyx_tuple__250 = PyTuple_Pack(2, __pyx_n_u__248, __pyx_n_u__249); if (unlikely(!__pyx_tuple__250)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__250);
  __Pyx_GIVEREF(__pyx_tuple__250);
  __pyx_tuple__253 = PyTuple_Pack(2, __pyx_n_u__251, __pyx_n_u__252); if (unlikely(!__pyx_tuple__253)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__253);
  __Pyx_GIVEREF(__pyx_tuple__253);
  __pyx_tuple__256 = PyTuple_Pack(2, __pyx_n_u__254, __pyx_n_u__255); if (unlikely(!__pyx_tuple__256)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__256);
  __Pyx_GIVEREF(__pyx_tuple__256);
  __pyx_tuple__259 = PyTuple_Pack(2, __pyx_n_u__257, __pyx_n_u__258); if (unlikely(!__pyx_tuple__259)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__259);
  __Pyx_GIVEREF(__pyx_tuple__259);

  /* "neologdn.pyx":40
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 */
  __pyx_tuple__262 = PyTuple_Pack(2, __pyx_n_u__260, __pyx_n_u__261); if (unlikely(!__pyx_tuple__262)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__262);
  __Pyx_GIVEREF(__pyx_tuple__262);
  __pyx_tuple__265 = PyTuple_Pack(2, __pyx_n_u__263, __pyx_n_u__264); if (unlikely(!__pyx_tuple__265)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__265);
  __Pyx_GIVEREF(__pyx_tuple__265);
  __pyx_tuple__268 = PyTuple_Pack(2, __pyx_n_u__266, __pyx_n_u__267); if (unlikely(!__pyx_tuple__268)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__268);
  __Pyx_GIVEREF(__pyx_tuple__268);
  __pyx_tuple__271 = PyTuple_Pack(2, __pyx_n_u__269, __pyx_n_u__270); if (unlikely(!__pyx_tuple__271)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__271);
  __Pyx_GIVEREF(__pyx_tuple__271);
  __pyx_tuple__274 = PyTuple_Pack(2, __pyx_n_u__272, __pyx_n_u__273); if (unlikely(!__pyx_tuple__274)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__274);
  __Pyx_GIVEREF(__pyx_tuple__274);

  /* "neologdn.pyx":41
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''),
 */
  __pyx_tuple__277 = PyTuple_Pack(2, __pyx_n_u__275, __pyx_n_u__276); if (unlikely(!__pyx_tuple__277)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__277);
  __Pyx_GIVEREF(__pyx_tuple__277);
  __pyx_tuple__280 = PyTuple_Pack(2, __pyx_n_u__278, __pyx_n_u__279); if (unlikely(!__pyx_tuple__280)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__280);
  __Pyx_GIVEREF(__pyx_tuple__280);
  __pyx_tuple__283 = PyTuple_Pack(2, __pyx_n_u__281, __pyx_n_u__282); if (unlikely(!__pyx_tuple__283)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__283);
  __Pyx_GIVEREF(__pyx_tuple__283);
  __pyx_tuple__286 = PyTuple_Pack(2, __pyx_n_u__284, __pyx_n_u__285); if (unlikely(!__pyx_tuple__286)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__286);
  __Pyx_GIVEREF(__pyx_tuple__286);
  __pyx_tuple__289 = PyTuple_Pack(2, __pyx_n_u__287, __pyx_n_u__288); if (unlikely(!__pyx_tuple__289)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__289);
  __Pyx_GIVEREF(__pyx_tuple__289);

  /* "neologdn.pyx":42
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 */
  __pyx_tuple__292 = PyTuple_Pack(2, __pyx_n_u__290, __pyx_n_u__291); if (unlikely(!__pyx_tuple__292)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__292);
  __Pyx_GIVEREF(__pyx_tuple__292);
  __pyx_tuple__295 = PyTuple_Pack(2, __pyx_n_u__293, __pyx_n_u__294); if (unlikely(!__pyx_tuple__295)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__295);
  __Pyx_GIVEREF(__pyx_tuple__295);
  __pyx_tuple__298 = PyTuple_Pack(2, __pyx_n_u__296, __pyx_n_u__297); if (unlikely(!__pyx_tuple__298)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__298);
  __Pyx_GIVEREF(__pyx_tuple__298);
  __pyx_tuple__301 = PyTuple_Pack(2, __pyx_n_u__299, __pyx_n_u__300); if (unlikely(!__pyx_tuple__301)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__301);
  __Pyx_GIVEREF(__pyx_tuple__301);
  __pyx_tuple__304 = PyTuple_Pack(2, __pyx_n_u__302, __pyx_n_u__303); if (unlikely(!__pyx_tuple__304)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__304);
  __Pyx_GIVEREF(__pyx_tuple__304);

  /* "neologdn.pyx":43
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''),
 */
  __pyx_tuple__307 = PyTuple_Pack(2, __pyx_n_u__305, __pyx_n_u__306); if (unlikely(!__pyx_tuple__307)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__307);
  __Pyx_GIVEREF(__pyx_tuple__307);
  __pyx_tuple__310 = PyTuple_Pack(2, __pyx_n_u__308, __pyx_n_u__309); if (unlikely(!__pyx_tuple__310)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__310);
  __Pyx_GIVEREF(__pyx_tuple__310);
  __pyx_tuple__313 = PyTuple_Pack(2, __pyx_n_u__311, __pyx_n_u__312); if (unlikely(!__pyx_tuple__313)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__313);
  __Pyx_GIVEREF(__pyx_tuple__313);

  /* "neologdn.pyx":44
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 */
  __pyx_tuple__316 = PyTuple_Pack(2, __pyx_n_u__314, __pyx_n_u__315); if (unlikely(!__pyx_tuple__316)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__316);
  __Pyx_GIVEREF(__pyx_tuple__316);
  __pyx_tuple__319 = PyTuple_Pack(2, __pyx_n_u__317, __pyx_n_u__318); if (unlikely(!__pyx_tuple__319)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__319);
  __Pyx_GIVEREF(__pyx_tuple__319);
  __pyx_tuple__322 = PyTuple_Pack(2, __pyx_n_u__320, __pyx_n_u__321); if (unlikely(!__pyx_tuple__322)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__322);
  __Pyx_GIVEREF(__pyx_tuple__322);
  __pyx_tuple__325 = PyTuple_Pack(2, __pyx_n_u__323, __pyx_n_u__324); if (unlikely(!__pyx_tuple__325)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__325);
  __Pyx_GIVEREF(__pyx_tuple__325);
  __pyx_tuple__328 = PyTuple_Pack(2, __pyx_n_u__326, __pyx_n_u__327); if (unlikely(!__pyx_tuple__328)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__328);
  __Pyx_GIVEREF(__pyx_tuple__328);

  /* "neologdn.pyx":45
 *     ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''),
 */
  __pyx_tuple__331 = PyTuple_Pack(2, __pyx_n_u__329, __pyx_n_u__330); if (unlikely(!__pyx_tuple__331)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__331);
  __Pyx_GIVEREF(__pyx_tuple__331);
  __pyx_tuple__334 = PyTuple_Pack(2, __pyx_n_u__332, __pyx_n_u__333); if (unlikely(!__pyx_tuple__334)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__334);
  __Pyx_GIVEREF(__pyx_tuple__334);
  __pyx_tuple__337 = PyTuple_Pack(2, __pyx_n_u__335, __pyx_n_u__336); if (unlikely(!__pyx_tuple__337)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__337);
  __Pyx_GIVEREF(__pyx_tuple__337);

  /* "neologdn.pyx":46
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 */
  __pyx_tuple__340 = PyTuple_Pack(2, __pyx_n_u__338, __pyx_n_u__339); if (unlikely(!__pyx_tuple__340)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__340);
  __Pyx_GIVEREF(__pyx_tuple__340);
  __pyx_tuple__343 = PyTuple_Pack(2, __pyx_n_u__341, __pyx_n_u__342); if (unlikely(!__pyx_tuple__343)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__343);
  __Pyx_GIVEREF(__pyx_tuple__343);
  __pyx_tuple__346 = PyTuple_Pack(2, __pyx_n_u__344, __pyx_n_u__345); if (unlikely(!__pyx_tuple__346)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__346);
  __Pyx_GIVEREF(__pyx_tuple__346);
  __pyx_tuple__349 = PyTuple_Pack(2, __pyx_n_u__347, __pyx_n_u__348); if (unlikely(!__pyx_tuple__349)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__349);
  __Pyx_GIVEREF(__pyx_tuple__349);
  __pyx_tuple__352 = PyTuple_Pack(2, __pyx_n_u__350, __pyx_n_u__351); if (unlikely(!__pyx_tuple__352)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__352);
  __Pyx_GIVEREF(__pyx_tuple__352);

  /* "neologdn.pyx":47
 *     ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', '')
 */
  __pyx_tuple__355 = PyTuple_Pack(2, __pyx_n_u__353, __pyx_n_u__354); if (unlikely(!__pyx_tuple__355)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__355);
  __Pyx_GIVEREF(__pyx_tuple__355);
  __pyx_tuple__358 = PyTuple_Pack(2, __pyx_n_u__356, __pyx_n_u__357); if (unlikely(!__pyx_tuple__358)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__358);
  __Pyx_GIVEREF(__pyx_tuple__358);
  __pyx_tuple__361 = PyTuple_Pack(2, __pyx_n_u__359, __pyx_n_u__360); if (unlikely(!__pyx_tuple__361)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__361);
  __Pyx_GIVEREF(__pyx_tuple__361);
  __pyx_tuple__364 = PyTuple_Pack(2, __pyx_n_u__362, __pyx_n_u__363); if (unlikely(!__pyx_tuple__364)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__364);
  __Pyx_GIVEREF(__pyx_tuple__364);

  /* "neologdn.pyx":48
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', '')
 * )
 */
  __pyx_tuple__367 = PyTuple_Pack(2, __pyx_kp_u__365, __pyx_kp_u__366); if (unlikely(!__pyx_tuple__367)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__367);
  __Pyx_GIVEREF(__pyx_tuple__367);
  __pyx_tuple__370 = PyTuple_Pack(2, __pyx_kp_u__368, __pyx_kp_u__369); if (unlikely(!__pyx_tuple__370)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__370);
  __Pyx_GIVEREF(__pyx_tuple__370);
  __pyx_tuple__373 = PyTuple_Pack(2, __pyx_kp_u__371, __pyx_kp_u__372); if (unlikely(!__pyx_tuple__373)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__373);
  __Pyx_GIVEREF(__pyx_tuple__373);
  __pyx_tuple__376 = PyTuple_Pack(2, __pyx_kp_u__374, __pyx_n_u__375); if (unlikely(!__pyx_tuple__376)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__376);
  __Pyx_GIVEREF(__pyx_tuple__376);
  __pyx_tuple__379 = PyTuple_Pack(2, __pyx_kp_u__377, __pyx_n_u__378); if (unlikely(!__pyx_tuple__379)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__379);
  __Pyx_GIVEREF(__pyx_tuple__379);

  /* "neologdn.pyx":49
 *     ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', '')             # <<<<<<<<<<<<<<
 * )
 * DIGIT = (
 */
  __pyx_tuple__382 = PyTuple_Pack(2, __pyx_kp_u__380, __pyx_kp_u__381); if (unlikely(!__pyx_tuple__382)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__382);
  __Pyx_GIVEREF(__pyx_tuple__382);
  __pyx_tuple__385 = PyTuple_Pack(2, __pyx_kp_u__383, __pyx_kp_u__384); if (unlikely(!__pyx_tuple__385)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__385);
  __Pyx_GIVEREF(__pyx_tuple__385);
  __pyx_tuple__388 = PyTuple_Pack(2, __pyx_n_u__386, __pyx_n_u__387); if (unlikely(!__pyx_tuple__388)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__388);
  __Pyx_GIVEREF(__pyx_tuple__388);

  /* "neologdn.pyx":36
 * )
 * KANA = (
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 */
  __pyx_tuple__389 = PyTuple_Pack(63, __pyx_tuple__202, __pyx_tuple__205, __pyx_tuple__208, __pyx_tuple__211, __pyx_tuple__214, __pyx_tuple__217, __pyx_tuple__220, __pyx_tuple__223, __pyx_tuple__226, __pyx_tuple__229, __pyx_tuple__232, __pyx_tuple__235, __pyx_tuple__238, __pyx_tuple__241, __pyx_tuple__244, __pyx_tuple__247, __pyx_tuple__250, __pyx_tuple__253, __pyx_tuple__256, __pyx_tuple__259, __pyx_tuple__262, __pyx_tuple__265, __pyx_tuple__268, __pyx_tuple__271, __pyx_tuple__274, __pyx_tuple__277, __pyx_tuple__280, __pyx_tuple__283, __pyx_tuple__286, __pyx_tuple__289, __pyx_tuple__292, __pyx_tuple__295, __pyx_tuple__298, __pyx_tuple__301, __pyx_tuple__304, __pyx_tuple__307, __pyx_tuple__310, __pyx_tuple__313, __pyx_tuple__316, __pyx_tuple__319, __pyx_tuple__322, __pyx_tuple__325, __pyx_tuple__328, __pyx_tuple__331, __pyx_tuple__334, __pyx_tuple__337, __pyx_tuple__340, __pyx_tuple__343, __pyx_tuple__346, __pyx_tuple__349, __pyx_tuple__352, __pyx_tuple__355, __pyx_tuple__358, __pyx_tuple__361, __pyx_tuple__364, __pyx_tuple__367, __pyx_tuple__370, __pyx_tuple__373, __pyx_tuple__376, __pyx_tuple__379, __pyx_tuple__382, __pyx_tuple__385, __pyx_tuple__388); if (unlikely(!__pyx_tuple__389)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__389);
  __Pyx_GIVEREF(__pyx_tuple__389);

  /* "neologdn.pyx":52
 * )
 * DIGIT = (
 *     ('', '0'), ('', '1'), ('', '2'), ('', '3'), ('', '4'),             # <<<<<<<<<<<<<<
 *     ('', '5'), ('', '6'), ('', '7'), ('', '8'), ('', '9')
 * )
 */
  __pyx_tuple__391 = PyTuple_Pack(2, __pyx_n_u__390, __pyx_kp_u_0); if (unlikely(!__pyx_tuple__391)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__391);
  __Pyx_GIVEREF(__pyx_tuple__391);
  __pyx_tuple__393 = PyTuple_Pack(2, __pyx_n_u__392, __pyx_kp_u_1); if (unlikely(!__pyx_tuple__393)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__393);
  __Pyx_GIVEREF(__pyx_tuple__393);
  __pyx_tuple__395 = PyTuple_Pack(2, __pyx_n_u__394, __pyx_kp_u_2); if (unlikely(!__pyx_tuple__395)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__395);
  __Pyx_GIVEREF(__pyx_tuple__395);
  __pyx_tuple__397 = PyTuple_Pack(2, __pyx_n_u__396, __pyx_kp_u_3); if (unlikely(!__pyx_tuple__397)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__397);
  __Pyx_GIVEREF(__pyx_tuple__397);
  __pyx_tuple__399 = PyTuple_Pack(2, __pyx_n_u__398, __pyx_kp_u_4); if (unlikely(!__pyx_tuple__399)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__399);
  __Pyx_GIVEREF(__pyx_tuple__399);

  /* "neologdn.pyx":53
 * DIGIT = (
 *     ('', '0'), ('', '1'), ('', '2'), ('', '3'), ('', '4'),
 *     ('', '5'), ('', '6'), ('', '7'), ('', '8'), ('', '9')             # <<<<<<<<<<<<<<
 * )
 * KANA_TEN = (
 */
  __pyx_tuple__401 = PyTuple_Pack(2, __pyx_n_u__400, __pyx_kp_u_5); if (unlikely(!__pyx_tuple__401)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__401);
  __Pyx_GIVEREF(__pyx_tuple__401);
  __pyx_tuple__403 = PyTuple_Pack(2, __pyx_n_u__402, __pyx_kp_u_6); if (unlikely(!__pyx_tuple__403)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__403);
  __Pyx_GIVEREF(__pyx_tuple__403);
  __pyx_tuple__405 = PyTuple_Pack(2, __pyx_n_u__404, __pyx_kp_u_7); if (unlikely(!__pyx_tuple__405)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__405);
  __Pyx_GIVEREF(__pyx_tuple__405);
  __pyx_tuple__407 = PyTuple_Pack(2, __pyx_n_u__406, __pyx_kp_u_8); if (unlikely(!__pyx_tuple__407)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__407);
  __Pyx_GIVEREF(__pyx_tuple__407);
  __pyx_tuple__409 = PyTuple_Pack(2, __pyx_n_u__408, __pyx_kp_u_9); if (unlikely(!__pyx_tuple__409)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__409);
  __Pyx_GIVEREF(__pyx_tuple__409);

  /* "neologdn.pyx":52
 * )
 * DIGIT = (
 *     ('', '0'), ('', '1'), ('', '2'), ('', '3'), ('', '4'),             # <<<<<<<<<<<<<<
 *     ('', '5'), ('', '6'), ('', '7'), ('', '8'), ('', '9')
 * )
 */
  __pyx_tuple__410 = PyTuple_Pack(10, __pyx_tuple__391, __pyx_tuple__393, __pyx_tuple__395, __pyx_tuple__397, __pyx_tuple__399, __pyx_tuple__401, __pyx_tuple__403, __pyx_tuple__405, __pyx_tuple__407, __pyx_tuple__409); if (unlikely(!__pyx_tuple__410)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__410);
  __Pyx_GIVEREF(__pyx_tuple__410);

  /* "neologdn.pyx":56
 * )
 * KANA_TEN = (
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 */
  __pyx_tuple__412 = PyTuple_Pack(2, __pyx_n_u__216, __pyx_n_u__411); if (unlikely(!__pyx_tuple__412)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__412);
  __Pyx_GIVEREF(__pyx_tuple__412);
  __pyx_tuple__414 = PyTuple_Pack(2, __pyx_n_u__219, __pyx_n_u__413); if (unlikely(!__pyx_tuple__414)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__414);
  __Pyx_GIVEREF(__pyx_tuple__414);
  __pyx_tuple__416 = PyTuple_Pack(2, __pyx_n_u__222, __pyx_n_u__415); if (unlikely(!__pyx_tuple__416)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__416);
  __Pyx_GIVEREF(__pyx_tuple__416);
  __pyx_tuple__418 = PyTuple_Pack(2, __pyx_n_u__225, __pyx_n_u__417); if (unlikely(!__pyx_tuple__418)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__418);
  __Pyx_GIVEREF(__pyx_tuple__418);
  __pyx_tuple__420 = PyTuple_Pack(2, __pyx_n_u__228, __pyx_n_u__419); if (unlikely(!__pyx_tuple__420)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__420);
  __Pyx_GIVEREF(__pyx_tuple__420);

  /* "neologdn.pyx":57
 * KANA_TEN = (
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 */
  __pyx_tuple__422 = PyTuple_Pack(2, __pyx_n_u__231, __pyx_n_u__421); if (unlikely(!__pyx_tuple__422)) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__422);
  __Pyx_GIVEREF(__pyx_tuple__422);
  __pyx_tuple__424 = PyTuple_Pack(2, __pyx_n_u__234, __pyx_n_u__423); if (unlikely(!__pyx_tuple__424)) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__424);
  __Pyx_GIVEREF(__pyx_tuple__424);
  __pyx_tuple__426 = PyTuple_Pack(2, __pyx_n_u__237, __pyx_n_u__425); if (unlikely(!__pyx_tuple__426)) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__426);
  __Pyx_GIVEREF(__pyx_tuple__426);
  __pyx_tuple__428 = PyTuple_Pack(2, __pyx_n_u__240, __pyx_n_u__427); if (unlikely(!__pyx_tuple__428)) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__428);
  __Pyx_GIVEREF(__pyx_tuple__428);
  __pyx_tuple__430 = PyTuple_Pack(2, __pyx_n_u__243, __pyx_n_u__429); if (unlikely(!__pyx_tuple__430)) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__430);
  __Pyx_GIVEREF(__pyx_tuple__430);

  /* "neologdn.pyx":58
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', '')
 */
  __pyx_tuple__432 = PyTuple_Pack(2, __pyx_n_u__246, __pyx_n_u__431); if (unlikely(!__pyx_tuple__432)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__432);
  __Pyx_GIVEREF(__pyx_tuple__432);
  __pyx_tuple__434 = PyTuple_Pack(2, __pyx_n_u__249, __pyx_n_u__433); if (unlikely(!__pyx_tuple__434)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__434);
  __Pyx_GIVEREF(__pyx_tuple__434);
  __pyx_tuple__436 = PyTuple_Pack(2, __pyx_n_u__252, __pyx_n_u__435); if (unlikely(!__pyx_tuple__436)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__436);
  __Pyx_GIVEREF(__pyx_tuple__436);
  __pyx_tuple__438 = PyTuple_Pack(2, __pyx_n_u__255, __pyx_n_u__437); if (unlikely(!__pyx_tuple__438)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__438);
  __Pyx_GIVEREF(__pyx_tuple__438);
  __pyx_tuple__440 = PyTuple_Pack(2, __pyx_n_u__258, __pyx_n_u__439); if (unlikely(!__pyx_tuple__440)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__440);
  __Pyx_GIVEREF(__pyx_tuple__440);

  /* "neologdn.pyx":59
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', '')
 * )
 */
  __pyx_tuple__442 = PyTuple_Pack(2, __pyx_n_u__276, __pyx_n_u__441); if (unlikely(!__pyx_tuple__442)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__442);
  __Pyx_GIVEREF(__pyx_tuple__442);
  __pyx_tuple__444 = PyTuple_Pack(2, __pyx_n_u__279, __pyx_n_u__443); if (unlikely(!__pyx_tuple__444)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__444);
  __Pyx_GIVEREF(__pyx_tuple__444);
  __pyx_tuple__446 = PyTuple_Pack(2, __pyx_n_u__282, __pyx_n_u__445); if (unlikely(!__pyx_tuple__446)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__446);
  __Pyx_GIVEREF(__pyx_tuple__446);
  __pyx_tuple__448 = PyTuple_Pack(2, __pyx_n_u__285, __pyx_n_u__447); if (unlikely(!__pyx_tuple__448)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__448);
  __Pyx_GIVEREF(__pyx_tuple__448);
  __pyx_tuple__450 = PyTuple_Pack(2, __pyx_n_u__288, __pyx_n_u__449); if (unlikely(!__pyx_tuple__450)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__450);
  __Pyx_GIVEREF(__pyx_tuple__450);

  /* "neologdn.pyx":60
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', '')             # <<<<<<<<<<<<<<
 * )
 * KANA_MARU = (
 */
  __pyx_tuple__452 = PyTuple_Pack(2, __pyx_n_u__207, __pyx_n_u__451); if (unlikely(!__pyx_tuple__452)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__452);
  __Pyx_GIVEREF(__pyx_tuple__452);
  __pyx_tuple__455 = PyTuple_Pack(2, __pyx_n_u__453, __pyx_n_u__454); if (unlikely(!__pyx_tuple__455)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__455);
  __Pyx_GIVEREF(__pyx_tuple__455);

  /* "neologdn.pyx":56
 * )
 * KANA_TEN = (
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 */
  __pyx_tuple__456 = PyTuple_Pack(22, __pyx_tuple__412, __pyx_tuple__414, __pyx_tuple__416, __pyx_tuple__418, __pyx_tuple__420, __pyx_tuple__422, __pyx_tuple__424, __pyx_tuple__426, __pyx_tuple__428, __pyx_tuple__430, __pyx_tuple__432, __pyx_tuple__434, __pyx_tuple__436, __pyx_tuple__438, __pyx_tuple__440, __pyx_tuple__442, __pyx_tuple__444, __pyx_tuple__446, __pyx_tuple__448, __pyx_tuple__450, __pyx_tuple__452, __pyx_tuple__455); if (unlikely(!__pyx_tuple__456)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__456);
  __Pyx_GIVEREF(__pyx_tuple__456);

  /* "neologdn.pyx":63
 * )
 * KANA_MARU = (
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', '')
 * )
 */
  __pyx_tuple__458 = PyTuple_Pack(2, __pyx_n_u__276, __pyx_n_u__457); if (unlikely(!__pyx_tuple__458)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__458);
  __Pyx_GIVEREF(__pyx_tuple__458);
  __pyx_tuple__460 = PyTuple_Pack(2, __pyx_n_u__279, __pyx_n_u__459); if (unlikely(!__pyx_tuple__460)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__460);
  __Pyx_GIVEREF(__pyx_tuple__460);
  __pyx_tuple__462 = PyTuple_Pack(2, __pyx_n_u__282, __pyx_n_u__461); if (unlikely(!__pyx_tuple__462)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__462);
  __Pyx_GIVEREF(__pyx_tuple__462);
  __pyx_tuple__464 = PyTuple_Pack(2, __pyx_n_u__285, __pyx_n_u__463); if (unlikely(!__pyx_tuple__464)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__464);
  __Pyx_GIVEREF(__pyx_tuple__464);
  __pyx_tuple__466 = PyTuple_Pack(2, __pyx_n_u__288, __pyx_n_u__465); if (unlikely(!__pyx_tuple__466)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__466);
  __Pyx_GIVEREF(__pyx_tuple__466);

  /* "neologdn.pyx":64
 * KANA_MARU = (
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', '')             # <<<<<<<<<<<<<<
 * )
 * 
 */
  __pyx_tuple__469 = PyTuple_Pack(2, __pyx_n_u__467, __pyx_n_u__468); if (unlikely(!__pyx_tuple__469)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__469);
  __Pyx_GIVEREF(__pyx_tuple__469);
  __pyx_tuple__472 = PyTuple_Pack(2, __pyx_n_u__470, __pyx_n_u__471); if (unlikely(!__pyx_tuple__472)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__472);
  __Pyx_GIVEREF(__pyx_tuple__472);
  __pyx_tuple__475 = PyTuple_Pack(2, __pyx_n_u__473, __pyx_n_u__474); if (unlikely(!__pyx_tuple__475)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__475);
  __Pyx_GIVEREF(__pyx_tuple__475);
  __pyx_tuple__478 = PyTuple_Pack(2, __pyx_n_u__476, __pyx_n_u__477); if (unlikely(!__pyx_tuple__478)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__478);
  __Pyx_GIVEREF(__pyx_tuple__478);
  __pyx_tuple__481 = PyTuple_Pack(2, __pyx_n_u__479, __pyx_n_u__480); if (unlikely(!__pyx_tuple__481)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__481);
  __Pyx_GIVEREF(__pyx_tuple__481);

  /* "neologdn.pyx":63
 * )
 * KANA_MARU = (
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', '')
 * )
 */
  __pyx_tuple__482 = PyTuple_Pack(10, __pyx_tuple__458, __pyx_tuple__460, __pyx_tuple__462, __pyx_tuple__464, __pyx_tuple__466, __pyx_tuple__469, __pyx_tuple__472, __pyx_tuple__475, __pyx_tuple__478, __pyx_tuple__481); if (unlikely(!__pyx_tuple__482)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__482);
  __Pyx_GIVEREF(__pyx_tuple__482);

  /* "neologdn.pyx":67
 * )
 * 
 * HIPHENS = ('', '', '', '', '', '', '', '', '', '')             # <<<<<<<<<<<<<<
 * CHOONPUS = ('', '', '', '', '', '', '', '')
 * TILDES = ('~', '', '', '', '', '')
 */
  __pyx_tuple__492 = PyTuple_Pack(10, __pyx_kp_u__483, __pyx_kp_u__484, __pyx_kp_u__485, __pyx_kp_u__486, __pyx_kp_u__487, __pyx_kp_u__488, __pyx_kp_u__489, __pyx_kp_u__490, __pyx_kp_u__491, __pyx_kp_u__142); if (unlikely(!__pyx_tuple__492)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__492);
  __Pyx_GIVEREF(__pyx_tuple__492);

  /* "neologdn.pyx":68
 * 
 * HIPHENS = ('', '', '', '', '', '', '', '', '', '')
 * CHOONPUS = ('', '', '', '', '', '', '', '')             # <<<<<<<<<<<<<<
 * TILDES = ('~', '', '', '', '', '')
 * 
 */
  __pyx_tuple__499 = PyTuple_Pack(8, __pyx_kp_u__493, __pyx_kp_u__494, __pyx_n_u__386, __pyx_kp_u__495, __pyx_kp_u__496, __pyx_kp_u__497, __pyx_kp_u__498, __pyx_n_u__387); if (unlikely(!__pyx_tuple__499)) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__499);
  __Pyx_GIVEREF(__pyx_tuple__499);

  /* "neologdn.pyx":69
 * HIPHENS = ('', '', '', '', '', '', '', '', '', '')
 * CHOONPUS = ('', '', '', '', '', '', '', '')
 * TILDES = ('~', '', '', '', '', '')             # <<<<<<<<<<<<<<
 * 
 * SPACE = (' ', '')
 */
  __pyx_tuple__506 = PyTuple_Pack(6, __pyx_kp_u__500, __pyx_kp_u__501, __pyx_kp_u__502, __pyx_kp_u__503, __pyx_kp_u__504, __pyx_kp_u__505); if (unlikely(!__pyx_tuple__506)) __PYX_ERR(0, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__506);
  __Pyx_GIVEREF(__pyx_tuple__506);

  /* "neologdn.pyx":71
 * TILDES = ('~', '', '', '', '', '')
 * 
 * SPACE = (' ', '')             # <<<<<<<<<<<<<<
 * 
 * cdef unordered_map[Py_UNICODE, Py_UNICODE] conversion_map, kana_ten_map, kana_maru_map
 */
  __pyx_tuple__509 = PyTuple_Pack(2, __pyx_kp_u__507, __pyx_kp_u__508); if (unlikely(!__pyx_tuple__509)) __PYX_ERR(0, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__509);
  __Pyx_GIVEREF(__pyx_tuple__509);

  /* "neologdn.pyx":86
 * 
 * char_codes = itertools.chain(
 *     range(19968, 40960),  # CJK UNIFIED IDEOGRAPHS             # <<<<<<<<<<<<<<
 *     range(12352, 12448),  # HIRAGANA
 *     range(12448, 12544),  # KATAKANA
 */
  __pyx_tuple__510 = PyTuple_Pack(2, __pyx_int_19968, __pyx_int_40960); if (unlikely(!__pyx_tuple__510)) __PYX_ERR(0, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__510);
  __Pyx_GIVEREF(__pyx_tuple__510);

  /* "neologdn.pyx":87
 * char_codes = itertools.chain(
 *     range(19968, 40960),  # CJK UNIFIED IDEOGRAPHS
 *     range(12352, 12448),  # HIRAGANA             # <<<<<<<<<<<<<<
 *     range(12448, 12544),  # KATAKANA
 *     range(12289, 12352),  # CJK SYMBOLS AND PUNCTUATION
 */
  __pyx_tuple__511 = PyTuple_Pack(2, __pyx_int_12352, __pyx_int_12448); if (unlikely(!__pyx_tuple__511)) __PYX_ERR(0, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__511);
  __Pyx_GIVEREF(__pyx_tuple__511);

  /* "neologdn.pyx":88
 *     range(19968, 40960),  # CJK UNIFIED IDEOGRAPHS
 *     range(12352, 12448),  # HIRAGANA
 *     range(12448, 12544),  # KATAKANA             # <<<<<<<<<<<<<<
 *     range(12289, 12352),  # CJK SYMBOLS AND PUNCTUATION
 *     range(65280, 65520)   # HALFWIDTH AND FULLWIDTH FORMS
 */
  __pyx_tuple__512 = PyTuple_Pack(2, __pyx_int_12448, __pyx_int_12544); if (unlikely(!__pyx_tuple__512)) __PYX_ERR(0, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__512);
  __Pyx_GIVEREF(__pyx_tuple__512);

  /* "neologdn.pyx":89
 *     range(12352, 12448),  # HIRAGANA
 *     range(12448, 12544),  # KATAKANA
 *     range(12289, 12352),  # CJK SYMBOLS AND PUNCTUATION             # <<<<<<<<<<<<<<
 *     range(65280, 65520)   # HALFWIDTH AND FULLWIDTH FORMS
 * )
 */
  __pyx_tuple__513 = PyTuple_Pack(2, __pyx_int_12289, __pyx_int_12352); if (unlikely(!__pyx_tuple__513)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__513);
  __Pyx_GIVEREF(__pyx_tuple__513);

  /* "neologdn.pyx":90
 *     range(12448, 12544),  # KATAKANA
 *     range(12289, 12352),  # CJK SYMBOLS AND PUNCTUATION
 *     range(65280, 65520)   # HALFWIDTH AND FULLWIDTH FORMS             # <<<<<<<<<<<<<<
 * )
 * if version_info >= (3, 0):
 */
  __pyx_tuple__514 = PyTuple_Pack(2, __pyx_int_65280, __pyx_int_65520); if (unlikely(!__pyx_tuple__514)) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__514);
  __Pyx_GIVEREF(__pyx_tuple__514);

  /* "neologdn.pyx":92
 *     range(65280, 65520)   # HALFWIDTH AND FULLWIDTH FORMS
 * )
 * if version_info >= (3, 0):             # <<<<<<<<<<<<<<
 *     chr_func = chr
 * else:
 */
  __pyx_tuple__515 = PyTuple_Pack(2, __pyx_int_3, __pyx_int_0); if (unlikely(!__pyx_tuple__515)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__515);
  __Pyx_GIVEREF(__pyx_tuple__515);

  /* "neologdn.pyx":99
 *     blocks.insert(c)
 * 
 * for c in map(chr_func, range(128)):             # <<<<<<<<<<<<<<
 *     basic_latin.insert(c)
 * 
 */
  __pyx_tuple__516 = PyTuple_Pack(1, __pyx_int_128); if (unlikely(!__pyx_tuple__516)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__516);
  __Pyx_GIVEREF(__pyx_tuple__516);
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_128 = PyInt_FromLong(128); if (unlikely(!__pyx_int_128)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12289 = PyInt_FromLong(12289L); if (unlikely(!__pyx_int_12289)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12352 = PyInt_FromLong(12352L); if (unlikely(!__pyx_int_12352)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12448 = PyInt_FromLong(12448L); if (unlikely(!__pyx_int_12448)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12544 = PyInt_FromLong(12544L); if (unlikely(!__pyx_int_12544)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_19968 = PyInt_FromLong(19968L); if (unlikely(!__pyx_int_19968)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_40960 = PyInt_FromLong(40960L); if (unlikely(!__pyx_int_40960)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_65280 = PyInt_FromLong(65280L); if (unlikely(!__pyx_int_65280)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_65520 = PyInt_FromLong(65520L); if (unlikely(!__pyx_int_65520)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC initneologdn(void); /*proto*/
PyMODINIT_FUNC initneologdn(void)
#else
PyMODINIT_FUNC PyInit_neologdn(void); /*proto*/
PyMODINIT_FUNC PyInit_neologdn(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        result = PyDict_SetItemString(moddict, to_name, value);
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__") < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__") < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__") < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__") < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static int __pyx_pymod_exec_neologdn(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  Py_UNICODE __pyx_t_9;
  Py_UNICODE __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m && __pyx_m == __pyx_pyinit_module) return 0;
  #endif
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit_neologdn(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("neologdn", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_neologdn) {
    if (PyObject_SetAttrString(__pyx_m, "__name__", __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "neologdn")) {
      if (unlikely(PyDict_SetItemString(modules, "neologdn", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global init code ---*/
  /*--- Variable export code ---*/
  /*--- Function export code ---*/
  /*--- Type init code ---*/
  /*--- Type import code ---*/
  /*--- Variable import code ---*/
  /*--- Function import code ---*/
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "neologdn.pyx":5
 * 
 * from __future__ import unicode_literals
 * import itertools             # <<<<<<<<<<<<<<
 * from sys import version_info
 * from libc.stdlib cimport malloc, free
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_itertools, 0, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_itertools, __pyx_t_1) < 0) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "neologdn.pyx":6
 * from __future__ import unicode_literals
 * import itertools
 * from sys import version_info             # <<<<<<<<<<<<<<
 * from libc.stdlib cimport malloc, free
 * from libcpp.unordered_map cimport unordered_map
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_version_info);
  __Pyx_GIVEREF(__pyx_n_s_version_info);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_version_info);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_sys, __pyx_t_1, -1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_version_info); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_version_info, __pyx_t_1) < 0) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "neologdn.pyx":11
 * from libcpp.unordered_set cimport unordered_set
 * 
 * VERSION = (0, 3)             # <<<<<<<<<<<<<<
 * __version__ = '0.3'
 * 
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_VERSION, __pyx_tuple_) < 0) __PYX_ERR(0, 11, __pyx_L1_error)

  /* "neologdn.pyx":12
 * 
 * VERSION = (0, 3)
 * __version__ = '0.3'             # <<<<<<<<<<<<<<
 * 
 * ASCII = (
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_version, __pyx_kp_u_0_3) < 0) __PYX_ERR(0, 12, __pyx_L1_error)

  /* "neologdn.pyx":15
 * 
 * ASCII = (
 *     ('', 'a'), ('', 'b'), ('', 'c'), ('', 'd'), ('', 'e'),             # <<<<<<<<<<<<<<
 *     ('', 'f'), ('', 'g'), ('', 'h'), ('', 'i'), ('', 'j'),
 *     ('', 'k'), ('', 'l'), ('', 'm'), ('', 'n'), ('', 'o'),
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ASCII, __pyx_tuple__199) < 0) __PYX_ERR(0, 14, __pyx_L1_error)

  /* "neologdn.pyx":36
 * )
 * KANA = (
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_KANA, __pyx_tuple__389) < 0) __PYX_ERR(0, 35, __pyx_L1_error)

  /* "neologdn.pyx":52
 * )
 * DIGIT = (
 *     ('', '0'), ('', '1'), ('', '2'), ('', '3'), ('', '4'),             # <<<<<<<<<<<<<<
 *     ('', '5'), ('', '6'), ('', '7'), ('', '8'), ('', '9')
 * )
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_DIGIT, __pyx_tuple__410) < 0) __PYX_ERR(0, 51, __pyx_L1_error)

  /* "neologdn.pyx":56
 * )
 * KANA_TEN = (
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_KANA_TEN, __pyx_tuple__456) < 0) __PYX_ERR(0, 55, __pyx_L1_error)

  /* "neologdn.pyx":63
 * )
 * KANA_MARU = (
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', ''),             # <<<<<<<<<<<<<<
 *     ('', ''), ('', ''), ('', ''), ('', ''), ('', '')
 * )
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_KANA_MARU, __pyx_tuple__482) < 0) __PYX_ERR(0, 62, __pyx_L1_error)

  /* "neologdn.pyx":67
 * )
 * 
 * HIPHENS = ('', '', '', '', '', '', '', '', '', '')             # <<<<<<<<<<<<<<
 * CHOONPUS = ('', '', '', '', '', '', '', '')
 * TILDES = ('~', '', '', '', '', '')
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_HIPHENS, __pyx_tuple__492) < 0) __PYX_ERR(0, 67, __pyx_L1_error)

  /* "neologdn.pyx":68
 * 
 * HIPHENS = ('', '', '', '', '', '', '', '', '', '')
 * CHOONPUS = ('', '', '', '', '', '', '', '')             # <<<<<<<<<<<<<<
 * TILDES = ('~', '', '', '', '', '')
 * 
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CHOONPUS, __pyx_tuple__499) < 0) __PYX_ERR(0, 68, __pyx_L1_error)

  /* "neologdn.pyx":69
 * HIPHENS = ('', '', '', '', '', '', '', '', '', '')
 * CHOONPUS = ('', '', '', '', '', '', '', '')
 * TILDES = ('~', '', '', '', '', '')             # <<<<<<<<<<<<<<
 * 
 * SPACE = (' ', '')
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_TILDES, __pyx_tuple__506) < 0) __PYX_ERR(0, 69, __pyx_L1_error)

  /* "neologdn.pyx":71
 * TILDES = ('~', '', '', '', '', '')
 * 
 * SPACE = (' ', '')             # <<<<<<<<<<<<<<
 * 
 * cdef unordered_map[Py_UNICODE, Py_UNICODE] conversion_map, kana_ten_map, kana_maru_map
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_SPACE, __pyx_tuple__509) < 0) __PYX_ERR(0, 71, __pyx_L1_error)

  /* "neologdn.pyx":76
 * cdef unordered_set[Py_UNICODE] blocks, basic_latin
 * 
 * for (before, after) in (ASCII + DIGIT + KANA):             # <<<<<<<<<<<<<<
 *     conversion_map[before] = after
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ASCII); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_DIGIT); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_KANA); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 76, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 76, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 76, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 76, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 76, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 76, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_5(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 76, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      #if !CYTHON_COMPILING_IN_PYPY
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 76, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 76, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 76, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 76, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
      index = 0; __pyx_t_3 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_3)) goto __pyx_L4_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L4_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(0, 76, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L5_unpacking_done;
      __pyx_L4_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 76, __pyx_L1_error)
      __pyx_L5_unpacking_done:;
    }
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_before, __pyx_t_3) < 0) __PYX_ERR(0, 76, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_after, __pyx_t_6) < 0) __PYX_ERR(0, 76, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "neologdn.pyx":77
 * 
 * for (before, after) in (ASCII + DIGIT + KANA):
 *     conversion_map[before] = after             # <<<<<<<<<<<<<<
 * 
 * for (before, after) in KANA_TEN:
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_after); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = __Pyx_PyObject_AsPy_UNICODE(__pyx_t_2); if (unlikely((__pyx_t_9 == (Py_UNICODE)-1) && PyErr_Occurred())) __PYX_ERR(0, 77, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_before); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = __Pyx_PyObject_AsPy_UNICODE(__pyx_t_2); if (unlikely((__pyx_t_10 == (Py_UNICODE)-1) && PyErr_Occurred())) __PYX_ERR(0, 77, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    (__pyx_v_8neologdn_conversion_map[__pyx_t_10]) = __pyx_t_9;

    /* "neologdn.pyx":76
 * cdef unordered_set[Py_UNICODE] blocks, basic_latin
 * 
 * for (before, after) in (ASCII + DIGIT + KANA):             # <<<<<<<<<<<<<<
 *     conversion_map[before] = after
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "neologdn.pyx":79
 *     conversion_map[before] = after
 * 
 * for (before, after) in KANA_TEN:             # <<<<<<<<<<<<<<
 *     kana_ten_map[before] = after
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_KANA_TEN); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 79, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 79, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 79, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 79, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 79, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 79, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 79, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
      PyObject* sequence = __pyx_t_1;
      #if !CYTHON_COMPILING_IN_PYPY
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 79, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_3);
      #else
      __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 79, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 79, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 79, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
      index = 0; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L8_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      index = 1; __pyx_t_3 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_3)) goto __pyx_L8_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(0, 79, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L9_unpacking_done;
      __pyx_L8_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 79, __pyx_L1_error)
      __pyx_L9_unpacking_done:;
    }
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_before, __pyx_t_6) < 0) __PYX_ERR(0, 79, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_after, __pyx_t_3) < 0) __PYX_ERR(0, 79, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "neologdn.pyx":80
 * 
 * for (before, after) in KANA_TEN:
 *     kana_ten_map[before] = after             # <<<<<<<<<<<<<<
 * 
 * for (before, after) in KANA_MARU:
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_after); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyObject_AsPy_UNICODE(__pyx_t_1); if (unlikely((__pyx_t_9 == (Py_UNICODE)-1) && PyErr_Occurred())) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_before); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_10 = __Pyx_PyObject_AsPy_UNICODE(__pyx_t_1); if (unlikely((__pyx_t_10 == (Py_UNICODE)-1) && PyErr_Occurred())) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    (__pyx_v_8neologdn_kana_ten_map[__pyx_t_10]) = __pyx_t_9;

    /* "neologdn.pyx":79
 *     conversion_map[before] = after
 * 
 * for (before, after) in KANA_TEN:             # <<<<<<<<<<<<<<
 *     kana_ten_map[before] = after
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "neologdn.pyx":82
 *     kana_ten_map[before] = after
 * 
 * for (before, after) in KANA_MARU:             # <<<<<<<<<<<<<<
 *     kana_maru_map[before] = after
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_KANA_MARU); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 82, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 82, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 82, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 82, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 82, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_5(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 82, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      #if !CYTHON_COMPILING_IN_PYPY
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 82, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 82, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 82, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 82, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
      index = 0; __pyx_t_3 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_3)) goto __pyx_L12_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L12_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(0, 82, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L13_unpacking_done;
      __pyx_L12_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 82, __pyx_L1_error)
      __pyx_L13_unpacking_done:;
    }
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_before, __pyx_t_3) < 0) __PYX_ERR(0, 82, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_after, __pyx_t_6) < 0) __PYX_ERR(0, 82, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "neologdn.pyx":83
 * 
 * for (before, after) in KANA_MARU:
 *     kana_maru_map[before] = after             # <<<<<<<<<<<<<<
 * 
 * char_codes = itertools.chain(
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_after); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = __Pyx_PyObject_AsPy_UNICODE(__pyx_t_2); if (unlikely((__pyx_t_9 == (Py_UNICODE)-1) && PyErr_Occurred())) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_before); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = __Pyx_PyObject_AsPy_UNICODE(__pyx_t_2); if (unlikely((__pyx_t_10 == (Py_UNICODE)-1) && PyErr_Occurred())) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    (__pyx_v_8neologdn_kana_maru_map[__pyx_t_10]) = __pyx_t_9;

    /* "neologdn.pyx":82
 *     kana_ten_map[before] = after
 * 
 * for (before, after) in KANA_MARU:             # <<<<<<<<<<<<<<
 *     kana_maru_map[before] = after
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "neologdn.pyx":85
 *     kana_maru_map[before] = after
 * 
 * char_codes = itertools.chain(             # <<<<<<<<<<<<<<
 *     range(19968, 40960),  # CJK UNIFIED IDEOGRAPHS
 *     range(12352, 12448),  # HIRAGANA
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_itertools); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_chain); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "neologdn.pyx":86
 * 
 * char_codes = itertools.chain(
 *     range(19968, 40960),  # CJK UNIFIED IDEOGRAPHS             # <<<<<<<<<<<<<<
 *     range(12352, 12448),  # HIRAGANA
 *     range(12448, 12544),  # KATAKANA
 */
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_tuple__510, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "neologdn.pyx":87
 * char_codes = itertools.chain(
 *     range(19968, 40960),  # CJK UNIFIED IDEOGRAPHS
 *     range(12352, 12448),  # HIRAGANA             # <<<<<<<<<<<<<<
 *     range(12448, 12544),  # KATAKANA
 *     range(12289, 12352),  # CJK SYMBOLS AND PUNCTUATION
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_tuple__511, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "neologdn.pyx":88
 *     range(19968, 40960),  # CJK UNIFIED IDEOGRAPHS
 *     range(12352, 12448),  # HIRAGANA
 *     range(12448, 12544),  # KATAKANA             # <<<<<<<<<<<<<<
 *     range(12289, 12352),  # CJK SYMBOLS AND PUNCTUATION
 *     range(65280, 65520)   # HALFWIDTH AND FULLWIDTH FORMS
 */
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_tuple__512, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "neologdn.pyx":89
 *     range(12352, 12448),  # HIRAGANA
 *     range(12448, 12544),  # KATAKANA
 *     range(12289, 12352),  # CJK SYMBOLS AND PUNCTUATION             # <<<<<<<<<<<<<<
 *     range(65280, 65520)   # HALFWIDTH AND FULLWIDTH FORMS
 * )
 */
  __pyx_t_11 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_tuple__513, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);

  /* "neologdn.pyx":90
 *     range(12448, 12544),  # KATAKANA
 *     range(12289, 12352),  # CJK SYMBOLS AND PUNCTUATION
 *     range(65280, 65520)   # HALFWIDTH AND FULLWIDTH FORMS             # <<<<<<<<<<<<<<
 * )
 * if version_info >= (3, 0):
 */
  __pyx_t_12 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_tuple__514, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_13 = NULL;
  __pyx_t_14 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_14 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_6)) {
    PyObject *__pyx_temp[6] = {__pyx_t_13, __pyx_t_2, __pyx_t_3, __pyx_t_7, __pyx_t_11, __pyx_t_12};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_14, 5+__pyx_t_14); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 85, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
    PyObject *__pyx_temp[6] = {__pyx_t_13, __pyx_t_2, __pyx_t_3, __pyx_t_7, __pyx_t_11, __pyx_t_12};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_14, 5+__pyx_t_14); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 85, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  } else
  #endif
  {
    __pyx_t_15 = PyTuple_New(5+__pyx_t_14); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 85, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    if (__pyx_t_13) {
      __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_13); __pyx_t_13 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_15, 0+__pyx_t_14, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_15, 1+__pyx_t_14, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_15, 2+__pyx_t_14, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_11);
    PyTuple_SET_ITEM(__pyx_t_15, 3+__pyx_t_14, __pyx_t_11);
    __Pyx_GIVEREF(__pyx_t_12);
    PyTuple_SET_ITEM(__pyx_t_15, 4+__pyx_t_14, __pyx_t_12);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_t_7 = 0;
    __pyx_t_11 = 0;
    __pyx_t_12 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_15, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 85, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_char_codes, __pyx_t_1) < 0) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "neologdn.pyx":92
 *     range(65280, 65520)   # HALFWIDTH AND FULLWIDTH FORMS
 * )
 * if version_info >= (3, 0):             # <<<<<<<<<<<<<<
 *     chr_func = chr
 * else:
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_version_info); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyObject_RichCompare(__pyx_t_1, __pyx_tuple__515, Py_GE); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_16 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_16 < 0)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__pyx_t_16) {

    /* "neologdn.pyx":93
 * )
 * if version_info >= (3, 0):
 *     chr_func = chr             # <<<<<<<<<<<<<<
 * else:
 *     chr_func = locals()['__builtins__'].unichr
 */
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_chr_func, __pyx_builtin_chr) < 0) __PYX_ERR(0, 93, __pyx_L1_error)

    /* "neologdn.pyx":92
 *     range(65280, 65520)   # HALFWIDTH AND FULLWIDTH FORMS
 * )
 * if version_info >= (3, 0):             # <<<<<<<<<<<<<<
 *     chr_func = chr
 * else:
 */
    goto __pyx_L14;
  }

  /* "neologdn.pyx":95
 *     chr_func = chr
 * else:
 *     chr_func = locals()['__builtins__'].unichr             # <<<<<<<<<<<<<<
 * for c in map(chr_func, char_codes):
 *     blocks.insert(c)
 */
  /*else*/ {
    __pyx_t_6 = __Pyx_Globals(); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_t_6, __pyx_n_u_builtins); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_unichr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_chr_func, __pyx_t_6) < 0) __PYX_ERR(0, 95, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_L14:;

  /* "neologdn.pyx":96
 * else:
 *     chr_func = locals()['__builtins__'].unichr
 * for c in map(chr_func, char_codes):             # <<<<<<<<<<<<<<
 *     blocks.insert(c)
 * 
 */
  __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_chr_func); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 96, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_char_codes); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 96, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_15 = PyTuple_New(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 96, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_t_1);
  __pyx_t_6 = 0;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_15, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 96, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_15 = __pyx_t_1; __Pyx_INCREF(__pyx_t_15); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_15 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 96, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_5 = Py_TYPE(__pyx_t_15)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 96, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_15))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_15)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_15, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 96, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_15, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 96, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_15)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_15, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 96, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_15, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 96, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_5(__pyx_t_15);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 96, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_c, __pyx_t_1) < 0) __PYX_ERR(0, 96, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "neologdn.pyx":97
 *     chr_func = locals()['__builtins__'].unichr
 * for c in map(chr_func, char_codes):
 *     blocks.insert(c)             # <<<<<<<<<<<<<<
 * 
 * for c in map(chr_func, range(128)):
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_c); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 97, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyObject_AsPy_UNICODE(__pyx_t_1); if (unlikely((__pyx_t_9 == (Py_UNICODE)-1) && PyErr_Occurred())) __PYX_ERR(0, 97, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_8neologdn_blocks.insert(__pyx_t_9);

    /* "neologdn.pyx":96
 * else:
 *     chr_func = locals()['__builtins__'].unichr
 * for c in map(chr_func, char_codes):             # <<<<<<<<<<<<<<
 *     blocks.insert(c)
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

  /* "neologdn.pyx":99
 *     blocks.insert(c)
 * 
 * for c in map(chr_func, range(128)):             # <<<<<<<<<<<<<<
 *     basic_latin.insert(c)
 * 
 */
  __pyx_t_15 = __Pyx_GetModuleGlobalName(__pyx_n_s_chr_func); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_tuple__516, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_15);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_15);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
  __pyx_t_15 = 0;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_6 = __pyx_t_1; __Pyx_INCREF(__pyx_t_6); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 99, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = Py_TYPE(__pyx_t_6)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 99, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_6))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_6)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 99, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_6, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 99, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_6)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 99, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_6, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 99, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_5(__pyx_t_6);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 99, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_c, __pyx_t_1) < 0) __PYX_ERR(0, 99, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "neologdn.pyx":100
 * 
 * for c in map(chr_func, range(128)):
 *     basic_latin.insert(c)             # <<<<<<<<<<<<<<
 * 
 * del ASCII, KANA, DIGIT, KANA_TEN, KANA_MARU, char_codes, version_info, chr_func
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_c); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyObject_AsPy_UNICODE(__pyx_t_1); if (unlikely((__pyx_t_9 == (Py_UNICODE)-1) && PyErr_Occurred())) __PYX_ERR(0, 100, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_8neologdn_basic_latin.insert(__pyx_t_9);

    /* "neologdn.pyx":99
 *     blocks.insert(c)
 * 
 * for c in map(chr_func, range(128)):             # <<<<<<<<<<<<<<
 *     basic_latin.insert(c)
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "neologdn.pyx":102
 *     basic_latin.insert(c)
 * 
 * del ASCII, KANA, DIGIT, KANA_TEN, KANA_MARU, char_codes, version_info, chr_func             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_ASCII) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_KANA) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_DIGIT) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_KANA_TEN) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_KANA_MARU) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_char_codes) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_version_info) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_chr_func) < 0) __PYX_ERR(0, 102, __pyx_L1_error)

  /* "neologdn.pyx":1
 * # distutils: language=c++             # <<<<<<<<<<<<<<
 * # -*- coding: utf-8 -*-
 * 
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_6) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_15);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init neologdn", 0, __pyx_lineno, __pyx_filename);
    }
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init neologdn");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* unicode_iter */
static CYTHON_INLINE int __Pyx_init_unicode_iteration(
    PyObject* ustring, Py_ssize_t *length, void** data, int *kind) {
#if CYTHON_PEP393_ENABLED
    if (unlikely(__Pyx_PyUnicode_READY(ustring) < 0)) return -1;
    *kind   = PyUnicode_KIND(ustring);
    *length = PyUnicode_GET_LENGTH(ustring);
    *data   = PyUnicode_DATA(ustring);
#else
    *kind   = 0;
    *length = PyUnicode_GET_SIZE(ustring);
    *data   = (void*)PyUnicode_AS_UNICODE(ustring);
#endif
    return 0;
}

/* GetModuleGlobalName */
static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name) {
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
    result = PyDict_GetItem(__pyx_d, name);
    if (likely(result)) {
        Py_INCREF(result);
    } else {
#else
    result = PyObject_GetItem(__pyx_d, name);
    if (!result) {
        PyErr_Clear();
#endif
        result = __Pyx_GetBuiltinName(name);
    }
    return result;
}

/* RaiseDoubleKeywords */
  static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
  static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* RaiseArgTupleInvalid */
  static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* ArgTypeTest */
  static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

/* Import */
  static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
  static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* RaiseTooManyValuesToUnpack */
  static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
  static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
  static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_FAST_THREAD_STATE
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

/* UnpackItemEndCheck */
  static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

/* PyObjectCall */
  #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyFunctionFastCall */
  #if CYTHON_FAST_PYCALL
#include "frameobject.h"
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = f->f_localsplus;
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyCFunctionFastCall */
  #if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)meth)) (self, args, nargs);
    }
}
#endif

/* PyErrFetchRestore */
  #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* CLineInTraceback */
  #ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
      use_cline = PyDict_GetItem(*cython_runtime_dict, __pyx_n_s_cline_in_traceback);
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (PyObject_Not(use_cline) != 0) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
  static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, (size_t)new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
  #include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* ObjectAsPyUnicode */
  static CYTHON_INLINE Py_UNICODE __Pyx_PyObject_AsPy_UNICODE(PyObject* x) {
    long ival;
    #if CYTHON_PEP393_ENABLED
    #if Py_UNICODE_SIZE > 2
    const long maxval = 1114111;
    #else
    const long maxval = 65535;
    #endif
    #else
    static long maxval = 0;
    #endif
    if (PyUnicode_Check(x)) {
        if (unlikely(__Pyx_PyUnicode_GET_LENGTH(x) != 1)) {
            PyErr_Format(PyExc_ValueError,
                         "only single character unicode strings can be converted to Py_UNICODE, "
                         "got length %" CYTHON_FORMAT_SSIZE_T "d", __Pyx_PyUnicode_GET_LENGTH(x));
            return (Py_UNICODE)-1;
        }
        #if CYTHON_PEP393_ENABLED
        ival = PyUnicode_READ_CHAR(x, 0);
        #else
        return PyUnicode_AS_UNICODE(x)[0];
        #endif
    } else {
        #if !CYTHON_PEP393_ENABLED
        if (unlikely(!maxval))
            maxval = (long)PyUnicode_GetMax();
        #endif
        ival = __Pyx_PyInt_As_long(x);
    }
    if (unlikely(ival < 0)) {
        if (!PyErr_Occurred())
            PyErr_SetString(PyExc_OverflowError,
                            "cannot convert negative value to Py_UNICODE");
        return (Py_UNICODE)-1;
    } else if (unlikely(ival > maxval)) {
        PyErr_SetString(PyExc_OverflowError,
                        "value too large to convert to Py_UNICODE");
        return (Py_UNICODE)-1;
    }
    return (Py_UNICODE)ival;
}

/* CIntFromPyVerify */
  #define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* GetAttr */
  static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* CIntFromPy */
  static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* Globals */
  static PyObject* __Pyx_Globals(void) {
    Py_ssize_t i;
    PyObject *names;
    PyObject *globals = __pyx_d;
    Py_INCREF(globals);
    names = PyObject_Dir(__pyx_m);
    if (!names)
        goto bad;
    for (i = PyList_GET_SIZE(names)-1; i >= 0; i--) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject* name = PySequence_ITEM(names, i);
        if (!name)
            goto bad;
#else
        PyObject* name = PyList_GET_ITEM(names, i);
#endif
        if (!PyDict_Contains(globals, name)) {
            PyObject* value = __Pyx_GetAttr(__pyx_m, name);
            if (!value) {
#if CYTHON_COMPILING_IN_PYPY
                Py_DECREF(name);
#endif
                goto bad;
            }
            if (PyDict_SetItem(globals, name, value) < 0) {
#if CYTHON_COMPILING_IN_PYPY
                Py_DECREF(name);
#endif
                Py_DECREF(value);
                goto bad;
            }
        }
#if CYTHON_COMPILING_IN_PYPY
        Py_DECREF(name);
#endif
    }
    Py_DECREF(names);
    return globals;
bad:
    Py_XDECREF(names);
    Py_XDECREF(globals);
    return NULL;
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
  static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* FastTypeChecks */
  #if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
  static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
  static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            PyErr_Clear();
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(x);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
